@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_anim_c =
- *   "$Id: anim.c 14152 2010-12-05 12:24:05Z ryo_saeba $";
+ *   "$Id: anim.c 16220 2011-12-18 19:14:52Z ryo_saeba $";
  */
 
 /*
@@ -72,7 +72,7 @@ void init_anim(void) {
     animations[0].name = add_string("###none");
     animations[0].num_animations = 1;
     animations[0].faces = malloc(sizeof(New_Face*));
-    animations[0].faces[0] = NULL;
+    animations[0].faces[0] = &new_faces[find_face("bug.111", 0)];
     animations[0].facings = 0;
 
     snprintf(buf, sizeof(buf), "%s/animations", settings.datadir);
@@ -121,11 +121,13 @@ void init_anim(void) {
                 animations[num_animations].facings = 1;
             }
         } else {
-            int face = find_face(buf, 0);
-            faces[num_frames++] = &new_faces[face];
-            if (face == 0)
-                LOG(llevDebug, "Could not find face %s for animation %s\n",
+            unsigned face = find_face(buf, (unsigned)-1);
+            if (face == (unsigned)-1) {
+                LOG(llevError, "Could not find face %s for animation %s\n",
                     buf, animations[num_animations].name);
+                face = find_face("bug.111", 0);
+            }
+            faces[num_frames++] = &new_faces[face];
         }
     }
     fclose(fp);
@@ -180,13 +182,15 @@ int try_find_animation(const char *name) {
  * Updates the face-variable of an object.
  * If the object is the head of a multi-object, all objects are animated.
  * The object's state is not changed, but merely updated if needed (out of bounds of
- * new animation, reached end of animation, ...)
+ * new animation, reached end of animation, ...).
+ * This function correctly handles FLAG_IS_TURNABLE too.
  *
  * @param op is the object to animate.
  * @param dir is the direction the object is facing.  This is generally same as
  *    op->direction, but in some cases, op->facing is used instead - the
  *    caller has a better idea which one it really wants to be using,
- *    so let it pass along the right one.
+ *    so let it pass along the right one. This parameter is ignored if
+ *    the object has a head or is turnable.
  */
 void animate_object(object *op, int dir) {
     int max_state;  /* Max animation state object should be drawn in */
@@ -211,6 +215,8 @@ void animate_object(object *op, int dir) {
 
         if (NUM_ANIMATIONS(op) == NUM_ANIMATIONS(op->head))
             op->state = op->head->state;
+    } else if (QUERY_FLAG(op, FLAG_IS_TURNABLE)) {
+        dir = op->direction;
     }
 
     /* If object is turning, then max animation state is half through the
@@ -239,6 +245,9 @@ void animate_object(object *op, int dir) {
             base_state = 0;
         else
             base_state = (dir-1)*(NUM_ANIMATIONS(op)/8);
+    } else if (QUERY_FLAG(op, FLAG_IS_TURNABLE)) {
+        base_state = (NUM_ANIMATIONS(op) / 9) * (dir);
+        max_state = NUM_ANIMATIONS(op) / 9;
     }
 
     /* If beyond drawable states, reset */
@@ -246,8 +255,6 @@ void animate_object(object *op, int dir) {
         op->state = 0;
         if (op->temp_animation_id) {
             op->temp_animation_id = 0;
-            /* op->last_anim = 0; */
-            /* object_update(op, UP_OBJ_FACE); */
             animate_object(op, dir);
             return;
         }
@@ -311,7 +318,6 @@ void apply_anim_suffix(object *who, sstring suffix) {
         for (; head != NULL; head = head->more) {
             head->temp_animation_id = anim;
             head->temp_anim_speed = animations[anim].num_animations/animations[anim].facings;
-            head->temp_last_anim = 0;
             head->last_anim = 0;
             head->state = 0;
         }
