@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_arch_c =
- *   "$Id: arch.c 14097 2010-11-15 07:17:37Z mwedel $";
+ *   "$Id: arch.c 15665 2011-11-11 10:37:59Z ryo_saeba $";
  */
 
 /*
@@ -358,24 +358,15 @@ archetype *get_archetype_struct(void) {
  * opened file descriptor which will be used to read the archetypes.
  */
 static void first_arch_pass(FILE *fp) {
-    object *op;
     archetype *at, *head = NULL, *last_more = NULL;
-    int i, first = 2;
+    int i, first = LO_NEWFILE;
 
-    op = object_new();
-    op->arch = first_archetype = at = get_archetype_struct();
+    at = get_archetype_struct();
+    first_archetype = at;
 
-    while ((i = load_object(fp, op, first, 0))) {
+    while ((i = load_object(fp, &at->clone, first, 0))) {
         first = 0;
-        object_copy(op, &at->clone);
         at->clone.speed_left = (float)(-0.1);
-        /* copy the body_info to the body_used - this is only really
-         * need for monsters, but doesn't hurt to do it for everything.
-         * by doing so, when a monster is created, it has good starting
-         * values for the body_used info, so when items are created
-         * for it, they can be properly equipped.
-         */
-        memcpy(&at->clone.body_used, &op->body_info, sizeof(op->body_info));
 
         switch (i) {
         case LL_NORMAL: /* A new archetype, just link it with the previous */
@@ -420,11 +411,8 @@ static void first_arch_pass(FILE *fp) {
         }
 
         at = get_archetype_struct();
-        object_clear(op);
-        op->arch = at;
     }
-    object_free_drop_inventory(op);
-    op->arch = NULL; /* arch is checked for temporary archetypes if not NULL. */
+    at->clone.arch = NULL; /* arch is checked for temporary archetypes if not NULL. */
     free(at);
 }
 
@@ -559,14 +547,13 @@ static void check_spells(void) {
 static void load_archetypes(void) {
     FILE *fp;
     char filename[MAX_BUF];
-    int comp;
 #if TIME_ARCH_LOAD
     struct timeval tv1, tv2;
 #endif
 
     snprintf(filename, sizeof(filename), "%s/%s", settings.datadir, settings.archetypes);
     LOG(llevDebug, "Reading archetypes from %s...\n", filename);
-    if ((fp = open_and_uncompress(filename, 0, &comp, "r")) == NULL) {
+    if ((fp = fopen(filename, "r")) == NULL) {
         LOG(llevError, " Can't open archetype file.\n");
         return;
     }
@@ -595,11 +582,7 @@ static void load_archetypes(void) {
     init_archetable();
     warn_archetypes = 1;
 
-    /* do a close and reopen instead of a rewind - necessary in case the
-     * file has been compressed.
-     */
-    close_and_delete(fp, comp);
-    fp = open_and_uncompress(filename, 0, &comp, "r");
+    rewind(fp);
 
     LOG(llevDebug, " loading treasure...\n");
     load_treasures();
@@ -610,7 +593,7 @@ static void load_archetypes(void) {
     check_generators();
     check_spells();
     check_summoned();
-    close_and_delete(fp, comp);
+    fclose(fp);
     LOG(llevDebug, " done\n");
 }
 
@@ -823,7 +806,7 @@ int is_type_valid(uint8 type) {
 
     if (type == 11 || type == 12)
         return 0;
-    if (type == 19 || type == 25 || type == 35 || type == 38 || type == 47)
+    if (type == 19 || type == 25 || type == 35 || type == 38 || type == 44 || type == 47)
         return 0;
     if (type == 61 || type == 63 || type == 76 || type == 78 || type == 81)
         return 0;
