@@ -218,6 +218,9 @@ void give_artifact_abilities(object *op, const object *artifact) {
     if (op->title)
         free_string(op->title);
     op->title = add_string(new_name);
+    if (op->artifact)
+        free_string(op->artifact);
+    op->artifact = add_refcount(artifact->name);
     add_abilities(op, artifact); /* Give out the bonuses */
 
     return;
@@ -264,17 +267,26 @@ int legal_artifact_combination(const object *op, const artifact *art) {
  */
 void add_abilities(object *op, const object *change) {
     int i, tmp;
+    char buf[MAX_BUF];
 
     if (change->face != blank_face) {
 #ifdef TREASURE_VERBOSE
         LOG(llevDebug, "FACE: %d\n", change->face->number);
 #endif
-        op->face = change->face;
+
+        object_set_value(op, "identified_face", change->face->name, 1);
     }
-    if (change->animation_id != 0) {
-        op->animation_id = change->animation_id;
-        SET_FLAG(op, FLAG_ANIMATE);
-        animate_object(op, op->facing);
+    if (QUERY_FLAG(change, FLAG_CLIENT_ANIM_RANDOM)) {
+        object_set_value(op, "identified_anim_random", "1", 1);
+    }
+    if (change->anim_speed > 0) {
+        snprintf(buf, sizeof(buf), "%d", change->anim_speed);
+        object_set_value(op, "identified_anim_speed", buf, 1);
+    }
+    if (change->animation_id != 0 && op->arch != NULL) {
+        /* op->arch can be NULL when called from artifact_msg(). */
+        snprintf(buf, sizeof(buf),"%d", change->animation_id);
+        object_set_value(op, "identified_animation", buf, 1);
     }
 
     for (i = 0; i < NUM_STATS; i++)
@@ -340,6 +352,9 @@ void add_abilities(object *op, const object *change) {
                 object_free_drop_inventory(tmp_obj);
             }
             tmp_obj = arch_to_object(change->other_arch);
+            /* This is an artifact, so this function will be called at load time,
+             * thus we don't need to keep the inventory */
+            SET_FLAG(tmp_obj, FLAG_NO_SAVE);
             object_insert_in_ob(tmp_obj, op);
         }
         /* No harm setting this for potions/horns */
@@ -472,7 +487,7 @@ void init_artifacts(void) {
     char filename[MAX_BUF], buf[HUGE_BUF], *cp, *next;
     artifact *art = NULL;
     linked_char *tmp;
-    int value, comp;
+    int value;
     artifactlist *al;
     archetype dummy_archetype;
 
@@ -487,7 +502,7 @@ void init_artifacts(void) {
 
     snprintf(filename, sizeof(filename), "%s/artifacts", settings.datadir);
     LOG(llevDebug, "Reading artifacts from %s...\n", filename);
-    if ((fp = open_and_uncompress(filename, 0, &comp, "r")) == NULL) {
+    if ((fp = fopen(filename, "r")) == NULL) {
         LOG(llevError, "Can't open %s.\n", filename);
         return;
     }
@@ -558,7 +573,7 @@ void init_artifacts(void) {
             LOG(llevError, "Unknown input in artifact file: %s\n", buf);
     }
 
-    close_and_delete(fp, comp);
+    fclose(fp);
 
     for (al = first_artifactlist; al != NULL; al = al->next) {
         for (art = al->items; art != NULL; art = art->next) {
@@ -587,6 +602,32 @@ const artifactlist *find_artifactlist(int type) {
     return find_artifactlist_internal(type);
 }
 
+/**
+ * Searches and returns a specific artifact, NULL if not found.
+ * @param op item to search for.
+ * @param name artifact name.
+ * @return matching artifact, NULL if none matched.
+ */
+const artifact *find_artifact(const object *op, const char *name) {
+    artifactlist *list;
+    artifact *at;
+    sstring sname = find_string(name);
+
+    if (sname == NULL)
+        return NULL;
+
+    list = find_artifactlist_internal(op->type);
+    if (list == NULL)
+        return NULL;
+
+    for (at = list->items; at != NULL; at = at->next) {
+        if (at->item->name == sname && legal_artifact_combination(op, at))
+            return at;
+    }
+
+    return NULL;
+}
+
 /**
  * For debugging purposes.  Dumps all tables.
  *
@@ -613,3 +654,51 @@ void dump_artifacts(void) {
     }
     fprintf(logfile, "\n");
 }
+
+/**
+ * Get a suitable face number for representing an artifact.
+ * @param art what to get the face of.
+ * @return face, -1 as unsigned if none could be found.
+ */
+unsigned artifact_get_face(const artifact *art) {
+    const archetype *arch = first_archetype;
+
+    if (art->item->face != blank_face && art->item->face != NULL)
+        return art->item->face->number;
+
+    if (art->allowed_size > 0) {
+        if (art->allowed->name[0] == '!') {
+            linked_char *allowed;
+            while (arch) {
+                if (arch->clone.type != art->item->type)
+                    arch = arch->next;
+
+                for (allowed = art->allowed; allowed != NULL; allowed = allowed->next) {
+                    if (strcmp(arch->name, allowed->name + 1) == 0) {
+                        break;
+                    }
+                }
+                if (allowed != NULL)
+                    continue;
+
+                if (arch->clone.face == NULL)
+                    continue;
+                return arch->clone.face->number;
+            }
+            return (unsigned)-1;
+        } else {
+            const archetype *arch = find_archetype(art->allowed->name);
+            if (arch != NULL)
+                return arch->clone.face->number;
+            return (unsigned)-1;
+        }
+    }
+
+    while (arch != NULL) {
+        if (arch->clone.type == art->item->type && arch->clone.face != NULL)
+            return arch->clone.face->number;
+
+        arch = arch->next;
+    }
+    return (unsigned)-1;
+}
