@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_holy_c =
- *   "$Id: holy.c 13531 2010-07-29 17:03:56Z ryo_saeba $";
+ *   "$Id: holy.c 17403 2012-03-08 22:22:35Z ryo_saeba $";
  */
 
 /*
@@ -146,7 +146,7 @@ const object *pntr_to_god_obj(godlink *godlnk) {
  * @param maxlen maximum wanted length of the description, if 0 no maximum length.
  * @return information actually written, combination of @ref GOD_xxx "GOD_xxx", based on maxlen.
  */
-int describe_god(const object *god, int what, StringBuffer *buf, int maxlen) {
+int describe_god(const object *god, int what, StringBuffer *buf, size_t maxlen) {
     int hassomething = 0, real = 0;
     char temp[HUGE_BUF];
     StringBuffer *add;
@@ -170,26 +170,24 @@ int describe_god(const object *god, int what, StringBuffer *buf, int maxlen) {
     if (what & GOD_PATHS) {
         /* spell paths */
         int has_effect = 0;
-        size_t buflen = 0;
-        temp[0] = '\0';
 
         add = stringbuffer_new();
         stringbuffer_append_printf(add, "It is rarely known fact that the priests of %s are mystically transformed. Effects of this include:\n", name);
 
         if (god->path_attuned) {
             has_effect = 1;
-            DESCRIBE_PATH_SAFE(temp, god->path_attuned, "Attuned", &buflen, BOOK_BUF);
+            describe_spellpath_attenuation("Attuned", god->path_attuned, add);
         }
         if (god->path_repelled) {
             has_effect = 1;
-            DESCRIBE_PATH_SAFE(temp, god->path_repelled, "Repelled", &buflen, BOOK_BUF);
+            describe_spellpath_attenuation("Repelled", god->path_repelled, add);
         }
         if (god->path_denied) {
             has_effect = 1;
-            DESCRIBE_PATH_SAFE(temp, god->path_denied, "Denied", &buflen, BOOK_BUF);
+            describe_spellpath_attenuation("Denied", god->path_denied, add);
         }
         if (has_effect) {
-            stringbuffer_append_printf(add, "%s\n ---\n", temp);
+            stringbuffer_append_string(add, "\n ---\n");
 
             if ((maxlen == 0) || (stringbuffer_length(add) + stringbuffer_length(buf) < maxlen)) {
                 stringbuffer_append_stringbuffer(buf, add);
@@ -361,6 +359,36 @@ void free_all_god(void) {
     first_god = NULL;
 }
 
+#define DESCRIBE_ABILITY(retbuf, variable, name)                   \
+    if (variable) {                                                \
+        int i, j = 0;                                              \
+        strcat(retbuf, "(" name ": ");                             \
+        for (i = 0; i < NROFATTACKS; i++)                          \
+            if (variable&(1<<i)) {                                 \
+                if (j)                                             \
+                    strcat(retbuf, ", ");                          \
+                else                                               \
+                    j = 1;                                         \
+                strcat(retbuf, attacks[i]);                        \
+            }                                                      \
+        strcat(retbuf, ")");                                       \
+    }
+
+#define DESCRIBE_PATH(retbuf, variable, name)                      \
+    if (variable) {                                                \
+        int i, j = 0;                                              \
+        strcat(retbuf, "(" name ": ");                             \
+        for (i = 0; i < NRSPELLPATHS; i++)                         \
+            if (variable&(1<<i)) {                                 \
+                if (j)                                             \
+                    strcat(retbuf, ", ");                          \
+                else                                               \
+                    j = 1;                                         \
+                strcat(retbuf, spellpathnames[i]);                 \
+            }                                                      \
+        strcat(retbuf, ")");                                       \
+    }
+
 /**
  * Prints all gods to stderr.
  *
