@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_image_c =
- *   "$Id: image.c 14029 2010-10-24 11:58:25Z ryo_saeba $";
+ *   "$Id: image.c 15579 2011-11-08 21:14:12Z ryo_saeba $";
  */
 
 /*
@@ -35,30 +35,12 @@
 #include <stdio.h>
 #include "image.h"
 
+/**
+ * Contains face information, with names, numbers, magicmap color and such.
+ * It is sorted by alphabetical order.
+ */
 New_Face *new_faces;
 
-/**
- * bmappair and ::xbm are used when looking for the image id numbers
- * of a face by name.  xbm is sorted alphabetically so that bsearch
- * can be used to quickly find the entry for a name.  the number is
- * then an index into the new_faces array.
- * This data is redundant with new_face information - the difference
- * is that this data gets sorted, and that doesn't necessarily happen
- * with the new_face data - when accessing new_face[some number],
- * that some number corresponds to the face at that number - for
- * xbm, it may not.  At current time, these do in fact match because
- * the bmaps file is created in a sorted order.
- */
-struct bmappair {
-    char *name;
-    unsigned int number;
-};
-/**
- * The xbm array (which contains name and number information, and
- * is then sorted) contains nroffiles entries.
- */
-static struct bmappair *xbm = NULL;
-
 /**
  * Following can just as easily be pointers, but
  * it is easier to keep them like this.
@@ -66,14 +48,10 @@ static struct bmappair *xbm = NULL;
 New_Face *blank_face, *empty_face, *smooth_face;
 
 
-/** nroffiles is the actual number of bitmaps defined. */
-static int nroffiles = 0;
-
-/** nrofpixmaps is the number of bitmaps loaded.  With
- * the automatic generation of the bmaps file, this is now equal
- * to nroffiles.
+/**
+ * Number of bitmaps loaded from the "bmaps" file.
  */
-int nrofpixmaps = 0;
+unsigned int nrofpixmaps = 0;
 
 face_sets facesets[MAX_FACE_SETS];    /**< All facesets */
 
@@ -101,9 +79,23 @@ static const char *const colorname[] = {
 };
 
 /**
- * Used for bsearch searching.
+ * Used for bsearch searching for faces by name.
+ * The face "bug.111" is always put at first.
+ * @todo "bug.111" should be a regular face, alas many places consider face 0
+ * to be that face. This should be fixed at some point.
+ * @param a first item to compare.
+ * @param b second item to compare.
+ * @retval -1 if a < b
+ * @retval 0 if a == b
+ * @retval 1 if a > b
  */
-static int compar(const struct bmappair *a, const struct bmappair *b) {
+static int compare_face(const New_Face *a, const New_Face *b) {
+    if (strcmp(a->name, "bug.111") == 0) {
+        if (strcmp(b->name, "bug.111") == 0)
+            return 0;
+        return -1;
+    } else if (strcmp(b->name, "bug.111") == 0)
+        return 1;
     return strcmp(a->name, b->name);
 }
 
@@ -133,7 +125,7 @@ static uint8 find_color(const char *name) {
 
 /**
  * This reads the lib/faces file, getting color and visibility information.
- * it is called by read_bmap_names().
+ * It is called by read_bmap_names().
  *
  * @note
  * will call exit() if file doesn't exist.
@@ -163,6 +155,7 @@ static void read_face_data(void) {
 
             if ((tmp = find_face(cp, (unsigned)-1)) == (unsigned)-1) {
                 LOG(llevError, "Could not find face %s\n", cp);
+                on_face = NULL;
                 continue;
             }
             on_face = &new_faces[tmp];
@@ -198,7 +191,8 @@ static void read_face_data(void) {
 void read_bmap_names(void) {
     char buf[MAX_BUF], *p, *q;
     FILE *fp;
-    int value, nrofbmaps = 0, i;
+    int value;
+    unsigned int i;
     size_t l;
 
     bmaps_checksum = 0;
@@ -209,21 +203,29 @@ void read_bmap_names(void) {
         exit(-1);
     }
 
+    nrofpixmaps = 0;
+
     /* First count how many bitmaps we have, so we can allocate correctly */
     while (fgets(buf, MAX_BUF, fp) != NULL)
         if (buf[0] != '#' && buf[0] != '\n')
-            nrofbmaps++;
+            nrofpixmaps++;
     rewind(fp);
 
-    xbm = (struct bmappair *)malloc(sizeof(struct bmappair)*nrofbmaps);
-    if (xbm == NULL) {
-        LOG(llevError, "read_bmap_names: xbm memory allocation failure.\n");
+    new_faces = (New_Face *)malloc(sizeof(New_Face)*nrofpixmaps);
+    if (new_faces == NULL) {
+        LOG(llevError, "read_bmap_names: new_faces memory allocation failure.\n");
         abort();
     }
-    memset(xbm, 0, sizeof(struct bmappair)*nrofbmaps);
 
-    nroffiles = 0;
-    while (nroffiles < nrofbmaps && fgets(buf, MAX_BUF, fp) != NULL) {
+    for (i = 0; i < nrofpixmaps; i++) {
+        new_faces[i].name = NULL;
+        new_faces[i].visibility = 0;
+        new_faces[i].magicmap = 255;
+        new_faces[i].smoothface = (uint16)-1;
+    }
+
+    i = 0;
+    while (i < nrofpixmaps && fgets(buf, MAX_BUF, fp) != NULL) {
         if (*buf == '#')
             continue;
 
@@ -233,7 +235,7 @@ void read_bmap_names(void) {
             continue;
         }
         value = atoi(p);
-        xbm[nroffiles].name = strdup_local(q);
+        new_faces[i].name = strdup_local(q);
 
         /* We need to calculate the checksum of the bmaps file
          * name->number mapping to send to the client.  This does not
@@ -255,35 +257,23 @@ void read_bmap_names(void) {
             bmaps_checksum &= 0xffffffff;
         }
 
-        xbm[nroffiles].number = value;
-        nroffiles++;
-        if (value >= nrofpixmaps)
-            nrofpixmaps = value+1;
+        i++;
     }
     fclose(fp);
 
-    LOG(llevDebug, "done (got %d/%d/%d)\n", nrofpixmaps, nrofbmaps, nroffiles);
-
-    new_faces = (New_Face *)malloc(sizeof(New_Face)*nrofpixmaps);
-    if (new_faces == NULL) {
-        LOG(llevError, "read_bmap_names: new_faces memory allocation failure.\n");
-        abort();
+    if (i != nrofpixmaps) {
+        LOG(llevError, "read_bmap_names: first read gave %d faces but only loaded %d??\n", nrofpixmaps, i);
+        fatal(SEE_LAST_ERROR);
     }
 
+    LOG(llevDebug, "done (got %d faces)\n", nrofpixmaps);
+
+    qsort(new_faces, nrofpixmaps, sizeof(New_Face), (int (*)(const void *, const void *))compare_face);
+
     for (i = 0; i < nrofpixmaps; i++) {
-        new_faces[i].name = "";
         new_faces[i].number = i;
-        new_faces[i].visibility = 0;
-        new_faces[i].magicmap = 255;
-        new_faces[i].smoothface = (uint16)-1;
     }
 
-    for (i = 0; i < nroffiles; i++) {
-        new_faces[xbm[i].number].name = xbm[i].name;
-    }
-
-    qsort(xbm, nroffiles, sizeof(struct bmappair), (int (*)(const void *, const void *))compar);
-
     read_face_data();
 
     for (i = 0; i < nrofpixmaps; i++) {
@@ -322,10 +312,10 @@ void read_bmap_names(void) {
  * from the server)
  */
 unsigned find_face(const char *name, unsigned error) {
-    struct bmappair *bp, tmp;
+    New_Face *bp, tmp;
 
-    tmp.name = (char *)name;
-    bp = (struct bmappair *)bsearch(&tmp, xbm, nroffiles, sizeof(struct bmappair), (int (*)(const void *, const void *))compar);
+    tmp.name = name;
+    bp = (New_Face *)bsearch(&tmp, new_faces, nrofpixmaps, sizeof(New_Face), (int (*)(const void *, const void *))compare_face);
 
     return bp ? bp->number : error;
 }
@@ -416,11 +406,10 @@ int find_smooth(uint16 face, uint16 *smoothed) {
  * Deallocates memory allocated by read_bmap_names() and read_smooth().
  */
 void free_all_images(void) {
-    int i;
+    unsigned int i;
 
-    for (i = 0; i < nroffiles; i++)
-        free(xbm[i].name);
-    free(xbm);
+    for (i = 0; i < nrofpixmaps; i++)
+        free((char*)(new_faces[i].name));
     free(new_faces);
 }
 
@@ -471,19 +460,18 @@ static void check_faceset_fallback(int faceset, int togo) {
 void read_client_images(void) {
     char filename[400];
     char buf[HUGE_BUF];
-    char *cp, *cps[7+1];
+    char *cp, *cps[7+1], *slash;
     FILE *infile;
-    int num, len, compressed, fileno, i, badline;
+    int len, fileno, i;
+    unsigned int num;
 
     memset(facesets, 0, sizeof(facesets));
     snprintf(filename, sizeof(filename), "%s/image_info", settings.datadir);
-    if ((infile = open_and_uncompress(filename, 0, &compressed, "r")) == NULL) {
+    if ((infile = fopen(filename, "r")) == NULL) {
         LOG(llevError, "Unable to open %s\n", filename);
         abort();
     }
     while (fgets(buf, HUGE_BUF-1, infile) != NULL) {
-        badline = 0;
-
         if (buf[0] == '#')
             continue;
         if (split_string(buf, cps, sizeof(cps)/sizeof(*cps), ':') != 7)
@@ -502,7 +490,7 @@ void read_client_images(void) {
             facesets[len].comment = strdup_local(cps[6]);
         }
     }
-    close_and_delete(infile, compressed);
+    fclose(infile);
     for (i = 0; i < MAX_FACE_SETS; i++) {
         if (facesets[i].prefix)
             check_faceset_fallback(i, MAX_FACE_SETS);
@@ -520,7 +508,7 @@ void read_client_images(void) {
         snprintf(filename, sizeof(filename), "%s/crossfire.%d", settings.datadir, fileno);
         LOG(llevDebug, "Loading image file %s\n", filename);
 
-        if ((infile = open_and_uncompress(filename, 0, &compressed, "rb")) == NULL) {
+        if ((infile = fopen(filename, "rb")) == NULL) {
             LOG(llevError, "Unable to open %s\n", filename);
             abort();
         }
@@ -529,22 +517,38 @@ void read_client_images(void) {
                 LOG(llevError, "read_client_images:Bad image line - not IMAGE, instead\n%s", buf);
                 abort();
             }
-            num = atoi(buf+6);
-            if (num < 0 || num >= nrofpixmaps) {
-                LOG(llevError, "read_client_images: Image num %d not in 0..%d\n%s", num, nrofpixmaps, buf);
-                abort();
-            }
-            /* Skip accross the number data */
-            for (cp = buf+6; *cp != ' '; cp++)
-                ;
+            cp = buf + 6;
             len = atoi(cp);
             if (len == 0 || len > MAX_IMAGE_SIZE) {
                 LOG(llevError, "read_client_images: length not valid: %d > %d \n%s", len, MAX_IMAGE_SIZE, buf);
                 abort();
             }
-            /* We don't actualy care about the name if the image that
-             * is embedded in the image file, so just ignore it.
-             */
+
+            for ( ; *cp != ' ' && *cp != '\n' && *cp != '\0'; cp++)
+                ;
+            if (*cp != ' ') {
+                LOG(llevError, "read_client_images: couldn't find name start for %d\n", num);
+                abort();
+            }
+            cp++;
+            /* cp points to the start of the full name */
+            slash = strrchr(cp, '/');
+            if (slash != NULL)
+                cp = slash + 1;
+            if (cp[strlen(cp) - 1] == '\n')
+                cp[strlen(cp) - 1] = '\0';
+
+            /* cp points to the start of the picture name itself */
+            num = find_face(cp, (unsigned)-1);
+            if (num == (unsigned)-1) {
+                LOG(llevError, "read_client_images: couldn't find picture %s\n", cp);
+                abort();
+            }
+            if (num >= nrofpixmaps) {
+                LOG(llevError, "read_client_images: invalid picture number %d for %s\n", num, cp);
+                abort();
+            }
+
             facesets[fileno].faces[num].datalen = len;
             facesets[fileno].faces[num].data = malloc(len);
             if ((i = fread(facesets[fileno].faces[num].data, len, 1, infile)) != 1) {
@@ -558,7 +562,7 @@ void read_client_images(void) {
                 facesets[fileno].faces[num].checksum &= 0xffffffff;
             }
         }
-        close_and_delete(infile, compressed);
+        fclose(infile);
     } /* For fileno < MAX_FACE_SETS */
 }
 
@@ -576,7 +580,8 @@ int is_valid_faceset(int fsn) {
  * Frees all faceset information
  */
 void free_socket_images(void) {
-    int num, q;
+    int num;
+    unsigned int q;
 
     for (num = 0; num < MAX_FACE_SETS; num++) {
         if (facesets[num].prefix) {
