@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_info_c =
- *    "$Id: info.c 13542 2010-08-01 10:22:09Z ryo_saeba $";
+ *    "$Id: info.c 17404 2012-03-08 22:31:47Z ryo_saeba $";
  */
 
 /*
@@ -34,6 +34,42 @@
  * in differently formatted output, mainly about monsters.
  */
 
+/**
+ * Writes num ones and zeros to the given string based on the
+ * bits variable.
+ *
+ * @param bits
+ * variable to convert to binary string
+ * @param num
+ * number of bits to dump. Values above 32 will be ignored.
+ * @param str
+ * string to write to. Must be long enough.
+ *
+ * @note
+ * no check is done whether str has enough space to write or not.
+ * Final \\0 is appended to str.
+ */
+static void bitstostring(long bits, int num, char *str) {
+    int i, j = 0;
+
+    if (num > 32)
+        num = 32;
+
+    for (i = 0; i < num; i++) {
+        if (i && (i%3) == 0) {
+            str[i+j] = ' ';
+            j++;
+        }
+        if (bits&1)
+            str[i+j] = '1';
+        else
+            str[i+j] = '0';
+        bits >>= 1;
+    }
+    str[i+j] = '\0';
+    return;
+}
+
 /**
  * Dump to standard out the abilities of all monsters.
  */
@@ -92,39 +128,3 @@ void print_monsters(void) {
         object_free_drop_inventory(op);
     }
 }
-
-/**
- * Writes num ones and zeros to the given string based on the
- * bits variable.
- *
- * @param bits
- * variable to convert to binary string
- * @param num
- * number of bits to dump. Values above 32 will be ignored.
- * @param str
- * string to write to. Must be long enough.
- *
- * @note
- * no check is done whether str has enough space to write or not.
- * Final \\0 is appended to str.
- */
-void bitstostring(long bits, int num, char *str) {
-    int i, j = 0;
-
-    if (num > 32)
-        num = 32;
-
-    for (i = 0; i < num; i++) {
-        if (i && (i%3) == 0) {
-            str[i+j] = ' ';
-            j++;
-        }
-        if (bits&1)
-            str[i+j] = '1';
-        else
-            str[i+j] = '0';
-        bits >>= 1;
-    }
-    str[i+j] = '\0';
-    return;
-}
