@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_item_c =
- *   "$Id: item.c 14102 2010-11-19 06:35:42Z mwedel $";
+ *   "$Id: item.c 16871 2012-01-28 13:23:12Z ryo_saeba $";
  */
 
 /*
@@ -143,7 +143,6 @@ static const typedata item_types[] = {
     { TELEPORTER, "teleporter", "teleporters", 0, 0 },
     { CREATOR, "creator", "creators", 0, 0 },
     { SKILL, "skill", "skills", 0, 0 },
-    { EXPERIENCE, "experience", "experience", 0, 0 },
     { EARTHWALL, "earthwall", "earthwalls", 0, 0 },
     { GOLEM, "golem", "golems", 0, 0 },
     { THROWN_OBJ, "projectile", "projectiles", 0, 0 },
@@ -202,9 +201,9 @@ static const typedata item_types[] = {
     { POTION_RESIST_EFFECT, "potion effect", "potion effects", 0, 0 },
     { CLOSE_CON, "closed container", "closed container", 0, 0 },
     { CONTAINER, "container", "containers", SK_ALCHEMY, 0 },
-    { ARMOUR_IMPROVER, "armour improver", "armour improvers", 0, 0 },
-    { WEAPON_IMPROVER, "weapon improver", "weapon improvers", 0, 0 },
-    { SKILLSCROLL, "skillscroll", "skillscrolls", 0, 0 },
+    { ARMOUR_IMPROVER, "armour improver", "armour improvers", SK_LITERACY, 0 },
+    { WEAPON_IMPROVER, "weapon improver", "weapon improvers", SK_LITERACY, 0 },
+    { SKILLSCROLL, "skillscroll", "skillscrolls", SK_LITERACY, 0 },
     { DEEP_SWAMP, "deep swamp", "deep swamps", 0, 0 },
     { IDENTIFY_ALTAR, "identify altar", "identify altars", 0, 0 },
     { SHOP_INVENTORY, "inventory list", "inventory lists", 0, 0 },
@@ -461,9 +460,8 @@ void get_levelnumber(int i, char *buf, size_t size) {
  * buffer that will contain the description. If NULL a new one is created.
  * @return buf, or a new StringBuffer the caller should free if buf was NULL.
  * @todo why does this also describe a SKILL?
- * @todo make static when check (test/unit/common/check_item.c) is removed.
  */
-StringBuffer *ring_desc(const object *op, StringBuffer *buf) {
+static StringBuffer *ring_desc(const object *op, StringBuffer *buf) {
     int attr, val;
     size_t len;
 
@@ -616,22 +614,9 @@ void query_short_name(const object *op, char *buf, size_t size) {
  */
 void query_name(const object *op, char *buf, size_t size) {
     size_t len = 0;
-#ifdef NEW_MATERIAL_CODE
-    materialtype_t *mt;
-#endif
 
     buf[0] = '\0';
 
-#ifdef NEW_MATERIAL_CODE
-    if ((IS_ARMOR(op) || IS_WEAPON(op) || IS_SHIELD(op)) && op->materialname) {
-        mt = name_to_material(op->materialname);
-        if (mt) {
-            safe_strcat(buf, mt->description, &len, size);
-            safe_strcat(buf, " ", &len, size);
-        }
-    }
-#endif
-
     query_short_name(op, buf+len, size-len);
     len += strlen(buf+len);
 
@@ -719,9 +704,6 @@ void query_name(const object *op, char *buf, size_t size) {
  */
 void query_base_name(const object *op, int plural, char *buf, size_t size) {
     size_t len;
-#ifdef NEW_MATERIAL_CODE
-    materialtype_t *mt;
-#endif
 
     if ((!plural && !op->name)
     || (plural && !op->name_pl)) {
@@ -736,26 +718,8 @@ void query_base_name(const object *op, int plural, char *buf, size_t size) {
 
     buf[0] = '\0';
 
-#ifdef NEW_MATERIAL_CODE
-    if ((IS_ARMOR(op) || IS_WEAPON(op)) && op->materialname)
-        mt = name_to_material(op->materialname);
-    else
-        mt = NULL;
-
-    if (mt
-    && op->arch->clone.materialname != mt->name
-    && !(op->material&M_SPECIAL)) {
-        snprintf(buf, size, "%s", mt->description);
-        len = strlen(buf);
-        safe_strcat(buf, " ", &len, size);
-        safe_strcat(buf, plural ? op->name_pl : op->name, &len, size);
-    } else {
-#endif
-        snprintf(buf, size, "%s", plural ? op->name_pl : op->name);
-        len = strlen(buf);
-#ifdef NEW_MATERIAL_CODE
-    }
-#endif
+    snprintf(buf, size, "%s", plural ? op->name_pl : op->name);
+    len = strlen(buf);
 
     if (op->title && QUERY_FLAG(op, FLAG_IDENTIFIED)) {
         safe_strcat(buf, " ", &len, size);
@@ -1411,11 +1375,66 @@ int need_identify(const object *op) {
     case POISON:
     case BOOK:
     case SKILL_TOOL:
+    case ARMOUR_IMPROVER:
+    case WEAPON_IMPROVER:
         return 1;
     }
     return 0;
 }
 
+/**
+ * Ensure op has all its "identified" properties set.
+ * @param op object to process.
+ */
+void object_give_identified_properties(object *op) {
+    sstring key;
+
+    key = object_get_value(op, "identified_face");
+    if (key != NULL) {
+        op->face = &new_faces[find_face(key, op->face->number)];
+        /* if the face is defined, clean the animation, because else
+         * the face can be lost ; if an animation is defined, it'll be
+         * processed later on */
+        CLEAR_FLAG(op, FLAG_CLIENT_ANIM_RANDOM);
+        CLEAR_FLAG(op, FLAG_CLIENT_ANIM_SYNC);
+        op->anim_speed = 0;
+        op->animation_id = 0;
+        object_set_value(op, "identified_face", NULL, 0);
+    }
+
+    if (object_get_value(op, "identified_anim_random") != NULL) {
+        SET_FLAG(op, FLAG_CLIENT_ANIM_RANDOM);
+        object_set_value(op, "identified_anim_random", NULL, 0);
+    }
+
+    key = object_get_value(op, "identified_anim_speed");
+    if (key != NULL) {
+        op->anim_speed = atoi(key);
+        op->last_anim = 1;
+        object_set_value(op, "identified_anim_speed", NULL, 0);
+    }
+
+    key = object_get_value(op, "identified_animation");
+    if (key != NULL) {
+        op->animation_id = atoi(key);
+        if (!QUERY_FLAG(op, FLAG_IS_TURNABLE))
+            SET_FLAG(op, FLAG_ANIMATE);
+        animate_object(op, op->facing);
+        object_set_value(op, "identified_animation", NULL, 0);
+    }
+
+    key = object_get_value(op, "identified_name");
+    if (key != NULL) {
+        FREE_AND_COPY(op->name, key);
+        object_set_value(op, "identified_name", NULL, 0);
+    }
+    key = object_get_value(op, "identified_name_pl");
+    if (key != NULL) {
+        FREE_AND_COPY(op->name_pl, key);
+        object_set_value(op, "identified_name_pl", NULL, 0);
+    }
+}
+
 /**
  * Identifies an item.
  * Supposed to fix face-values as well here, but later.
@@ -1436,6 +1455,8 @@ object *identify(object *op) {
     CLEAR_FLAG(op, FLAG_KNOWN_MAGICAL);
     CLEAR_FLAG(op, FLAG_NO_SKILL_IDENT);
 
+    object_give_identified_properties(op);
+
     /*
      * We want autojoining of equal objects:
      */
