@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_map_c =
- *   "$Id: map.c 13962 2010-10-03 09:47:30Z ryo_saeba $";
+ *   "$Id: map.c 15908 2011-11-24 18:01:35Z ryo_saeba $";
  */
 
 /*
@@ -216,9 +216,8 @@ static void create_items_path(const char *s, char *buf, size_t size) {
 int check_path(const char *name, int prepend_dir) {
     char buf[MAX_BUF];
 #ifndef WIN32
-    char *endbuf;
     struct stat statbuf;
-    int mode = 0, i;
+    int mode = 0;
 #endif
 
     if (prepend_dir)
@@ -229,23 +228,9 @@ int check_path(const char *name, int prepend_dir) {
     return(_access(buf, 0));
 #else
 
-    /* old method (strchr(buf, '\0')) seemd very odd to me -
-     * this method should be equivalant and is clearer.
-     * Can not use strcat because we need to cycle through
-     * all the names.
-     */
-    endbuf = buf+strlen(buf);
+    if (stat(buf, &statbuf) != 0)
+        return -1;
 
-    for (i = 0; i < NROF_COMPRESS_METHODS; i++) {
-        if (uncomp[i][0])
-            snprintf(endbuf, buf+sizeof(buf)-endbuf, "%s", uncomp[i][0]);
-        else
-            *endbuf = '\0';
-        if (!stat(buf, &statbuf))
-            break;
-    }
-    if (i == NROF_COMPRESS_METHODS)
-        return (-1);
     if (!S_ISREG(statbuf.st_mode))
         return (-1);
 
@@ -1215,7 +1200,6 @@ static int load_map_header(FILE *fp, mapstruct *m) {
 mapstruct *load_original_map(const char *filename, int flags) {
     FILE *fp;
     mapstruct *m;
-    int comp;
     char pathname[MAX_BUF];
 
     LOG(llevDebug, "load_original_map: %s (%x)\n", filename, flags);
@@ -1226,7 +1210,7 @@ mapstruct *load_original_map(const char *filename, int flags) {
     else
         create_pathname(filename, pathname, MAX_BUF);
 
-    if ((fp = open_and_uncompress(pathname, 0, &comp, "r")) == NULL) {
+    if ((fp = fopen(pathname, "r")) == NULL) {
         char err[MAX_BUF];
 
         LOG((flags&MAP_PLAYER_UNIQUE) ? llevDebug : llevError, "Can't open %s: %s\n", pathname, strerror_local(errno, err, sizeof(err)));
@@ -1243,11 +1227,10 @@ mapstruct *load_original_map(const char *filename, int flags) {
     }
 
     allocate_map(m);
-    m->compressed = comp;
 
     m->in_memory = MAP_LOADING;
     load_objects(m, fp, flags&(MAP_BLOCK|MAP_STYLE));
-    close_and_delete(fp, comp);
+    fclose(fp);
     m->in_memory = MAP_IN_MEMORY;
     if (!MAP_DIFFICULTY(m))
         MAP_DIFFICULTY(m) = calculate_difficulty(m);
@@ -1259,6 +1242,9 @@ mapstruct *load_original_map(const char *filename, int flags) {
     /* Handle for map load event */
     execute_global_event(EVENT_MAPLOAD, m);
 
+    if (!(flags & MAP_STYLE))
+        apply_auto_fix(m); /* Chests which open as default */
+
     return (m);
 }
 
@@ -1268,53 +1254,33 @@ mapstruct *load_original_map(const char *filename, int flags) {
  * @param m
  * map we want to reload.
  * @return
- * map object we load into (this can change from the passed
- * option if we can't find the original map)
- *
- * @todo
- * check spurious logic for load_map_header failure (shouldn't it return m?)
+ * 0 if success, non zero if failure, in which case error was LOG'ed.
  */
-static mapstruct *load_temporary_map(mapstruct *m) {
+static int load_temporary_map(mapstruct *m) {
     FILE *fp;
-    int comp;
     char buf[MAX_BUF];
 
     if (!m->tmpname) {
         LOG(llevError, "No temporary filename for map %s\n", m->path);
-        snprintf(buf, sizeof(buf), "%s", m->path);
-        delete_map(m);
-        m = load_original_map(buf, 0);
-        if (m == NULL)
-            return NULL;
-        apply_auto_fix(m); /* Chests which open as default */
-        return m;
+        return 1;
     }
 
-    if ((fp = open_and_uncompress(m->tmpname, 0, &comp, "r")) == NULL) {
+    if ((fp = fopen(m->tmpname, "r")) == NULL) {
         LOG(llevError, "Cannot open %s: %s\n", m->tmpname, strerror_local(errno, buf, sizeof(buf)));
-        snprintf(buf, sizeof(buf), "%s", m->path);
-        delete_map(m);
-        m = load_original_map(buf, 0);
-        if (m == NULL)
-            return NULL;
-        apply_auto_fix(m); /* Chests which open as default */
-        return m;
+        return 2;
     }
 
     if (load_map_header(fp, m)) {
         LOG(llevError, "Error loading map header for %s (%s)\n", m->path, m->tmpname);
-        delete_map(m);
-        m = load_original_map(m->path, 0);
-        return NULL;
+        return 3;
     }
-    m->compressed = comp;
     allocate_map(m);
 
     m->in_memory = MAP_LOADING;
     load_objects(m, fp, 0);
-    close_and_delete(fp, comp);
+    fclose(fp);
     m->in_memory = MAP_IN_MEMORY;
-    return m;
+    return 0;
 }
 
 /**
@@ -1324,35 +1290,30 @@ static mapstruct *load_temporary_map(mapstruct *m) {
  * @param m
  * map we want to load.
  * @return
- * map object we load into (this can change from the passed
- * option if we can't find the original map)
+ * 0 on success, non zero in case of error, which is LOG'ed.
  */
-static mapstruct *load_overlay_map(const char *filename, mapstruct *m) {
+static int load_overlay_map(const char *filename, mapstruct *m) {
     FILE *fp;
-    int comp;
     char pathname[MAX_BUF];
 
     create_overlay_pathname(filename, pathname, MAX_BUF);
 
-    if ((fp = open_and_uncompress(pathname, 0, &comp, "r")) == NULL) {
-        /* LOG(llevDebug, "Can't open overlay %s\n", pathname);*/
-        return m;
+    if ((fp = fopen(pathname, "r")) == NULL) {
+        /* nothing bad to not having an overlay */
+        return 0;
     }
 
     if (load_map_header(fp, m)) {
         LOG(llevError, "Error loading map header for overlay %s (%s)\n", m->path, pathname);
-        delete_map(m);
-        m = load_original_map(m->path, 0);
-        return NULL;
+        return 1;
     }
-    m->compressed = comp;
     /*allocate_map(m);*/
 
     m->in_memory = MAP_LOADING;
     load_objects(m, fp, MAP_OVERLAY);
-    close_and_delete(fp, comp);
+    fclose(fp);
     m->in_memory = MAP_IN_MEMORY;
-    return m;
+    return 0;
 }
 
 /******************************************************************************
@@ -1392,7 +1353,7 @@ static void delete_unique_items(mapstruct *m) {
  */
 static void load_unique_objects(mapstruct *m) {
     FILE *fp;
-    int comp, count;
+    int count;
     char firstname[MAX_BUF], name[MAX_BUF];
 
     create_items_path(m->path, name, MAX_BUF);
@@ -1405,7 +1366,7 @@ static void load_unique_objects(mapstruct *m) {
     if (count == 10)
         return;
 
-    if ((fp = open_and_uncompress(firstname, 0, &comp, "r")) == NULL) {
+    if ((fp = fopen(firstname, "r")) == NULL) {
         /* There is no expectation that every map will have unique items, but this
         * is debug output, so leave it in.
         */
@@ -1418,7 +1379,7 @@ static void load_unique_objects(mapstruct *m) {
         delete_unique_items(m); /* original map before, don't duplicate them */
     load_object(fp, NULL, LO_NOREAD, 0);
     load_objects(m, fp, 0);
-    close_and_delete(fp, comp);
+    fclose(fp);
     m->in_memory = MAP_IN_MEMORY;
 }
 
@@ -1457,13 +1418,6 @@ int save_map(mapstruct *m, int flag) {
         } else
             snprintf(filename, sizeof(filename), "%s", m->path);
 
-        /* If the compression suffix already exists on the filename, don't
-         * put it on again.  This nasty looking strcmp checks to see if the
-         * compression suffix is at the end of the filename already.
-         */
-        if (m->compressed
-        && strcmp((filename+strlen(filename)-strlen(uncomp[m->compressed][0])), uncomp[m->compressed][0]))
-            strcat(filename, uncomp[m->compressed][0]);
         make_path_to_file(filename);
     } else {
         if (!m->tmpname)
@@ -1473,17 +1427,9 @@ int save_map(mapstruct *m, int flag) {
     LOG(llevDebug, "Saving map %s\n", m->path);
     m->in_memory = MAP_SAVING;
 
-    /* Compress if it isn't a temporary save.  Do compress if unique */
-    if (m->compressed && (m->unique || m->is_template || flag != SAVE_MODE_NORMAL)) {
-        char buf[MAX_BUF];
-        snprintf(buf, sizeof(buf), "%s > %s%s", uncomp[m->compressed][2], filename, TEMP_EXT);
-        snprintf(final, sizeof(final), "%s", filename);
-        fp = popen(buf, "w");
-    } else {
-        snprintf(final, sizeof(final), "%s", filename);
-        snprintf(filename, sizeof(filename), "%s%s", final, TEMP_EXT);
-        fp = fopen(filename, "w");
-    }
+    snprintf(final, sizeof(final), "%s", filename);
+    snprintf(filename, sizeof(filename), "%s%s", final, TEMP_EXT);
+    fp = fopen(filename, "w");
 
     if (fp == NULL) {
         LOG(llevError, "Cannot open regular objects file %s: %s\n", filename, strerror_local(errno, buf, sizeof(buf)));
@@ -1567,11 +1513,7 @@ int save_map(mapstruct *m, int flag) {
         snprintf(buf, sizeof(buf), "%s%s", final_unique, TEMP_EXT);
         if ((fp2 = fopen(buf, "w")) == NULL) {
             LOG(llevError, "Can't open unique items file %s\n", buf);
-            if (m->compressed && (m->unique || m->is_template || flag != SAVE_MODE_NORMAL)) {
-                pclose(fp);
-            } else {
-                fclose(fp);
-            }
+            fclose(fp);
             return SAVE_ERROR_UCREATION;
         }
         if (flag == SAVE_MODE_OVERLAY) {
@@ -1579,11 +1521,7 @@ int save_map(mapstruct *m, int flag) {
             res = save_objects(m, fp, fp2, SAVE_FLAG_NO_REMOVE);
             if (res < 0) {
                 LOG(llevError, "Save error during object save: %d\n", res);
-                if (m->compressed && (m->unique || m->is_template || flag != SAVE_MODE_NORMAL)) {
-                    pclose(fp);
-                } else {
-                    fclose(fp);
-                }
+                fclose(fp);
                 fclose(fp2);
                 return res;
             }
@@ -1592,11 +1530,7 @@ int save_map(mapstruct *m, int flag) {
             res = save_objects(m, fp, fp2, 0);
             if (res < 0) {
                 LOG(llevError, "Save error during object save: %d\n", res);
-                if (m->compressed && (m->unique || m->is_template || flag != SAVE_MODE_NORMAL)) {
-                    pclose(fp);
-                } else {
-                    fclose(fp);
-                }
+                fclose(fp);
                 fclose(fp2);
                 return res;
             }
@@ -1616,11 +1550,7 @@ int save_map(mapstruct *m, int flag) {
             unlink(final_unique); /* failure isn't too bad, maybe the file doesn't exist. */
             if (rename(buf, final_unique) == -1) {
                 LOG(llevError, "Couldn't rename unique file %s to %s\n", buf, final_unique);
-                if (m->compressed && (m->unique || m->is_template || flag != SAVE_MODE_NORMAL)) {
-                    pclose(fp);
-                } else {
-                    fclose(fp);
-                }
+                fclose(fp);
                 return SAVE_ERROR_URENAME;
             }
             chmod(final_unique, SAVE_MODE);
@@ -1629,28 +1559,16 @@ int save_map(mapstruct *m, int flag) {
         res = save_objects(m, fp, fp, 0);
         if (res < 0) {
             LOG(llevError, "Save error during object save: %d\n", res);
-            if (m->compressed && (m->unique || m->is_template || flag != SAVE_MODE_NORMAL)) {
-                pclose(fp);
-            } else {
-                fclose(fp);
-            }
+            fclose(fp);
             return res;
         }
         free_all_objects(m);
     }
 
-    if (m->compressed && (m->unique || m->is_template || flag != SAVE_MODE_NORMAL)) {
-        fflush(fp);
-        if (pclose(fp) == -1) {
-            LOG(llevError, "pclose error!\n");
-            return SAVE_ERROR_CLOSE;
-        }
-    } else {
-        fflush(fp);
-        if (fclose(fp) != 0) {
-            LOG(llevError, "fclose error!\n");
-            return SAVE_ERROR_CLOSE;
-        }
+    fflush(fp);
+    if (fclose(fp) != 0) {
+        LOG(llevError, "fclose error!\n");
+        return SAVE_ERROR_CLOSE;
     }
     unlink(final); /* failure isn't too bad, maybe the file doesn't exist. */
     if (rename(filename, final) == -1) {
@@ -1885,8 +1803,6 @@ mapstruct *ready_map_name(const char *name, int flags) {
         if (!(m = load_original_map(name, (flags&MAP_PLAYER_UNIQUE))))
             return (NULL);
 
-        apply_auto_fix(m); /* Chests which open as default */
-
         /* If a player unique map, no extra unique object file to load.
          * if from the editor, likewise.
          */
@@ -1894,16 +1810,30 @@ mapstruct *ready_map_name(const char *name, int flags) {
             load_unique_objects(m);
 
         if (!(flags&(MAP_FLUSH|MAP_PLAYER_UNIQUE|MAP_OVERLAY))) {
-            m = load_overlay_map(name, m);
-            if (m == NULL)
-                return NULL;
+            if (load_overlay_map(name, m) != 0) {
+                delete_map(m);
+                m = load_original_map(name, 0);
+                if (m == NULL) {
+                    /* Really, this map is bad :( */
+                    return NULL;
+                }
+            }
         }
     } else {
         /* If in this loop, we found a temporary map, so load it up. */
 
-        m = load_temporary_map(m);
-        if (m == NULL)
-            return NULL;
+        if (load_temporary_map(m) != 0) {
+            /*
+             * There was a failure loading the temporary map, fall back to original one.
+             * load_temporary_map() already logged the error.
+             */
+            delete_map(m);
+            m = load_original_map(name, 0);
+            if (m == NULL) {
+                /* Really, this map is bad :( */
+                return NULL;
+            }
+        }
         load_unique_objects(m);
 
         clean_tmp_map(m);
@@ -2243,7 +2173,7 @@ void update_position(mapstruct *m, int x, int y) {
      */
     if (((oldflags&~(P_NEED_UPDATE|P_NO_ERROR)) != flags)
     && (!(oldflags&P_NO_ERROR))) {
-        LOG(llevDebug, "update_position: updated flags do not match old flags: %s (old=%d,new=%d) %x != %x\n",
+        LOG(llevDebug, "update_position: updated flags do not match old flags: %s (x=%d,y=%d) %x != %x\n",
             m->path, x, y, (oldflags&~P_NEED_UPDATE), flags);
     }
 
