@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_porting_c =
- *   "$Id: porting.c 14250 2011-01-25 22:26:24Z ryo_saeba $";
+ *   "$Id: porting.c 15042 2011-09-04 09:09:08Z ryo_saeba $";
  */
 
 /*
@@ -138,7 +138,7 @@ char *tempnam_local(const char *dir, const char *pfx) {
  * The file will be opened read-write.
  *
  * @todo
- * Maybe adding some #ifdef for non-UNIX? I don't have any such system around
+ * Maybe adding some ifdef for non-UNIX? I don't have any such system around
  * to test with.
  */
 FILE *tempnam_secure(const char *dir, const char *pfx, char **filename) {
@@ -584,179 +584,6 @@ int isqrt(int n) {
     return result;
 }
 
-/**
- * This is a list of the suffix, uncompress and compress functions.  Thus,
- * if you have some other compress program you want to use, the only thing
- * that needs to be done is to extended this.
- * The first entry must be NULL - this is what is used for non
- * compressed files.
- */
-const char *uncomp[NROF_COMPRESS_METHODS][3] = {
-    { NULL, NULL, NULL },
-    { ".Z", UNCOMPRESS, COMPRESS },
-    { ".gz", GUNZIP, GZIP },
-    { ".bz2", BUNZIP, BZIP }
-};
-
-/**
- * Open and possibly uncompress a file.
- *
- * @param ext
- * the extension if the file is compressed.
- * @param uncompressor
- * the command to uncompress the file if the file is compressed.
- * @param name
- * the base file name without compression extension
- * @param flag
- * only used for compressed files:
- * @li if set, uncompress and open the file
- * @li if unset, uncompress the file via pipe
- * @param[out] compressed
- * set to zero if the file was uncompressed
- * @param mode
- * the mode to pass to fopen
- * @return
- * pointer to opened file, NULL on failure.
- *
- * @note
- * will set ::errno if an error occurs.
- */
-static FILE *open_and_uncompress_file(const char *ext, const char *uncompressor, const char *name, int flag, int *compressed, const char *mode) {
-    struct stat st;
-    char buf[MAX_BUF];
-    char buf2[MAX_BUF];
-    int ret;
-
-    if (ext == NULL) {
-        ext = "";
-    }
-
-    if (strlen(name)+strlen(ext) >= sizeof(buf)) {
-        errno = ENAMETOOLONG; /* File name too long */
-        return NULL;
-    }
-    snprintf(buf, sizeof(buf), "%s%s", name, ext);
-
-    if (stat(buf, &st) != 0) {
-        return NULL;
-    }
-
-    if (!S_ISREG(st.st_mode)) {
-        errno = EISDIR;         /* Not a regular file */
-        return NULL;
-    }
-
-    if (uncompressor == NULL) {
-        /* open without uncompression */
-        return fopen(buf, mode);
-    }
-
-    /* The file name buf (and its substring name) is passed as an argument to a
-     * shell command, therefore check for characters that could confuse the
-     * shell.
-     */
-    if (strpbrk(buf, "'\\\r\n") != NULL) {
-        errno = ENOENT;         /* Pretend the file does not exist */
-        return NULL;
-    }
-
-    if (!flag) {
-        /* uncompress via pipe */
-
-        if (strlen(uncompressor)+4+strlen(buf)+1 >= sizeof(buf2)) {
-            errno = ENAMETOOLONG;       /* File name too long */
-            return NULL;
-        }
-        snprintf(buf2, sizeof(buf2), "%s < '%s'", uncompressor, buf);
-        return popen(buf2, "r");
-    }
-
-    /* remove compression from file, then open file */
-
-    if (stat(name, &st) == 0 && !S_ISREG(st.st_mode)) {
-        errno = EISDIR;
-        return NULL;
-    }
-
-    if (strlen(uncompressor)+4+strlen(buf)+5+strlen(name)+1 >= sizeof(buf2)) {
-        errno = ENAMETOOLONG;   /* File name too long */
-        return NULL;
-    }
-    snprintf(buf2, sizeof(buf2), "%s < '%s' > '%s'", uncompressor, buf, name);
-
-    ret = system(buf2);
-    if (!WIFEXITED(ret) || WEXITSTATUS(ret) != 0) {
-        LOG(llevError, "system(%s) returned %d\n", buf2, ret);
-        errno = ENOENT;
-        return NULL;
-    }
-
-    unlink(buf);                /* Delete the original */
-    *compressed = 0;            /* Change to "uncompressed file" */
-    chmod(name, st.st_mode);    /* Copy access mode from compressed file */
-
-    return fopen(name, mode);
-}
-
-/**
- * open_and_uncompress() first searches for the original filename. If it exist,
- * then it opens it and returns the file-pointer.
- *
- * If not, it does two things depending on the flag. If the flag is set, it
- * tries to create the original file by appending a compression suffix to name
- * and uncompressing it. If the flag is not set, it creates a pipe that is used
- * for reading the file (NOTE - you can not use fseek on pipes).
- *
- * The compressed pointer is set to nonzero if the file is compressed (and
- * thus, fp is actually a pipe.) It returns 0 if it is a normal file.
- *
- * @param name
- * the base file name without compression extension
- * @param flag
- * only used for compressed files:
- * @li if set, uncompress and open the file
- * @li if unset, uncompress the file via pipe
- * @param[out] compressed
- * set to zero if the file was uncompressed
- * @param mode
- * the mode to pass to fopen
- * @return
- * pointer to opened file, NULL on failure.
- *
- * @note
- * will set ::errno if an error occurs.
- */
-FILE *open_and_uncompress(const char *name, int flag, int *compressed, const char *mode) {
-    size_t i;
-    FILE *fp;
-
-    for (i = 0; i < NROF_COMPRESS_METHODS; i++) {
-        *compressed = i;
-        fp = open_and_uncompress_file(uncomp[i][0], uncomp[i][1], name, flag, compressed, mode);
-        if (fp != NULL) {
-            return fp;
-        }
-    }
-
-    errno = ENOENT;
-    return NULL;
-}
-
-/**
- * Closes specified file.
- *
- * @param fp
- * file to close.
- * @param compressed
- * whether the file was compressed or not. Set by open_and_uncompress().
- */
-void close_and_delete(FILE *fp, int compressed) {
-    if (compressed)
-        pclose(fp);
-    else
-        fclose(fp);
-}
-
 /**
  * Checks if any directories in the given path doesn't exist, and creates if necessary.
  *
