@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_player_c =
- *   "$Id: re-cmp.c 11308 2009-02-01 17:02:56Z anmaster $";
+ *   "$Id: re-cmp.c 13988 2010-10-10 14:35:49Z anmaster $";
  */
 
 /**
@@ -21,13 +21,18 @@
 
 #include <stdio.h>
 #include <stdlib.h>
-#include <memory.h>
+#include <string.h>
 #include <limits.h>
 #include <re-cmp.h>
 #include <ctype.h>
 #include <global.h>
 #include <define.h> /* Needed for OUT_OF_MEMORY. */
 
+/* Unlikely to be needed any more... */
+#ifdef HAVE_MEMORY_H
+#  include <memory.h>
+#endif
+
 /* Get prototype functions to prevent warnings. */
 #if defined(__sun__) && defined(StupidSunHeaders)
 #  include <sys/types.h>
