@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_readable_c =
- *   "$Id: readable.c 13542 2010-08-01 10:22:09Z ryo_saeba $";
+ *   "$Id: readable.c 16408 2012-01-01 13:03:00Z ryo_saeba $";
  */
 
 /*
@@ -124,6 +124,19 @@ typedef struct namebytype {
     int type;          /**< matching type */
 } arttypename;
 
+/**
+ * One general message, from the lib/messages file.
+ */
+struct GeneralMessage {
+    int chance;             /**< Relative chance of the message appearing
+                              randomly. If 0 will never appear. */
+    sstring identifier;     /**< Message identifier, can be NULL. */
+    sstring title;          /**< The message's title, only used for knowledge. */
+    sstring message;        /**< The message's body. */
+    sstring quest_code;     /**< Optional quest code and state this message will start. */
+    GeneralMessage *next;   /**< Next message in the list. */
+};
+
 static void add_book(title *book, int type, const char *fname, int lineno);
 
 /**
@@ -142,16 +155,16 @@ static objectlink *first_mon_info = NULL;
 static int nrofmon = 0, need_to_write_bookarchive = 0;
 
 /**
- * this is needed to keep track of status of initialization
- * of the message file
+ * First message from data read from the messages file.
+ * Note that this points to the last message in the file,
+ * as messages are added to the start of the list.
  */
-static int nrofmsg = 0;
+static GeneralMessage *first_msg = NULL;
 
 /**
- * first_msg is the started of the linked list of messages as read from
- * the messages file
+ * Total chance of messages (GeneralMessage), to randomly select one.
  */
-static linked_char *first_msg = NULL;
+static int msg_total_chance = 0;
 
 /**
  * Spellpath information
@@ -713,7 +726,7 @@ int book_overflow(const char *buf1, const char *buf2, size_t booksize) {
 static void init_msgfile(void) {
     FILE *fp;
     char buf[MAX_BUF], msgbuf[HUGE_BUF], fname[MAX_BUF], *cp;
-    int comp;
+    int text = 0, nrofmsg = 0;
     static int did_init_msgfile = 0;
 
     if (did_init_msgfile)
@@ -723,9 +736,9 @@ static void init_msgfile(void) {
     snprintf(fname, sizeof(fname), "%s/messages", settings.datadir);
     LOG(llevDebug, "Reading messages from %s...\n", fname);
 
-    fp = open_and_uncompress(fname, 0, &comp, "r");
+    fp = fopen(fname, "r");
     if (fp != NULL) {
-        linked_char *tmp = NULL;
+        GeneralMessage *tmp = NULL;
         int lineno;
         int error_lineno;
 
@@ -740,38 +753,69 @@ static void init_msgfile(void) {
                 *cp = '\0';
             }
             if (tmp != NULL) {
-                if (strcmp(buf, "ENDMSG") == 0) {
+                if (text && strcmp(buf, "ENDMSG") == 0) {
                     if (strlen(msgbuf) > BOOK_BUF) {
                         LOG(llevDebug, "Warning: this string exceeded max book buf size:\n");
                         LOG(llevDebug, "  %s\n", msgbuf);
                     }
-                    tmp->name = add_string(msgbuf);
+                    tmp->message = add_string(msgbuf);
                     tmp->next = first_msg;
                     first_msg = tmp;
                     nrofmsg++;
+                    if (tmp->identifier != NULL && tmp->title == NULL) {
+                        LOG(llevError, "Error: message can't have identifier without title, on line %d\n", error_lineno);
+                        fatal(SEE_LAST_ERROR);
+                    }
                     tmp = NULL;
-                } else if (!buf_overflow(msgbuf, buf, HUGE_BUF-1)) {
-                    strcat(msgbuf, buf);
-                    strcat(msgbuf, "\n");
+                    text = 0;
+                } else if (text) {
+                    if (!buf_overflow(msgbuf, buf, HUGE_BUF-1)) {
+                        strcat(msgbuf, buf);
+                        strcat(msgbuf, "\n");
+                    } else if (error_lineno != 0) {
+                        LOG(llevInfo, "Warning: truncating book at %s, line %d\n", fname, error_lineno);
+                    }
+                } else if (strcmp(buf, "TEXT") == 0) {
+                    text = 1;
+                } else if (strncmp(buf, "CHANCE ", 7) == 0) {
+                    tmp->chance = atoi(buf + 7);
+                    msg_total_chance += tmp->chance;
+                } else if (strncmp(buf, "TITLE ", 6) == 0) {
+                    tmp->title = add_string(buf + 6);
+                } else if (strncmp(buf, "QUEST ", 6) == 0) {
+                    tmp->quest_code = add_string(buf + 6);
                 } else if (error_lineno != 0) {
-                    LOG(llevInfo, "Warning: truncating book at %s, line %d\n", fname, error_lineno);
-                    error_lineno = 0;
+                    LOG(llevInfo, "Warning: unknown line %s, line %d\n", buf, error_lineno);
                 }
-            } else if (strcmp(buf, "MSG") == 0) {
+            } else if (strncmp(buf, "MSG", 3) == 0) {
                 error_lineno = lineno;
-                tmp = (linked_char *)malloc(sizeof(linked_char));
+                tmp = (GeneralMessage *)calloc(1, sizeof(GeneralMessage));
                 strcpy(msgbuf, " ");  /* reset msgbuf for new message */
+                if (buf[3] == ' ') {
+                    int i = 4;
+                    while (buf[i] == ' ' && buf[i] != '\0')
+                        i++;
+                    if (buf[i] != '\0') {
+                        tmp->identifier = add_string(buf + i);
+                        if (get_message_from_identifier(buf + i)) {
+                            LOG(llevError, "Duplicated message identifier %s at line %d\n", buf + i, error_lineno);
+                            fatal(SEE_LAST_ERROR);
+                        }
+                    }
+                }
             } else {
                 LOG(llevInfo, "Warning: syntax error at %s, line %d\n", fname, lineno);
             }
         }
-        close_and_delete(fp, comp);
+        fclose(fp);
+
+        if (tmp != NULL) {
+            LOG(llevError, "Invalid file %s", fname);
+            fatal(SEE_LAST_ERROR);
+        }
     }
 
-#ifdef BOOK_MSG_DEBUG
-    LOG(llevDebug, "init_info_listfile() got %d messages.\n", nrofmsg);
-#endif
-    LOG(llevDebug, "done messages.\n");
+    LOG(llevDebug, "done messages, found %d for total chance %d.\n", nrofmsg, msg_total_chance);
 }
 
 /**
@@ -782,7 +826,7 @@ static void init_msgfile(void) {
  */
 static void init_book_archive(void) {
     FILE *fp;
-    int comp, nroftitle = 0;
+    int nroftitle = 0;
     char buf[MAX_BUF], fname[MAX_BUF], *cp;
     static int did_init_barch = 0;
 
@@ -796,7 +840,7 @@ static void init_book_archive(void) {
     snprintf(fname, sizeof(fname), "%s/bookarch", settings.localdir);
     LOG(llevDebug, " Reading bookarch from %s...\n", fname);
 
-    fp = open_and_uncompress(fname, 0, &comp, "r");
+    fp = fopen(fname, "r");
     if (fp != NULL) {
         int type;
         size_t i;
@@ -882,7 +926,7 @@ static void init_book_archive(void) {
         for (bl = booklist, i = 0; bl != NULL && i < arraysize(max_titles); bl = bl->next, i++) {
             LOG(llevDebug, "(%d/%d)\n", bl->number, max_titles[i]);
         }
-        close_and_delete(fp, comp);
+        fclose(fp);
     }
 
 #ifdef BOOK_MSG_DEBUG
@@ -1204,9 +1248,13 @@ static void change_book(object *book, int msgtype) {
 
     if (strlen(book->msg) > 5 && (t = find_title(book, msgtype))) {
         object *tmpbook;
+        sstring marker = object_get_value(book, "knowledge_marker");
 
         /* alter book properties */
         tmpbook = create_archetype(t->archname);
+        if (marker != NULL)
+            /* need to copy the knowledge_marker */
+            object_set_value(tmpbook, "knowledge_marker", marker, 1);
         object_set_msg(tmpbook, book->msg);
         object_copy(tmpbook, book);
         object_free_drop_inventory(tmpbook);
@@ -1370,19 +1418,14 @@ object *get_random_mon(int level) {
  *
  * @param mon
  * monster to describe.
- * @param buf
- * buffer that will contain the description.
- * @param size
- * buf's length.
  * @return
- * buf
+ * new StringBuffer containing the description.
  */
-static char *mon_desc(const object *mon, char *buf, size_t size) {
-    char *desc;
-    desc = stringbuffer_finish(describe_item(mon, NULL, NULL));
-    snprintf(buf, size, " *** %s ***\n%s", mon->name, desc);
-    free(desc);
-    return buf;
+static StringBuffer *mon_desc(const object *mon) {
+    StringBuffer *desc = stringbuffer_new();
+    stringbuffer_append_printf(desc, "\n---\n *** %s ***\n", mon->name);
+    describe_item(mon, NULL, desc);
+    return desc;
 }
 
 /**
@@ -1417,24 +1460,21 @@ static object *get_next_mon(const object *tmp) {
  *
  * @param level
  * book level.
- * @param buf
- * buffer that will contain the message. Must be at least of length booksize
  * @param booksize
  * size (in characters) of the book we want.
  * @param book
  * book in which we will put the information.
  * @return
- * buf.
+ * StringBuffer containing the information.
  */
-static char *mon_info_msg(int level, char *buf, size_t booksize, object *book) {
-    char tmpbuf[HUGE_BUF], desc[MAX_BUF];
+static StringBuffer *mon_info_msg(int level, size_t booksize, object *book) {
     object *tmp;
-    StringBuffer *marker = stringbuffer_new();
+    StringBuffer *marker = stringbuffer_new(), *desc = stringbuffer_new(), *mon = NULL;
     int added = 0;
     sstring final;
 
     /*preamble */
-    snprintf(buf, booksize, "This beastiary contains:");
+    stringbuffer_append_string(desc, "This beastiary contains:");
     stringbuffer_append_string(marker, "monster");
 
     /* lets print info on as many monsters as will fit in our
@@ -1446,54 +1486,141 @@ static char *mon_info_msg(int level, char *buf, size_t booksize, object *book) {
      */
     for (tmp = get_random_mon(level*3); tmp; tmp = get_next_mon(tmp)) {
         /* monster description */
-        snprintf(tmpbuf, sizeof(tmpbuf), "\n---\n%s", mon_desc(tmp, desc, sizeof(desc)));
+        mon = mon_desc(tmp);
 
-        if (book_overflow(buf, tmpbuf, booksize))
+        if (stringbuffer_length(desc) + stringbuffer_length(mon) >= booksize)
             break;
         added++;
         stringbuffer_append_printf(marker, ":%s", tmp->arch->name);
-        snprintf(buf+strlen(buf), booksize-strlen(buf), "%s", tmpbuf);
+        stringbuffer_append_stringbuffer(desc, mon);
+        stringbuffer_delete(mon);
     }
 
-#ifdef BOOK_MSG_DEBUG
-    LOG(llevDebug, "\n mon_info_msg() created strng: %d\n", strlen(retbuf));
-    fprintf(logfile, " MADE THIS:\n%s\n", retbuf);
-#endif
+    if (mon != NULL)
+        stringbuffer_delete(mon);
 
     final = stringbuffer_finish_shared(marker);
     if (added)
         object_set_value(book, "knowledge_marker", final, 1);
     free_string(final);
 
-    return buf;
+    return desc;
 }
 
 /*****************************************************************************
  * Artifact msg generation code.
  ****************************************************************************/
 
+/**
+ * Describe an artifact.
+ * @param art artifact to describe.
+ * @param al list art is part of.
+ * @param message if non zero, and the artifact has a suitable message, add it to the description.
+ * @param art_name index in ::art_name_array the artifact is in.
+ * @param separator if non zero, a separator is inserted at the start of the description.
+ * @return newly allocated StringBuffer* containing the description.
+ */
+static StringBuffer *artifact_describe(const artifact *art, const artifactlist *al, int message, int art_name, int separator) {
+    object *tmp;
+    int chance;
+    StringBuffer *desc = stringbuffer_new(), *sbuf;
+
+    if (separator)
+        stringbuffer_append_string(desc, "---\n");
+
+    /* Name */
+    if (art->allowed != NULL) {
+        archetype *arch;
+        linked_char *temp = art->allowed;
+        int inv = 0, w;
+
+        assert(art->allowed_size > 0);
+        if (art->allowed_size > 1)
+            w = 1 + RANDOM() % art->allowed_size;
+        else
+            w = 1;
+
+        while (w > 1) {
+            assert(temp);
+            temp = temp->next;
+            w--;
+        }
+
+        if (temp->name[0] == '!')
+            inv = 1;
+
+        /** @todo check archetype when loading archetypes, not here */
+        arch = try_find_archetype(temp->name + inv);
+        if (!arch)
+            arch = find_archetype_by_object_name(temp->name + inv);
+
+        if (!arch)
+            LOG(llevError, "artifact_msg: missing archetype %s for artifact %s (type %d)\n", temp->name + inv, art->item->name, art->item->type);
+        else {
+            if (inv)
+                stringbuffer_append_printf(desc, " A %s (excepted %s) of %s", art_name_array[art_name].name, arch->clone.name_pl, art->item->name);
+            else
+                stringbuffer_append_printf(desc, " A %s of %s", arch->clone.name, art->item->name);
+        }
+    } else {  /* default name is used */
+        /* use the base 'generic' name for our artifact */
+        stringbuffer_append_printf(desc, " The %s of %s", art_name_array[art_name].name, art->item->name);
+    }
+
+    /* chance of finding */
+    stringbuffer_append_string(desc, " is ");
+    chance = 100*((float)art->chance/al->total_chance);
+    if (chance >= 20)
+        stringbuffer_append_string(desc, "an uncommon");
+    else if (chance >= 10)
+        stringbuffer_append_string(desc, "an unusual");
+    else if (chance >= 5)
+        stringbuffer_append_string(desc, "a rare");
+    else
+        stringbuffer_append_string(desc, "a very rare");
+
+    /* value of artifact */
+    stringbuffer_append_printf(desc, " item with a value that is %d times normal.\n", art->item->value);
+
+    /* include the message about the artifact, if exists, and book
+    * level is kinda high */
+    if (message && !(strlen(art->item->msg) > BOOK_BUF))
+        stringbuffer_append_string(desc, art->item->msg);
+
+    /* properties of the artifact */
+    tmp = object_new();
+    add_abilities(tmp, art->item);
+    tmp->type = al->type;
+    SET_FLAG(tmp, FLAG_IDENTIFIED);
+    sbuf = describe_item(tmp, NULL, NULL);
+    if (stringbuffer_length(sbuf) > 1) {
+        stringbuffer_append_string(desc, " Properties of this artifact include:\n ");
+        stringbuffer_append_stringbuffer(desc, sbuf);
+        stringbuffer_append_string(desc, "\n");
+    }
+    free(stringbuffer_finish(sbuf));
+    object_free_drop_inventory(tmp);
+
+    return desc;
+}
+
 /**
  * Generate a message detailing the properties
  * of 1-6 artifacts drawn sequentially from the artifact list.
  *
  * @param level
  * level of the book.
- * @param retbuf
- * buffer to contain the description. Must be at least booksize chars.
  * @param booksize
- * length of the book.
+ * maximum length of the book.
  * @return
- * retbuf.
-@todo make static (again) when check_readable is cleaned of the unit rewrite test.
+ * new StringBuffer containing the dsecription.
  */
-char *artifact_msg(int level, char *retbuf, size_t booksize) {
+static StringBuffer *artifact_msg(int level, size_t booksize) {
     const artifactlist *al;
     const artifact *art;
-    int chance, i, type, index;
+    int i, type, index;
     int book_entries = level > 5 ? RANDOM()%3+RANDOM()%3+2 : RANDOM()%level+1;
-    char buf[BOOK_BUF], *final;
-    object *tmp;
-    StringBuffer *desc, *sbuf;
+    StringBuffer *desc, *message = stringbuffer_new();
 
     /* values greater than 5 create msg buffers that are too big! */
     if (book_entries > 5)
@@ -1513,8 +1640,8 @@ char *artifact_msg(int level, char *retbuf, size_t booksize) {
     } while (al == NULL && i < 10);
 
     if (i == 10) { /* Unable to find a message */
-        snprintf(retbuf, booksize, "None");
-        return retbuf;
+        stringbuffer_append_string(message, "None");
+        return message;
     }
 
     /* There is no reason to start on the artifact list at the beginning. Lets
@@ -1527,112 +1654,33 @@ char *artifact_msg(int level, char *retbuf, size_t booksize) {
     }
 
     /* Ok, lets print out the contents */
-    snprintf(retbuf, booksize, "Herein %s detailed %s...\n", book_entries > 1 ? "are" : "is", book_entries > 1 ? "some artifacts" : "an artifact");
+    stringbuffer_append_printf(message, "Herein %s detailed %s...\n", book_entries > 1 ? "are" : "is", book_entries > 1 ? "some artifacts" : "an artifact");
 
+    i = 0;
     /* artifact msg attributes loop. Lets keep adding entries to the 'book'
      * as long as we have space up to the allowed max # (book_entires)
      */
     while (book_entries > 0) {
+        int with_message;
         if (art == NULL)
             art = al->items;
+        with_message = (art->item->msg && RANDOM()%4+1 < level) ? 1 : 0;
 
-        desc = stringbuffer_new();
-        /* separator of items */
-        stringbuffer_append_string(desc, "---\n");
+        desc = artifact_describe(art, al, with_message, index, i++);
 
-        /* Name */
-        if (art->allowed != NULL) {
-            archetype *arch;
-            linked_char *temp = art->allowed;
-            int inv = 0, w;
-
-            assert(art->allowed_size > 0);
-            if (art->allowed_size > 1)
-                w = 1 + RANDOM() % art->allowed_size;
-            else
-                w = 1;
-
-            while (w > 1) {
-                assert(temp);
-                temp = temp->next;
-                w--;
-            }
-
-            if (temp->name[0] == '!')
-                inv = 1;
-
-            /** @todo check archetype when loading archetypes, not here */
-            arch = try_find_archetype(temp->name + inv);
-            if (!arch)
-                arch = find_archetype_by_object_name(temp->name + inv);
-
-            if (!arch)
-                LOG(llevError, "artifact_msg: missing archetype %s for artifact %s (type %d)\n", temp->name + inv, art->item->name, art->item->type);
-            else {
-                if (inv)
-                    stringbuffer_append_printf(desc, " A %s (excepted %s) of %s", art_name_array[index].name, arch->clone.name_pl, art->item->name);
-                else
-                    stringbuffer_append_printf(desc, " A %s of %s", arch->clone.name, art->item->name);
-            }
-        } else {  /* default name is used */
-            /* use the base 'generic' name for our artifact */
-            stringbuffer_append_printf(desc, " The %s of %s", art_name_array[index].name, art->item->name);
-        }
-
-        /* chance of finding */
-        stringbuffer_append_string(desc, " is ");
-        chance = 100*((float)art->chance/al->total_chance);
-        if (chance >= 20)
-            stringbuffer_append_string(desc, "an uncommon");
-        else if (chance >= 10)
-            stringbuffer_append_string(desc, "an unusual");
-        else if (chance >= 5)
-            stringbuffer_append_string(desc, "a rare");
-        else
-            stringbuffer_append_string(desc, "a very rare");
-
-        /* value of artifact */
-        stringbuffer_append_printf(desc, " item with a value that is %d times normal.\n", art->item->value);
-
-        /* include the message about the artifact, if exists, and book
-        * level is kinda high */
-        if (art->item->msg && RANDOM()%4+1 < level
-        && !(strlen(art->item->msg)+strlen(buf) > BOOK_BUF))
-            stringbuffer_append_string(desc, art->item->msg);
-
-        /* properties of the artifact */
-        tmp = object_new();
-        add_abilities(tmp, art->item);
-        tmp->type = type;
-        SET_FLAG(tmp, FLAG_IDENTIFIED);
-        sbuf = describe_item(tmp, NULL, NULL);
-        if (stringbuffer_length(sbuf) > 1) {
-            stringbuffer_append_string(desc, " Properties of this artifact include:\n ");
-            stringbuffer_append_stringbuffer(desc, sbuf);
-            stringbuffer_append_string(desc, "\n");
-        }
-        free(stringbuffer_finish(sbuf));
-        object_free_drop_inventory(tmp);
-
-        final = stringbuffer_finish(desc);
-
-        /* add the buf if it will fit */
-        if (book_overflow(retbuf, final, booksize)) {
-            free(final);
+        if (stringbuffer_length(message) + stringbuffer_length(desc) >= booksize) {
+            stringbuffer_delete(desc);
             break;
         }
-        snprintf(retbuf+strlen(retbuf), booksize-strlen(retbuf), "%s", final);
-        free(final);
+
+        stringbuffer_append_stringbuffer(message, desc);
+        stringbuffer_delete(desc);
 
         art = art->next;
         book_entries--;
     }
 
-#ifdef BOOK_MSG_DEBUG
-    LOG(llevDebug, "artifact_msg() created strng: %d\n", strlen(retbuf));
-    fprintf(logfile, " MADE THIS:\n%s", retbuf);
-#endif
-    return retbuf;
+    return message;
 }
 
 /*****************************************************************************
@@ -1645,28 +1693,25 @@ char *artifact_msg(int level, char *retbuf, size_t booksize) {
  *
  * @param level
  * level of the book.
- * @param retbuf
- * buffer to write the description into.
  * @param booksize
- * length of the book.
+ * maximumlength of the book.
+ * @param buf
+ * where to store the message. If not NULL, it is supposed to contain the message header.
  * @return
- * retbuf
-@todo make static when check_readable is cleaned.
+ * buf, newly allocated StringBuffer if buf is NULL.
  */
-char *spellpath_msg(int level, char *retbuf, size_t booksize) {
+static StringBuffer *spellpath_msg(int level, size_t booksize, StringBuffer *buf) {
     int path = RANDOM()%NRSPELLPATHS, prayers = RANDOM()%2;
     int did_first_sp = 0;
     uint32 pnum = spellpathdef[path];
     archetype *at;
-    StringBuffer *buf;
-    char *final;
 
-    buf = stringbuffer_new();
-    retbuf[0] = '\0';
-    /* Preamble */
-    stringbuffer_append_printf(buf, "Herein are detailed the names of %s\n", prayers ? "prayers" : "incantations");
-
-    stringbuffer_append_printf(buf, "belonging to the path of %s:\n", spellpathnames[path]);
+    if (buf == NULL) {
+        buf = stringbuffer_new();
+        /* Preamble */
+        stringbuffer_append_printf(buf, "Herein are detailed the names of %s", prayers ? "prayers" : "incantations");
+        stringbuffer_append_printf(buf, " belonging to the path of %s:\n ", spellpathnames[path]);
+    }
 
     for (at = first_archetype; at != NULL; at = at->next) {
         /* Determine if this is an appropriate spell.  Must
@@ -1681,27 +1726,21 @@ char *spellpath_msg(int level, char *retbuf, size_t booksize) {
                 break;
 
             if (did_first_sp)
-                stringbuffer_append_string(buf, ",\n");
+                stringbuffer_append_string(buf, ",\n ");
             did_first_sp = 1;
             stringbuffer_append_string(buf,at->clone.name);
         }
     }
 
-    final = stringbuffer_finish(buf);
     /* Geez, no spells were generated. */
     if (!did_first_sp) {
         if (RANDOM()%4) {  /* usually, lets make a recursive call... */
-            free(final);
-            return spellpath_msg(level, retbuf, booksize);
+            return spellpath_msg(level, booksize, buf);
         }
         /* give up, cause knowing no spells exist for path is info too. need the header too. */
-        snprintf(retbuf+strlen(retbuf), booksize-strlen(retbuf), "%s\n - no known spells exist -\n", final);
-        free(final);
-    } else {
-        snprintf(retbuf+strlen(retbuf), booksize-strlen(retbuf), "%s\n", final);
-        free(final);
+        stringbuffer_append_string(buf, "- no known spells exist -\n");
     }
-    return retbuf;
+    return buf;
 }
 
 /**
@@ -1713,12 +1752,13 @@ char *spellpath_msg(int level, char *retbuf, size_t booksize) {
  * level for formulaes and such.
  */
 static void make_formula_book(object *book, int level) {
-    char retbuf[BOOK_BUF], title[MAX_BUF];
     recipelist *fl;
     recipe *formula;
     int chance, count = 0;
     const char *op_name;
     archetype *at;
+    StringBuffer *text, *title;
+    char *final, km[MAX_BUF];
 
     /* the higher the book level, the more complex (ie number of
      * ingredients) the formula can be.
@@ -1753,9 +1793,6 @@ static void make_formula_book(object *book, int level) {
      * of information on the booklevel and the spellevel
      * of the formula. */
 
-    /* preamble */
-    snprintf(retbuf, sizeof(retbuf), "Herein is described a project using %s:\n", formula->skill ? formula->skill : "an unknown skill");
-
     op_name = formula->arch_name[RANDOM()%formula->arch_names];
     at = find_archetype(op_name);
     if (at == (archetype *)NULL) {
@@ -1767,27 +1804,33 @@ static void make_formula_book(object *book, int level) {
     }
     op_name = at->clone.name;
 
+    text = stringbuffer_new();
+    title = stringbuffer_new();
+
+    /* preamble */
+    stringbuffer_append_printf(text, "Herein is described a project using %s:\n", formula->skill ? formula->skill : "an unknown skill");
+
     /* item name */
     if (strcmp(formula->title, "NONE")) {
-        snprintf(retbuf+strlen(retbuf), sizeof(retbuf)-strlen(retbuf), "The %s of %s", op_name, formula->title);
+        stringbuffer_append_printf(text, "The %s of %s", op_name, formula->title);
         /* This results in things like pile of philo. sulfur.
         * while philo. sulfur may look better, without this,
         * you get things like 'the wise' because its missing the
         * water of section.
         */
-        snprintf(title, sizeof(title), "%s: %s of %s", formula_book_name[RANDOM()%arraysize(formula_book_name)], op_name, formula->title);
+        stringbuffer_append_printf(title, "%s: %s of %s", formula_book_name[RANDOM()%arraysize(formula_book_name)], op_name, formula->title);
     } else {
-        snprintf(retbuf+strlen(retbuf), sizeof(retbuf)-strlen(retbuf), "The %s", op_name);
-        snprintf(title, sizeof(title), "%s: %s", formula_book_name[RANDOM()%arraysize(formula_book_name)], op_name);
+        stringbuffer_append_printf(text, "The %s", op_name);
+        stringbuffer_append_printf(title, formula_book_name[RANDOM()%arraysize(formula_book_name)], op_name);
         if (at->clone.title) {
-            snprintf(retbuf+strlen(retbuf), sizeof(retbuf)-strlen(retbuf), " %s", at->clone.title);
-            snprintf(title+strlen(title), sizeof(title)-strlen(title), " %s", at->clone.title);
+            stringbuffer_append_printf(text, " %s", at->clone.title);
+            stringbuffer_append_printf(title, " %s", at->clone.title);
         }
     }
     /* Lets name the book something meaningful ! */
     if (book->name)
         free_string(book->name);
-    book->name = add_string(title);
+    book->name = stringbuffer_finish_shared(title);
     if (book->title) {
         free_string(book->title);
         book->title = NULL;
@@ -1805,58 +1848,74 @@ static void make_formula_book(object *book, int level) {
         else
             snprintf(name, sizeof(name), "an unknown place");
 
-        snprintf(retbuf+strlen(retbuf), sizeof(retbuf)-strlen(retbuf),
-            " may be made at %s using the following ingredients:\n", name);
+        stringbuffer_append_printf(text, " may be made at %s using the following ingredients:\n", name);
 
         for (next = formula->ingred; next != NULL; next = next->next) {
             count++;
-            snprintf(retbuf+strlen(retbuf), sizeof(retbuf)-strlen(retbuf), "%s\n", next->name);
+            stringbuffer_append_printf(text, "%s\n", next->name);
         }
-    } else
+    } else {
         LOG(llevError, "formula_msg() no ingredient list for object %s of %s\n", op_name, formula->title);
-    if (retbuf[strlen(retbuf)-1] != '\n')
-        snprintf(retbuf+strlen(retbuf), sizeof(retbuf)-strlen(retbuf), "\n");
-    object_set_msg(book, retbuf);
+        stringbuffer_append_string(text, "\n");
+    }
+
+    final = stringbuffer_finish(text);
+    object_set_msg(book, final);
+    free(final);
+
     /** knowledge marker */
     /** @todo this would be better in knowledge.c, except this file is in server, not common... */
-    snprintf(retbuf, sizeof(retbuf), "alchemy:%d:%d:%s", count, formula->index, formula->title);
-    object_set_value(book, "knowledge_marker", retbuf, 1);
+    snprintf(km, sizeof(km), "alchemy:%d:%d:%s", count, formula->index, formula->title);
+    object_set_value(book, "knowledge_marker", km, 1);
 }
 
 /**
- * Generate a message drawn randomly from a
- * file in lib/. Level currently has no effect on the message
- * which is returned.
+ * Generate a message drawn randomly from lib/messages.
  *
- * @param level
- * (ignored)
+ * @param book
+ * book to fill.
  * @param booksize
  * length of the book we want.
+ * @return
+ * message to put into book, newly allocated StringBuffer the caller should free.
  */
-static char *msgfile_msg(int level, size_t booksize) {
-    static char retbuf[BOOK_BUF];
-    int i, msgnum;
-    linked_char *msg = NULL;
+static StringBuffer *msgfile_msg(object *book, size_t booksize) {
+    int weight;
+    GeneralMessage *msg = NULL;
+    StringBuffer *ret = stringbuffer_new();
 
     /* get a random message for the 'book' from linked list */
-    if (nrofmsg > 1) {
+    if (msg_total_chance > 0) {
+        assert(first_msg != NULL);
         msg = first_msg;
-        msgnum = RANDOM()%nrofmsg;
-        for (i = 0; msg && i < nrofmsg && i != msgnum; i++)
+        weight = (RANDOM() % msg_total_chance) - msg->chance;
+        while (weight > 0 && msg) {
+            weight -= msg->chance;
             msg = msg->next;
+        }
+        /* if msg is NULL, then something is really wrong in the computation! */
+        assert(msg != NULL);
     }
 
-    if (msg && !book_overflow(retbuf, msg->name, booksize))
-        snprintf(retbuf, sizeof(retbuf), "%s", msg->name);
-    else
-        snprintf(retbuf, sizeof(retbuf), "\n <undecipherable text>");
+    if (msg && strlen(msg->message) <= booksize) {
+        stringbuffer_append_string(ret, msg->message);
+        if (msg->identifier != NULL) {
+            char km[HUGE_BUF];
+            /** knowledge marker */
+            /** @todo this would be better in knowledge.c, except this file is in server, not common... */
+            snprintf(km, sizeof(km), "message:%s", msg->identifier);
+            object_set_value(book, "knowledge_marker", km, 1);
+        }
+        if (msg->quest_code) {
+            /* add a 'apply' hook to launch the quest */
+            object *event = object_create_arch(find_archetype("quest_advance_apply"));
+            FREE_AND_COPY(event->name, msg->quest_code);
+            object_insert_in_ob(event, book);
+        }
+    } else
+        stringbuffer_append_string(ret, "\n <undecipherable text>");
 
-#ifdef BOOK_MSG_DEBUG
-    LOG(llevDebug, "\n info_list_msg() created strng: %d\n", strlen(retbuf));
-    LOG(llevDebug, " MADE THIS:\n%s\n", retbuf);
-#endif
-
-    return retbuf;
+    return ret;
 }
 
 /**
@@ -1865,22 +1924,21 @@ static char *msgfile_msg(int level, size_t booksize) {
  *
  * @param level
  * number of elements to give.
- * @param retbuf
- * buffer that will contain the description. Must be at least length chars.
  * @param booksize
  * desired length of the book.
  * @param book
  * book we're writing the information to, for knowledge management.
+ * @return
+ * StringBuffer with the information that the caller is responsible for cleaning,
+ * NULL if information overflows the booksize.
  */
-static void god_info_msg(int level, char *retbuf, size_t booksize, object *book) {
-    char buf[BOOK_BUF], *final;
+static StringBuffer *god_info_msg(int level, size_t booksize, object *book) {
     int what = 0;
-    size_t retlen;
     const object *god = pntr_to_god_obj(get_rand_god());
     StringBuffer *desc = NULL;
 
-    retbuf[0] = '\0';
-    retlen = 0;
+    if (!god)
+        return NULL; /* oops, problems... */
 
     if (booksize > BOOK_BUF) {
         LOG(llevError, "common/readable.c:god_info_msg() - passed in booksize (%lu) is larger than book buffer (%d)\n", (unsigned long)booksize, BOOK_BUF);
@@ -1909,24 +1967,21 @@ static void god_info_msg(int level, char *retbuf, size_t booksize, object *book)
         what |= GOD_PATHS;
     }
 
-    if (!god)
-        return; /* oops, problems... */
-
     desc = stringbuffer_new();
     what = describe_god(god, what, desc, booksize);
 
     /* check to be sure new buffer size dont exceed either
     * the maximum buffer size, or the 'natural' size of the
-    * book...
-            */
-    final = stringbuffer_finish(desc);
-    if (!book_overflow(retbuf, final, booksize) && strlen(final) > 1) {
-        safe_strcat(retbuf, final, &retlen, BOOK_BUF);
+    * book... */
+    if (stringbuffer_length(desc) > 1 && stringbuffer_length(desc) <= booksize) {
+        char buf[BOOK_BUF];
         snprintf(buf, sizeof(buf), "god:%s:%d", god->name, what);
         object_set_value(book, "knowledge_marker", buf, 1);
+        return desc;
     }
 
-    free(final);
+    stringbuffer_delete(desc);
+    return NULL;
 }
 
 /**
@@ -1948,9 +2003,9 @@ static void god_info_msg(int level, char *retbuf, size_t booksize, object *book)
  * message type - otherwise a random value is used.
  */
 void tailor_readable_ob(object *book, int msg_type) {
-    char msgbuf[BOOK_BUF];
     int level = book->level ? RANDOM()%book->level+1 : 1;
     size_t book_buf_size;
+    StringBuffer *message = NULL;
 
     /* safety */
     if (book->type != BOOK)
@@ -1962,6 +2017,7 @@ void tailor_readable_ob(object *book, int msg_type) {
     /* Max text length this book can have. */
     book_buf_size = BOOKSIZE(book);
     book_buf_size -= strlen("\n"); /* Keep enough for final \n. */
+    assert(book_buf_size < BOOK_BUF);
 
     /* &&& The message switch &&& */
     /* Below all of the possible types of messages in the "book"s.
@@ -1978,15 +2034,15 @@ void tailor_readable_ob(object *book, int msg_type) {
     msg_type = msg_type > 0 ? msg_type : RANDOM()%6;
     switch (msg_type) {
     case MSGTYPE_MONSTER:
-        mon_info_msg(level, msgbuf, book_buf_size, book);
+        message = mon_info_msg(level, book_buf_size, book);
         break;
 
     case MSGTYPE_ARTIFACT:
-        artifact_msg(level, msgbuf, book_buf_size);
+        message = artifact_msg(level, book_buf_size);
         break;
 
     case MSGTYPE_SPELLPATH: /* grouping incantations/prayers by path */
-        spellpath_msg(level, msgbuf, book_buf_size);
+        message = spellpath_msg(level, book_buf_size, NULL);
         break;
 
     case MSGTYPE_ALCHEMY: /* describe an alchemy formula */
@@ -1996,18 +2052,21 @@ void tailor_readable_ob(object *book, int msg_type) {
         break;
 
     case MSGTYPE_GODS: /* bits of information about a god */
-        god_info_msg(level, msgbuf, book_buf_size, book);
+        message = god_info_msg(level, book_buf_size, book);
         break;
 
     case MSGTYPE_LIB: /* use info list in lib/ */
     default:
-        strcpy(msgbuf, msgfile_msg(level, book_buf_size));
+        message = msgfile_msg(book, book_buf_size);
         break;
     }
 
-    strcat(msgbuf, "\n");  /* safety -- we get ugly map saves/crashes w/o this */
-    if (strlen(msgbuf) > strlen("\n")) {
-        object_set_msg(book, msgbuf);
+    if (message != NULL) {
+        char *final;
+        stringbuffer_append_string(message, "\n");
+        final = stringbuffer_finish(message);
+        object_set_msg(book, final);
+        free(final);
         /* lets give the "book" a new name, which may be a compound word */
         change_book(book, msg_type);
     }
@@ -2022,7 +2081,7 @@ void tailor_readable_ob(object *book, int msg_type) {
 void free_all_readable(void) {
     titlelist *tlist, *tnext;
     title *title1, *titlenext;
-    linked_char *lmsg, *nextmsg;
+    GeneralMessage *lmsg, *nextmsg;
     objectlink *monlink, *nextmon;
 
     LOG(llevDebug, "freeing all book information\n");
@@ -2043,8 +2102,14 @@ void free_all_readable(void) {
     }
     for (lmsg = first_msg; lmsg; lmsg = nextmsg) {
         nextmsg = lmsg->next;
-        if (lmsg->name)
-            free_string(lmsg->name);
+        if (lmsg->identifier)
+            free_string(lmsg->identifier);
+        if (lmsg->title)
+            free_string(lmsg->title);
+        if (lmsg->message)
+            free_string(lmsg->message);
+        if (lmsg->quest_code)
+            free_string(lmsg->quest_code);
         free(lmsg);
     }
     for (monlink = first_mon_info; monlink; monlink = nextmon) {
@@ -2123,3 +2188,34 @@ const readable_message_type *get_readable_message_type(object *readable) {
         return &readable_message_types[0];
     return &readable_message_types[subtype];
 }
+
+/**
+ * Find the message from its identifier.
+ * @param identifier message's identifier.
+ * @return corresponding message, NULL if no such message.
+ */
+const GeneralMessage *get_message_from_identifier(const char *identifier) {
+    GeneralMessage *msg = first_msg;
+    while (msg && ((msg->identifier == 0) || (strcmp(msg->identifier, identifier) != 0)))
+        msg = msg->next;
+
+    return msg;
+}
+
+/**
+ * Get a message's title.
+ * @param message message, must not be NULL.
+ * @return title.
+ */
+sstring get_message_title(const GeneralMessage *message) {
+    return message->title;
+}
+
+/**
+ * Get a message's body.
+ * @param message message, must not be NULL.
+ * @return body.
+ */
+sstring get_message_body(const GeneralMessage *message) {
+    return message->message;
+}
