@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_map_c =
- *   "$Id: region.c 12597 2010-03-07 20:37:38Z akirschbaum $";
+ *   "$Id: region.c 14865 2011-07-17 08:40:09Z ryo_saeba $";
  */
 
 /*
@@ -300,14 +300,13 @@ object *get_jail_exit(object *op) {
 void init_regions(void) {
     FILE *fp;
     char filename[MAX_BUF];
-    int comp;
 
     if (first_region != NULL) /* Only do this once */
         return;
 
     snprintf(filename, sizeof(filename), "%s/%s/%s", settings.datadir, settings.mapdir, settings.regions);
     LOG(llevDebug, "Reading regions from %s...\n", filename);
-    if ((fp = open_and_uncompress(filename, 0, &comp, "r")) == NULL) {
+    if ((fp = fopen(filename, "r")) == NULL) {
         LOG(llevError, " Can't open regions file %s in init_regions.\n", filename);
         return;
     }
@@ -315,7 +314,7 @@ void init_regions(void) {
     assign_region_parents();
     LOG(llevDebug, " done\n");
 
-    close_and_delete(fp, comp);
+    fclose(fp);
 }
 
 /**
@@ -518,9 +517,12 @@ static void assign_region_parents(void) {
     uint32 parent_count = 0;
     uint32 region_count = 0;
 
-    for (reg = first_region; reg != NULL && reg->next != NULL; reg = reg->next) {
+    for (reg = first_region; reg != NULL; reg = reg->next) {
         if (reg->parent_name != NULL) {
             reg->parent = get_region_by_name(reg->parent_name);
+            if (reg->parent == NULL) {
+                LOG(llevError, "Couldn't find parent %s for region %s\n", reg->name, reg->parent_name);
+            }
             parent_count++;
         }
         region_count++;
