@@ -1,7 +1,7 @@
 
 /*
  * static char *rcs_treasure_c =
- *   "$Id: treasure.c 13860 2010-09-23 17:42:12Z ryo_saeba $";
+ *   "$Id: treasure.c 15527 2011-11-06 17:43:01Z ryo_saeba $";
  */
 
 /*
@@ -53,9 +53,26 @@
 #include <sproto.h>
 
 
+/**
+ * Resistances which can show up on rings and amulets.
+ * If you want to weight things so certain resistances show up more often than
+ * others, just add more entries in the table for the protections you want to
+ * show up.
+ */
+static int resist_table[] = {
+    ATNR_PHYSICAL, ATNR_MAGIC, ATNR_FIRE,
+    ATNR_ELECTRICITY, ATNR_COLD, ATNR_CONFUSION, ATNR_ACID, ATNR_DRAIN,
+    ATNR_GHOSTHIT, ATNR_POISON, ATNR_SLOW, ATNR_PARALYZE, ATNR_TURN_UNDEAD,
+    ATNR_FEAR, ATNR_DEPLETE, ATNR_DEATH, ATNR_HOLYWORD, ATNR_BLIND,
+    ATNR_LIFE_STEALING, ATNR_DISEASE
+};
+
+/** Number of items in ::resist_table. */
+#define num_resist_table 19
+
 static void change_treasure(treasure *t, object *op); /* overrule default values */
 static int special_potion(object *op);
-static void fix_flesh_item(object *item, object *donor);
+static void fix_flesh_item(object *item, const object *donor);
 
 extern const char *const spell_mapping[];
 
@@ -225,10 +242,10 @@ void load_treasures(void) {
     char filename[MAX_BUF], buf[MAX_BUF], name[MAX_BUF];
     treasurelist *previous = NULL;
     treasure *t;
-    int comp, line = 0;
+    int line = 0;
 
     snprintf(filename, sizeof(filename), "%s/%s", settings.datadir, settings.treasures);
-    if ((fp = open_and_uncompress(filename, 0, &comp, "r")) == NULL) {
+    if ((fp = fopen(filename, "r")) == NULL) {
         LOG(llevError, "Can't open treasure file.\n");
         return;
     }
@@ -266,7 +283,7 @@ void load_treasures(void) {
         } else
             LOG(llevError, "Treasure-list didn't understand: %s, line %d\n", buf, line);
     }
-    close_and_delete(fp, comp);
+    fclose(fp);
 
 #ifdef TREASURE_DEBUG
     /* Perform some checks on how valid the treasure data actually is.
@@ -968,7 +985,7 @@ static void set_ring_bonus(object *op, int bonus) {
             if (val > 35)
                 val = 35; /* Upper limit */
             b = 0;
-            while (op->resist[resist_table[resist]] != 0 && b < 4) {
+            while (op->resist[resist_table[resist]] != 0 && b++ < 4) {
                 resist = RANDOM()%num_resist_table;
             }
             if (b == 4)
@@ -1030,6 +1047,54 @@ static int get_magic(int diff) {
     return 4;
 }
 
+/**
+ * Adjust trap difficulty to the map.
+ * The default traps are too strong for wimpy level 1 players, and
+ * unthreatening to anyone of high level
+ *
+ * @param trap
+ * trap to adjust.
+ * @param difficulty
+ * map difficulty.
+ */
+static void trap_adjust(object *trap, int difficulty) {
+    int i;
+
+    /* now we set the trap level to match the difficulty of the level
+     * the formula below will give a level from 1 to (2*difficulty) with
+     * a peak probability at difficulty
+     */
+
+    trap->level = rndm(0, difficulty-1)+rndm(0, difficulty-1);
+    if (trap->level < 1)
+        trap->level = 1;
+
+    /* set the hiddenness of the trap, similar formula to above */
+    trap->stats.Cha = rndm(0, 19)+rndm(0, difficulty-1)+rndm(0, difficulty-1);
+
+    if (!trap->other_arch && !trap->inv) {
+        /* set the damage of the trap.
+         * we get 0-4 pts of damage per level of difficulty of the map in
+         * the trap
+         */
+
+        trap->stats.dam = 0;
+        for (i = 0; i < difficulty; i++)
+            trap->stats.dam += rndm(0, 4);
+
+        /*  the poison trap special case */
+        if (trap->attacktype&AT_POISON) {
+            trap->stats.dam = rndm(0, difficulty-1);
+            if (trap->stats.dam < 1)
+                trap->stats.dam = 1;
+        }
+
+        /*  so we get an appropriate amnt of exp for AT_DEATH traps */
+        if (trap->attacktype&AT_DEATH)
+            trap->stats.dam = 127;
+    }
+}
+
 #define DICE2 (get_magic(2) == 2 ? 2 : 1)
 #define DICESPELL (RANDOM()%3+RANDOM()%3+RANDOM()%3+RANDOM()%3+RANDOM()%3)
 
@@ -1133,8 +1198,7 @@ void fix_generated_item(object *op, object *creator, int difficulty, int max_mag
     }
 
     /* materialtype modifications.  Note we allow this on artifacts. */
-
-    set_materialname(op, difficulty, NULL);
+    set_materialname(op);
 
     if (flags&GT_MINIMAL) {
         if (op->type == POTION)
@@ -1212,6 +1276,8 @@ void fix_generated_item(object *op, object *creator, int difficulty, int max_mag
                 /* It's a special artifact!*/
                 break;
 
+            if (GET_ANIM_ID(op))
+                SET_ANIMATION(op, RANDOM()%((int)NUM_ANIMATIONS(op)));
             if (!(flags&GT_ONLY_GOOD) && !(RANDOM()%3))
                 SET_FLAG(op, FLAG_CURSED);
             set_ring_bonus(op, QUERY_FLAG(op, FLAG_CURSED) ? -DICE2 : DICE2);
@@ -1229,8 +1295,6 @@ void fix_generated_item(object *op, object *creator, int difficulty, int max_mag
                     set_ring_bonus(op, d);
                 }
             }
-            if (GET_ANIM_ID(op))
-                SET_ANIMATION(op, RANDOM()%((int)NUM_ANIMATIONS(op)));
             break;
 
         case BOOK:
@@ -1250,7 +1314,8 @@ void fix_generated_item(object *op, object *creator, int difficulty, int max_mag
 
                 tailor_readable_ob(op, creator->stats.sp);
                 /* books w/ info are worth more! */
-                op->value *= ((op->level > 10 ? op->level : (op->level+1)/2)*((strlen(op->msg)/250)+1));
+                if (op->msg != NULL)
+                    op->value *= ((op->level > 10 ? op->level : (op->level+1)/2)*((strlen(op->msg)/250)+1));
                 /* creator related stuff */
 
                 if (creator->slaying && !op->slaying) /* for check_inv floors */
@@ -1419,11 +1484,13 @@ void dump_monster_treasure(const char *name) {
 }
 
 /**
- * fix_flesh_item() - objects of type FLESH are similar to type
+ * Objects of type FLESH are similar to type
  * FOOD, except they inherit properties (name, food value, etc).
  * based on the original owner (or 'donor' if you like). -b.t.
+ * @param item FLESH item to fix based on the donor.
+ * @param donor what monster will give item.
  */
-static void fix_flesh_item(object *item, object *donor) {
+static void fix_flesh_item(object *item, const object *donor) {
     char tmpbuf[MAX_BUF];
     int i;
 
@@ -1546,3 +1613,111 @@ void free_all_treasures(void) {
         free(tl);
     }
 }
+
+/**
+ * This is the function that does the actual work for treasurelist_find_matching_type().
+ * See notes below on what we are doing here.  Note that the logic here follows
+ * that of create_all_treasures(), except we do not care about difficulty
+ * or chances.
+ *
+ * @param t
+ * treasure entry we are working on.
+ * @param type
+ * object type we are matching against.
+ * @param olp
+ * linked list pointer, may be null.
+ * @param tries
+ * For each depth, increases by one.  This is needed because treasurelists
+ * can loop back on each other (A->B, B->C, C->A), so we needto make sure
+ * we do not get in an infinite loop.
+ *
+ * @return
+ * linked list of entries.  This may be NULL if nothing is found.
+ */
+static objectlink *treasure_find_matching_type(treasure *t, int type, objectlink *olp, int tries)
+{
+
+    objectlink *nolp = olp;
+
+    /* I do not think this should get logged - since we are processing all
+     * possibilities, this could happen pretty often.
+     */
+    if (tries++ > 100) {
+        return olp;
+    }
+
+    if (t->name) {
+        if (strcmp(t->name, "NONE")) {
+            /* Look up treasurelist and then process - this is safer
+             * as if for some reason the treasurelist does not exist,
+             * this will just skip over it harmlessly.
+             */
+            treasurelist *tl = find_treasurelist(t->name);
+
+            if (tl)
+                nolp = treasure_find_matching_type(tl->items, type, nolp, tries);
+        }
+    } else {
+        if (t->item->clone.type == type) {
+            nolp = get_objectlink();
+            nolp->next = olp;
+            nolp->ob = &t->item->clone;
+        }
+    }
+    if (t->next_yes != NULL) {
+        nolp = treasure_find_matching_type(t->next_yes, type, nolp, tries);
+    }
+    if (t->next_no != NULL) {
+        nolp = treasure_find_matching_type(t->next_no, type, nolp, tries);
+    }
+    if (t->next != NULL) {
+        nolp = treasure_find_matching_type(t->next, type, nolp, tries);
+    }
+    return nolp;
+}
+
+/**
+ * This function looks at the passed in treasurelist and returns all
+ * objects on it, or on treasurelists it references, of matching
+ * type.  The oblinkpt linked list will return a pointer to all
+ * the archetype clones.
+ * This is useful for functions that need to examine treasurelists
+ * and potentially revoke or add a partial set of items on the list.
+ * This removes the need of other functions to have their own parsing
+ * logic of treasurelists.
+ * Note that this will return all objects that may show up on the
+ * the treasurelist of matching type.  This does not look at difficulty,
+ * yes/no combinations, etc.  In general, functions that call this should
+ * have some idea of what the treasurelist may be/what it may have on it.
+ * The contents of the linked list may not be unique - it is entirely
+ * possible that due to treasurelist traversals, the same item shows up
+ * multiple times, and there is no check here for that.
+ * The order of items on the returned linked list should not be taken
+ * to be meaningful in any way - based on different processing algorithms,
+ * the results could change.  As of this writing, order is reverse from
+ * that of the treasurelists, simply because that is fastest way to process them.
+ *
+ * @param randomitems
+ * The treasurelist to examine.
+ * @param type
+ * the object type (arch->clone.type) to match against.
+ * @param traverse
+ * If true, then this will process any treasurelists that this treasurelist points
+ * to, and so on.
+ *
+ * @return oblinkpt
+ * linked list containing pointers to the arch->clone fields.  Those objects
+ * should not be altered in any way, and must be copied to a new object
+ * before being used.  the returned oblinkpt must be freed with free_objectlink(),
+ * otherwise, this will result in a memory leak.
+ */
+objectlink * treasurelist_find_matching_type(const treasurelist *randomitems, int type, int traverse) {
+
+    objectlink *olp;
+
+    olp=treasure_find_matching_type(randomitems->items, type, NULL, 0);
+
+    return olp;
+
+}
+
