@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_utils_c =
- *   "$Id: utils.c 14079 2010-11-10 19:41:37Z ryo_saeba $";
+ *   "$Id: utils.c 14734 2011-06-29 17:18:42Z ryo_saeba $";
  */
 
 /*
@@ -303,75 +303,24 @@ void transmute_materialname(object *op, const object *change) {
 }
 
 /**
- * Set the materialname and type for an item
+ * Set the material name and type for an item, if not set.
+ * @param op item to set the material for.
  */
-void set_materialname(object *op, int difficulty, materialtype_t *nmt) {
-    materialtype_t *mt, *lmt;
+void set_materialname(object *op) {
+    materialtype_t *mt;
 
     if (op->materialname != NULL)
         return;
 
-    if (nmt == NULL) {
-        lmt = NULL;
-#ifndef NEW_MATERIAL_CODE
-        for (mt = materialt; mt != NULL && mt->next != NULL; mt = mt->next) {
-            if (op->material&mt->material) {
-                lmt = mt;
-                break;
-            }
+    for (mt = materialt; mt != NULL && mt->next != NULL; mt = mt->next) {
+        if (op->material&mt->material) {
+            break;
         }
-#else
-        for (mt = materialt; mt != NULL && mt->next != NULL; mt = mt->next) {
-            if (op->material&mt->material
-            && rndm(1, 100) <= mt->chance
-            && difficulty >= mt->difficulty
-            && (op->magic >= mt->magic || mt->magic == 0)) {
-                lmt = mt;
-                if (!(IS_WEAPON(op) || IS_ARMOR(op) || IS_SHIELD(op) || op->type == GIRDLE || op->type == GLOVES || op->type == CLOAK))
-                    break;
-            }
-        }
-#endif
-    } else {
-        lmt = nmt;
     }
 
-    if (lmt != NULL) {
-#ifndef NEW_MATERIAL_CODE
-        op->materialname = add_string(lmt->name);
+    if (mt != NULL) {
+        op->materialname = add_string(mt->name);
         return;
-#else
-
-        if (op->stats.dam && IS_WEAPON(op)) {
-            op->stats.dam += lmt->damage;
-            if (op->stats.dam < 1)
-                op->stats.dam = 1;
-        }
-        if (op->stats.sp && op->type == BOW)
-            op->stats.sp += lmt->sp;
-        if (op->stats.wc && IS_WEAPON(op))
-            op->stats.wc += lmt->wc;
-        if (IS_ARMOR(op) || IS_SHIELD(op) || op->type == GIRDLE || op->type == GLOVES || op->type == CLOAK) {
-            int j;
-
-            if (op->stats.ac)
-                op->stats.ac += lmt->ac;
-            for (j = 0; j < NROFATTACKS; j++)
-                if (op->resist[j] != 0) {
-                    op->resist[j] += lmt->mod[j];
-                    if (op->resist[j] > 100)
-                        op->resist[j] = 100;
-                    if (op->resist[j] < -100)
-                        op->resist[j] = -100;
-                }
-        }
-        op->materialname = add_string(lmt->name);
-        /* dont make it unstackable if it doesn't need to be */
-        if (IS_WEAPON(op) || IS_ARMOR(op) || IS_SHIELD(op) || op->type == GIRDLE || op->type == GLOVES || op->type == CLOAK) {
-            op->weight = (op->weight*lmt->weight)/100;
-            op->value = (op->value*lmt->value)/100;
-        }
-#endif
     }
 }
 
