@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_commands_h =
- *   "$Id: commands.h 12316 2009-12-20 18:34:13Z akirschbaum $";
+ *   "$Id: commands.h 13558 2010-08-05 20:53:39Z ryo_saeba $";
  */
 
 /*
@@ -58,11 +58,8 @@
  * @param params
  * the command parameters; empty string if no commands are given; leading and
  * trailing spaces have been removed
- * @return
- * 0 if invalid command, else actual command's return value (which may be
- * zero).
  */
-typedef int (*command_function)(object *op, char *params);
+typedef void (*command_function)(object *op, const char *params);
 
 /** Represents one command. */
 typedef struct {
