@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_config_h =
- *   "$Id: config.h 13580 2010-08-12 14:11:56Z meflin2 $";
+ *   "$Id: config.h 14733 2011-06-29 17:13:23Z ryo_saeba $";
  */
 
 /*
@@ -327,17 +327,6 @@
 #endif
 
 
-/**
- * Enable the new material code - it needs some work.  You can
- * enable this, and things will work, just you'll see a whole
- * bunch more materials show up, and thus a whole bunch more materials
- * in your inventory, and the sorting for them isn't really good.
- */
-
-/*
-#define NEW_MATERIAL_CODE
-*/
-
 /***********************************************************************
  * SECTION 2 - Machine/Compiler specific stuff.
  *
