@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_define_h =
- *   "$Id: define.h 14097 2010-11-15 07:17:37Z mwedel $";
+ *   "$Id: define.h 17403 2012-03-08 22:22:35Z ryo_saeba $";
  */
 
 /*
@@ -75,7 +75,6 @@ error - Your ANSI C compiler should be defining __STDC__;
 #define NAME_MAX 255
 #endif
 
-#define MAX_STAT                30      /**< The maximum legal value of any stat */
 #define MIN_STAT                1       /**< The minimum legal value of any stat */
 
 #define MAX_BUF                 256     /**< Used for all kinds of things */
@@ -157,11 +156,6 @@ error - Your ANSI C compiler should be defining __STDC__;
 #define TELEPORTER                  41
 #define CREATOR                     42
 #define SKILL                       43    /**< Also see ::SKILL_TOOL (74) below */
-#define EXPERIENCE                  44    /**< This is basically obsolete now.
-                                           * It used to contain experience for
-                                           * broad skill categories.  This
-                                           * value is now automatically
-                                           * converted at load time. */
 #define EARTHWALL                   45
 #define GOLEM                       46
 /*#define BOMB                      47 */
@@ -504,7 +498,7 @@ typedef struct typedata {
 #define FLAG_CLIENT_ANIM_RANDOM 10 /**< Client animate this, randomized */
 #define FLAG_ANIMATE            11 /**< The object looks at archetype for faces */
 #define FLAG_DIALOG_PARSED      12 /**< Was the object::msg field parsed? Temporary flag not saved */
-/*#define FLAG_FLYING           13*//* Not affected by WALK_ON or SLOW_MOVE) */
+#define FLAG_NO_SAVE            13 /**< If set (through plugins), the object is not saved on maps. */
 #define FLAG_MONSTER            14 /**< Will attack players */
 #define FLAG_FRIENDLY           15 /**< Will help players */
 
@@ -517,7 +511,7 @@ typedef struct typedata {
 #define FLAG_CAN_ROLL           22 /**< Object can be rolled */
 #define FLAG_OVERLAY_FLOOR      23 /**< Object is an overlay floor */
 #define FLAG_IS_TURNABLE        24 /**< Object can change face with direction */
-/*#define FLAG_WALK_OFF         25*//* Object is applied when left */
+#define FLAG_PROBE              25 /**< Object displays HP information to player. */
 /*#define FLAG_FLY_ON           26*//* As WALK_ON, but only with FLAG_FLYING */
 /*#define FLAG_FLY_OFF          27*//* As WALK_OFF, but only with FLAG_FLYING */
 #define FLAG_IS_USED_UP         28 /**< When (--food<0) the object will exit */
@@ -861,73 +855,6 @@ static inline void safe_strcat(char *dest, const char *orig, size_t *curlen, siz
         *curlen = maxlen-1;
 }
 
-/* The SAFE versions of these call the safe_strcat function above.
- * Ideally, all functions should use the SAFE functions, but they
- * require some extra support in the calling function to remain as
- * efficient.
- */
-#define DESCRIBE_ABILITY_SAFE(retbuf, variable, name, len, maxlen) \
-    if (variable) {                                                \
-        int i, j = 0;                                              \
-        safe_strcat(retbuf, "(" name ": ", len, maxlen);           \
-        for (i = 0; i < NROFATTACKS; i++)                          \
-            if (variable&(1<<i)) {                                 \
-                if (j)                                             \
-                    safe_strcat(retbuf, ", ", len, maxlen);        \
-                else                                               \
-                    j = 1;                                         \
-                safe_strcat(retbuf, attacks[i], len, maxlen);      \
-            }                                                      \
-        safe_strcat(retbuf, ")", len, maxlen);                     \
-    }
-
-/* separated this from the common/item.c file. b.t. Dec 1995 */
-
-#define DESCRIBE_ABILITY(retbuf, variable, name)                   \
-    if (variable) {                                                \
-        int i, j = 0;                                              \
-        strcat(retbuf, "(" name ": ");                             \
-        for (i = 0; i < NROFATTACKS; i++)                          \
-            if (variable&(1<<i)) {                                 \
-                if (j)                                             \
-                    strcat(retbuf, ", ");                          \
-                else                                               \
-                    j = 1;                                         \
-                strcat(retbuf, attacks[i]);                        \
-            }                                                      \
-        strcat(retbuf, ")");                                       \
-    }
-
-#define DESCRIBE_PATH(retbuf, variable, name)                      \
-    if (variable) {                                                \
-        int i, j = 0;                                              \
-        strcat(retbuf, "(" name ": ");                             \
-        for (i = 0; i < NRSPELLPATHS; i++)                         \
-            if (variable&(1<<i)) {                                 \
-                if (j)                                             \
-                    strcat(retbuf, ", ");                          \
-                else                                               \
-                    j = 1;                                         \
-                strcat(retbuf, spellpathnames[i]);                 \
-            }                                                      \
-        strcat(retbuf, ")");                                       \
-    }
-
-#define DESCRIBE_PATH_SAFE(retbuf, variable, name, len, maxlen)    \
-    if (variable) {                                                \
-        int i, j = 0;                                              \
-        safe_strcat(retbuf, "(" name ": ", len, maxlen);           \
-        for (i = 0; i < NRSPELLPATHS; i++)                         \
-            if (variable&(1<<i)) {                                 \
-                if (j)                                             \
-                    safe_strcat(retbuf, ", ", len, maxlen);        \
-                else                                               \
-                    j = 1;                                         \
-                safe_strcat(retbuf, spellpathnames[i], len, maxlen); \
-            }                                                      \
-        safe_strcat(retbuf, ")", len, maxlen);                     \
-    }
-
 /**
  * @defgroup AP_xxx Flags for apply_special().
  *
@@ -950,6 +877,16 @@ static inline void safe_strcat(char *dest, const char *orig, size_t *curlen, siz
                              * may be some that still print */
 /*@}*/
 
+/**
+ * @defgroup AC_PLAYER_STAT for apply_changes_to_player()
+ *
+ * These flags determine what apply_changes_to_player() does for
+ * stat adjustment, if anything.
+ */
+#define AC_PLAYER_STAT_LIMIT        1   /** Limit stats to racial maximum */
+#define AC_PLAYER_STAT_NO_CHANGE    2   /** Do not make any stat adjustments */
+
+
 /**
  * @defgroup CAN_APPLY_xxx Values returned by apply_can_apply_object().
  *
@@ -1025,35 +962,6 @@ static inline void safe_strcat(char *dest, const char *orig, size_t *curlen, siz
  */
 #define WEIGHT(op) (op->nrof ? op->weight : op->weight+op->carrying)
 
-/**
- * @defgroup FASTCAT_xxx Code fastening defines
- *
- * FAST_STRCAT & FAST_STRNCAT will add buf2__ at position pointed by
- * buf__ and increment buf__ position so it will point to the end of buf__.
- * the '\\0' caracter will not be put at end of buf__.
- * use preparefastcat and finishfastcat on buf__ to prepare
- * and clean up the string. (Lots faster than doing each time...)
- * If you use them and have choice between FAST_STRCAT and FAST_STRNCAT,
- * keep in mind FAST_STRNCAT is faster since length of second argument is
- * known in advance.
- */
-/*@{*/
-#define PREPARE_FASTCAT(buf__) buf__+strlen(buf__)
-#define FAST_STRNCAT(buf__, buf2__, size__) { memcpy(buf__, buf2__, size__); buf__ += size__; }
-#define FAST_STRCAT(buf__, buf2__) { memcpy(buf__, buf2__, strlen(buf2__)); buf__ += strlen(buf2__); }
-#define FINISH_FASTCAT(buf__) buf__[0] = '\0';
-
-/* You may uncomment following define to check sanity of code.
- * But use as debug only (loses all speed gained by those macros)
- */
-/*#define FAST_STRNCAT(buf__, buf2__, size__) { \
-    memcpy (buf__, buf2__, size__); \
-    buf__ += size__; \
-    if (size__ != strlen(buf2__)) \
-        LOG(llevError, "Error, bad length for %s\n", buf2__); \
-}*/
-/*@}*/
-
 /**
  * Constructs a loop iterating over the inventory of an object. Example:
  * <pre>
