@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_global_h =
- *   "$Id: global.h 14209 2010-12-18 16:19:30Z ryo_saeba $";
+ *   "$Id: global.h 16018 2011-12-03 15:13:09Z ryo_saeba $";
  */
 
 /*
@@ -201,9 +201,6 @@ EXTERN godlink *first_god;                  /**< God list. */
 EXTERN racelink *first_race;                /**< Race list. */
 /*@}*/
 
-#define NROF_COMPRESS_METHODS 4
-extern const char *uncomp[NROF_COMPRESS_METHODS][3];
-
 /*
  * Variables set by different flags (see init.c):
  */
@@ -421,6 +418,10 @@ typedef struct Settings {
     uint8   starting_stat_max;        /**< Maximum value of a starting stat */
     uint8   starting_stat_points;     /**< How many stat points character starts with */
     uint8   roll_stat_points;         /**< How many stat points legacy (rolled) chars start with */
+    uint8   max_stat;                 /**< Maximum stat value - 255 should be sufficient */
+    uint8   special_break_map;        /**< If set, then submaps in random maps can break the walls. */
+    linked_char *disabled_plugins;    /**< List of disabled plugins, 'All' means all. */
+    uint8   ignore_plugin_compatibility;    /**< If set, don't check plugin version. */
 } Settings;
 
 /**
