@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_includes_h =
- *   "$Id: includes.h 11673 2009-05-09 05:48:40Z kbulgrien $";
+ *   "$Id: includes.h 15692 2011-11-12 21:11:29Z ryo_saeba $";
  */
 
 /*
@@ -57,6 +57,10 @@
 #include "win32.h"
 #else
 #include <autoconf.h>
+/* socklen_t is defined in this file on some systems, and that type is
+ * used in newserver.h, which is used in all other files
+ */
+#include <sys/socket.h>
 #endif
 
 #include <stdio.h>
@@ -104,7 +108,6 @@
 #include "define.h"
 #include "logger.h"
 #include "shared/newclient.h"
-#include "languages.h"
 
 #ifndef TRUE
 #define TRUE 1
