@@ -20,6 +20,7 @@ extern void free_arch(archetype *at);
 extern void free_all_archs(void);
 extern archetype *get_archetype_struct(void);
 extern void check_generators(void);
+extern void check_summoned(void);
 extern object *arch_to_object(archetype *at);
 extern object *create_singularity(const char *name);
 extern object *create_archetype(const char *name);
@@ -35,7 +36,9 @@ extern int legal_artifact_combination(const object *op, const artifact *art);
 extern void add_abilities(object *op, const object *change);
 extern void init_artifacts(void);
 extern const artifactlist *find_artifactlist(int type);
+const artifact *find_artifact(const object *op, const char *name);
 extern void dump_artifacts(void);
+extern unsigned artifact_get_face(const artifact *art);
 /* button.c */
 extern void trigger_connected(objectlink *ol, object *cause, const int state);
 extern void push_button(object *op);
@@ -73,13 +76,12 @@ extern void fatal(int err);
 extern void init_gods(void);
 extern godlink *get_rand_god(void);
 extern const object *pntr_to_god_obj(godlink *godlnk);
-extern int describe_god(const object *god, int what, StringBuffer *buf, int maxlen);
+extern int describe_god(const object *god, int what, StringBuffer *buf, size_t maxlen);
 extern void free_all_god(void);
 extern void dump_gods(void);
 /* info.c */
 extern void dump_abilities(void);
 extern void print_monsters(void);
-extern void bitstostring(long bits, int num, char *str);
 /* image.c */
 extern void read_bmap_names(void);
 extern unsigned find_face(const char *name, unsigned error);
@@ -111,11 +113,17 @@ extern StringBuffer *describe_monster(const object *op, StringBuffer *buf);
 extern StringBuffer *describe_item(const object *op, const object *owner, StringBuffer *buf);
 extern int is_magical(const object *op);
 extern int need_identify(const object *op);
-object *identify(object *op);
+extern void object_give_identified_properties(object *op);
+extern object *identify(object *op);
 /* languages.c */
+const char *i18n(const object *who, const char *code);
+extern int i18n_get_language_by_code(const char *code);
+int i18n_find_language_by_code(const char *code);
+extern sstring i18n_get_language_code(int language);
+extern void i18n_list_languages(object *who);
 extern int get_language(object *op);
-extern const char *i18n_translate(int language, int id);
 extern void i18n_init(void);
+extern void i18n_free(void);
 /* links.c */
 extern objectlink *get_objectlink(void);
 extern oblinkpt *get_objectlinkpt(void);
@@ -146,7 +154,7 @@ extern void change_exp(object *op, sint64 exp, const char *skill_name, int flag)
 extern void apply_death_exp_penalty(object *op);
 extern int did_make_save(const object *op, int level, int bonus);
 extern void share_exp(object *op, sint64 exp, const char *skill, int flag);
-extern float get_cha_bonus(int stat);
+extern int get_cha_bonus(int stat);
 extern int get_dex_bonus(int stat);
 extern int get_thaco_bonus(int stat);
 extern uint32 get_weight_limit(int stat);
@@ -156,6 +164,7 @@ extern int get_turn_bonus(int stat);
 extern int get_dam_bonus(int stat);
 extern float get_speed_bonus(int stat);
 extern int get_fear_bonus(int stat);
+extern void init_stats(int reload);
 /* logger.c */
 extern void LOG(LogLevel logLevel, const char *format, ...);
 /* los.c */
@@ -233,8 +242,8 @@ extern void object_set_enemy(object *op, object *enemy);
 extern void object_reset(object *op);
 extern void object_free_key_values(object *op);
 extern void object_clear(object *op);
-extern void object_copy(object *op2, object *op);
-extern void object_copy_with_inv(object *src_ob, object *dest_ob);
+extern void object_copy(const object *src_ob, object *dest_ob);
+extern void object_copy_with_inv(const object *src_ob, object *dest_ob);
 extern object *object_new(void);
 extern void object_update_turn_face(object *op);
 extern void object_update_speed(object *op);
@@ -265,8 +274,8 @@ extern object *arch_present_in_ob(const archetype *at, const object *op);
 extern void object_set_flag_inv(object *op, int flag);
 extern void object_unset_flag_inv(object *op, int flag);
 extern void object_set_cheat(object *op);
-extern int object_find_multi_free_spot_around(object *ob, object *gen, int *hx, int *hy);
-extern int object_find_multi_free_spot_within_radius(object *ob, object *gen, int *hx, int *hy);
+extern int object_find_multi_free_spot_around(const object *ob, const object *gen, int *hx, int *hy);
+extern int object_find_multi_free_spot_within_radius(const object *ob, const object *gen, int *hx, int *hy);
 extern int object_find_free_spot(const object *ob, mapstruct *m, int x, int y, int start, int stop);
 extern int object_find_first_free_spot(const object *ob, mapstruct *m, int x, int y);
 extern void get_search_arr(int *search_arr);
@@ -297,7 +306,7 @@ extern const char *object_get_value(const object *op, const char *const key);
 extern int object_set_value(object *op, const char *key, const char *value, int add_key);
 extern int object_matches_string(object *pl, object *op, const char *name);
 extern void object_fix_multipart(object *tmp);
-extern void object_get_multi_size(object *ob, int *sx, int *sy, int *hx, int *hy);
+extern void object_get_multi_size(const object *ob, int *sx, int *sy, int *hx, int *hy);
 extern void object_insert_to_free_spot_or_free(object *op, mapstruct *map, int x, int y, int start, int stop, object *originator);
 extern void object_set_msg(object *op, const char *msg);
 /* path.c */
@@ -312,8 +321,6 @@ extern char *strdup_local(const char *str);
 extern const char *strcasestr_local(const char *s, const char *find);
 extern char *strerror_local(int errnum, char *buf, size_t size);
 extern int isqrt(int n);
-extern FILE *open_and_uncompress(const char *name, int flag, int *compressed, const char *mode);
-extern void close_and_delete(FILE *fp, int compressed);
 extern void make_path_to_file(const char *filename);
 /* player.c */
 extern void clear_player(player *pl);
@@ -336,12 +343,13 @@ extern char *strtoktolin(const char *buf1, const char *buf2, char *retbuf, size_
 extern int book_overflow(const char *buf1, const char *buf2, size_t booksize);
 extern void init_readable(void);
 extern object *get_random_mon(int level);
-extern char *artifact_msg(int level, char *retbuf, size_t booksize);
-extern char *spellpath_msg(int level, char *retbuf, size_t booksize);
 extern void tailor_readable_ob(object *book, int msg_type);
 extern void free_all_readable(void);
 extern void write_book_archive(void);
 extern const readable_message_type *get_readable_message_type(object *readable);
+extern const GeneralMessage *get_message_from_identifier(const char *identifier);
+extern sstring get_message_title(const GeneralMessage *message);
+extern sstring get_message_body(const GeneralMessage *message);
 /* recipe.c */
 extern recipelist *get_formulalist(int i);
 extern void init_formulae(void);
@@ -376,6 +384,7 @@ extern char *ss_dump_table(int what, char *buf, size_t size);
 extern int buf_overflow(const char *buf1, const char *buf2, size_t bufsize);
 /* stringbuffer.c */
 extern StringBuffer *stringbuffer_new(void);
+extern void stringbuffer_delete(StringBuffer *sb);
 extern char *stringbuffer_finish(StringBuffer *sb);
 extern sstring stringbuffer_finish_shared(StringBuffer *sb);
 extern void stringbuffer_append_string(StringBuffer *sb, const char *str);
@@ -404,6 +413,7 @@ extern void set_abs_magic(object *op, int magic);
 extern void fix_generated_item(object *op, object *creator, int difficulty, int max_magic, int flags);
 extern void dump_monster_treasure(const char *name);
 extern void free_all_treasures(void);
+extern objectlink * treasurelist_find_matching_type(const treasurelist *randomitems, int type, int traverse);
 /* utils.c */
 extern int random_roll(int min, int max, const object *op, int goodbad);
 extern sint64 random_roll64(sint64 min, sint64 max, const object *op, int goodbad);
@@ -412,7 +422,7 @@ extern int rndm(int min, int max);
 extern void decay_objects(mapstruct *m);
 extern materialtype_t *name_to_material(const char *name);
 extern void transmute_materialname(object *op, const object *change);
-extern void set_materialname(object *op, int difficulty, materialtype_t *nmt);
+extern void set_materialname(object *op);
 extern const char *strrstr(const char *haystack, const char *needle);
 extern void strip_endline(char *buf);
 extern void replace(const char *src, const char *key, const char *replacement, char *result, size_t resultsize);
@@ -422,7 +432,7 @@ extern int get_randomized_dir(int dir);
 extern int adjust_dir(int dir, int destination_dir);
 extern void replace_unprintable_chars(char *buf);
 extern size_t split_string(char *str, char *array[], size_t array_size, char sep);
-extern StringBuffer *describe_spellpath_attenuation(const char *path, int value, StringBuffer *buf);
+extern StringBuffer *describe_spellpath_attenuation(const char *attenuation, int value, StringBuffer *buf);
 extern StringBuffer *describe_attacktype(const char *attack, int value, StringBuffer *buf);
 /* loader.c */
 extern int lex_load(int *depth, object **items, int maxdepth, int map_flags, int linemode);
