@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_living_h =
- *   "$Id: living.h 13862 2010-09-23 18:15:41Z ryo_saeba $";
+ *   "$Id: living.h 14447 2011-05-02 06:11:51Z mwedel $";
  */
 
 /*
@@ -77,7 +77,7 @@ typedef struct liv {
     sint32        food;       /**< How much food in stomach.  0 = starved. */
 } living;
 
-float get_cha_bonus(int stat);
+int get_cha_bonus(int stat);
 int get_dex_bonus(int stat);
 int get_thaco_bonus(int stat);
 uint32 get_weight_limit(int stat);
