@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_object_h =
- *   "$Id: object.h 14031 2010-10-24 13:46:33Z ryo_saeba $";
+ *   "$Id: object.h 16215 2011-12-18 18:13:41Z ryo_saeba $";
  */
 
 /*
@@ -164,6 +164,7 @@ typedef struct obj {
      * object_copy() to do so.  Everything below here also gets cleared
      * by object_clear()
      */
+    sstring     artifact;       /**< If set, the item is the artifact with this name and the matching type. */
     const char  *name;          /**< The name of the object, obviously... */
     const char  *name_pl;       /**< The plural name of the object */
     const char  *anim_suffix;   /**< Used to determine combined animations */
@@ -271,7 +272,6 @@ typedef struct obj {
     uint8       last_anim;      /**< Last sequence used to draw face */
     uint16      temp_animation_id; /**< An index into the temporary animation array */
     uint8       temp_anim_speed; /**< Ticks between temporary animation-frames */
-    uint8       temp_last_anim; /**< Last sequence used to draw temporary animation face */
     sint32      elevation;      /**< Elevation of this terrain - used in weather code */
     uint8       smoothlevel;    /**< how to smooth this square around*/
     uint8       map_layer;      /**< What level to draw this on the map */
@@ -287,9 +287,6 @@ typedef struct obj {
     const char  *custom_name;   /**< Custom name assigned by player */
     key_value   *key_values;    /**< Fields not explictly known by the loader. */
 
-    uint8       no_save;        /**< This field indicates that the object should never
-                                 * be saved even for map swapout. Not handled by the
-                                 * loading or saving code. */
     sint16      *discrete_damage; /**< damage values, based on each attacktype. */
     tag_t       *spell_tags;
 } object;
