@@ -1,13 +1,17 @@
-/* $Id: path.h 5117 2006-11-15 02:29:53Z qal21 $ */
+/* $Id: path.h 11278 2009-01-28 15:00:48Z anmaster $ */
+
+/**
+ * @file
+ * Path-related function prototypes.
+ */
 
 #ifndef PATH_H
 #define PATH_H
 
 /**
- * Combine two paths and return the combined path. The result value is a static
- * buffer; it is valid until the next call to this function.
+ * Combine two paths and return the combined path. Returns path.
  */
-char *path_combine(const char *src, const char *dst);
+char *path_combine(const char *src, const char *dst, char *path, size_t size);
 
 /**
  * Normalize a path; the passed in path is modified in-place.
@@ -19,6 +23,6 @@ void path_normalize(char *path);
  * it is valid until the next call to either this function or to
  * combine_path().
  */
-char *path_combine_and_normalize(const char *src, const char *dst);
+char *path_combine_and_normalize(const char *src, const char *dst, char *path, size_t size);
 
 #endif /* PATH_H */
