@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_player_h =
- *   "$Id: player.h 14248 2011-01-24 06:00:53Z mwedel $";
+ *   "$Id: player.h 16766 2012-01-21 11:30:34Z ryo_saeba $";
  */
 
 /*
@@ -159,6 +159,7 @@ typedef struct pl {
     uint32      peaceful:1;          /**< If set, won't attack friendly creatures. */
     uint32      hidden:1;            /**< If True, player (DM) is hidden from view. */
     uint32      no_shout:1;          /**< if True, player is *not *able to use shout command. */
+    uint32      has_directory:1;     /**< If 0, the player was not yet saved, its directory doesn't exist. */
     const char  *invis_race;         /**< What race invisible to? */
 
     object      *last_skill_ob[NUM_SKILLS];     /**< Exp objects sent to client. */
@@ -180,6 +181,8 @@ typedef struct pl {
     living      last_applied_stats;  /**< Last applied stats sent to the client. */
     float       last_speed;          /**< Last speed as sent to client. */
     sint16      last_resist[NROFATTACKS];       /**< last resist values sent to client. */
+    sint16      last_golem_hp;       /**< Last golem hp value sent to the client. */
+    sint16      last_golem_maxhp;    /**< Last golem max hp value sent to the client. */
     object      *ob;                 /**< The object representing the player. */
     object      *last_used;          /**< Pointer to object last picked or applied. */
     uint32      last_used_id;        /**< Safety measures to be sure it's the same. */
