@@ -30,11 +30,13 @@
 # else
 #  define MODULEAPI __declspec(dllimport)
 # endif
-#elif HAVE_VISIBILITY
+#else
+#ifdef HAVE_VISIBILITY
 # define MODULEAPI __attribute__((visibility("default")))
 #else
 # define MODULEAPI
 #endif
+#endif
 
 #include <global.h>
 #include <object.h>
@@ -268,7 +270,7 @@ extern crossfire_plugin *plugins_list;
 #define CFAPI_OBJECT_PROP_INVISIBLE         98
 #define CFAPI_OBJECT_PROP_FACE              99
 #define CFAPI_OBJECT_PROP_ANIMATION         100
-#define CFAPI_OBJECT_PROP_NO_SAVE           101
+/*#define CFAPI_OBJECT_PROP_NO_SAVE           101*/
 #define CFAPI_OBJECT_PROP_MOVE_TYPE         102
 #define CFAPI_OBJECT_PROP_MOVE_BLOCK        103
 #define CFAPI_OBJECT_PROP_MOVE_ALLOW        104
@@ -328,6 +330,9 @@ extern crossfire_plugin *plugins_list;
 #define CFAPI_REGION_PROP_PARENT            2
 #define CFAPI_REGION_PROP_LONGNAME          3
 #define CFAPI_REGION_PROP_MESSAGE           4
+#define CFAPI_REGION_PROP_JAIL_X            5
+#define CFAPI_REGION_PROP_JAIL_Y            6
+#define CFAPI_REGION_PROP_JAIL_PATH         7
 
 /*****************************************************************************/
 /* Exportable functions. Any plugin should define all those.                 */
