@@ -18,6 +18,7 @@ void magic_mapping_mark(object *pl, char *map_mark, int strength);
 void draw_magic_map(object *pl);
 /* init.c */
 void init_connection(socket_struct *ns, const char *from_ip);
+void init_listening_socket(socket_struct *ns);
 void init_server(void);
 void free_all_newserver(void);
 void free_newsocket(socket_struct *ns);
@@ -27,7 +28,7 @@ void esrv_draw_look(object *pl);
 void esrv_send_inventory(object *pl, object *op);
 void esrv_update_item(int flags, object *pl, object *op);
 void esrv_send_item(object *pl, object *op);
-void esrv_del_item(player *pl, int tag);
+void esrv_del_item(player *pl, object *ob);
 void examine_cmd(char *buf, int len, player *pl);
 void apply_cmd(char *buf, int len, player *pl);
 void lock_item_cmd(uint8 *data, int len, player *pl);
@@ -102,15 +103,17 @@ void esrv_remove_spell(player *pl, object *spell);
 void esrv_send_pickup(player *pl);
 void esrv_add_spells(player *pl, object *spell);
 void send_tick(player *pl);
-void send_file(socket_struct *ns, char *file);
+void send_file(socket_struct *ns, const char *file);
 void account_login_cmd(char *buf, int len, socket_struct *ns);
 void account_new_cmd(char *buf, int len, socket_struct *ns);
 void account_add_player_cmd(char *buf, int len, socket_struct *ns);
 void account_play_cmd(char *buf, int len, socket_struct *ns);
 void send_account_players(socket_struct *ns);
 void create_player_cmd(char *buf, int len, socket_struct *ns);
+void account_password(char *buf, int len, socket_struct *ns);
 /* requestinfo.c */
 void send_new_char_info(socket_struct *ns);
+void send_map_info(socket_struct *ns);
 /* sounds.c */
 void play_sound_player_only(player *pl, sint8 sound_type, object *emitter, int dir, const char *action);
 void play_sound_map(sint8 sound_type, object *emitter, int dir, const char *action);
