@@ -13,6 +13,7 @@ const char *account_get_account_for_char(const char *charname);
 player *account_get_logged_in_player(const char *name);
 socket_struct *account_get_logged_in_init_socket(const char *name);
 int account_is_logged_in(const char *name);
+int account_change_password(const char *account_name, const char *current_password, const char *new_password);
 /* account_char.c */
 Account_Char *account_char_load(const char *account_name);
 void account_char_save(const char *account, Account_Char *chars);
@@ -50,7 +51,7 @@ int friendly_fire(object *op, object *hitter);
 int hit_player(object *op, int dam, object *hitter, uint32 type, int full_hit);
 void confuse_living(object *op, object *hitter, int dam);
 void blind_living(object *op, object *hitter, int dam);
-void paralyze_living(object *op, object *hitter, int dam);
+void paralyze_living(object *op, int dam);
 /* ban.c */
 int checkbanned(const char *login, const char *host);
 /* build_map.c */
@@ -127,7 +128,6 @@ void command_body(object *op, const char *params);
 void command_motd(object *op, const char *params);
 void command_rules(object *op, const char *params);
 void command_news(object *op, const char *params);
-void malloc_info(object *op);
 void current_region_info(object *op);
 void current_map_info(object *op);
 void command_whereabouts(object *op, const char *params);
@@ -215,7 +215,7 @@ void command_empty(object *op, const char *params);
 void command_examine(object *op, const char *params);
 object *find_marked_object(object *op);
 void command_mark(object *op, const char *params);
-void examine_monster(object *op, object *tmp);
+void examine_monster(object *op, object *tmp, int level);
 void examine(object *op, object *tmp);
 void inventory(object *op, object *inv);
 void command_pickup(object *op, const char *params);
@@ -249,6 +249,7 @@ void command_toggle_shout(object *op, const char *params);
 void command_shutdown(object *op, const char *params);
 void command_goto(object *op, const char *params);
 void command_freeze(object *op, const char *params);
+int player_arrest(object *who);
 void command_arrest(object *op, const char *params);
 void command_summon(object *op, const char *params);
 void command_teleport(object *op, const char *params);
@@ -296,7 +297,7 @@ int move_disease(object *disease);
 int infect_object(object *victim, object *disease, int force);
 void move_symptom(object *symptom);
 void check_physically_infect(object *victim, object *hitter);
-int cure_disease(object *sufferer, object *caster);
+int cure_disease(object *sufferer, object *caster, sstring skill);
 /* hiscore.c */
 void hiscore_init(void);
 void hiscore_check(object *op, int quiet);
@@ -317,6 +318,11 @@ void knowledge_read(player *pl, object *book);
 void command_knowledge(object *pl, const char *params);
 void free_knowledge(void);
 int knowledge_player_knows(const player *pl, const char *knowledge);
+void knowledge_item_can_be_used_alchemy(object *op, const object *item);
+void knowledge_send_info(socket_struct *ns);
+void knowledge_send_known(player *pl);
+void knowledge_first_player_save(player *pl);
+void knowledge_process_incremental(void);
 /* login.c */
 void emergency_save(int flag);
 void delete_character(const char *name);
@@ -329,6 +335,7 @@ void check_login(object *op, int check_pass);
 object *monster_check_enemy(object *npc, rv_vector *rv);
 object *monster_find_nearest_living_creature(object *npc);
 int monster_compute_path(object *source, object *target, int default_dir);
+void monster_do_living(object *op);
 int monster_move(object *op);
 void monster_check_apply_all(object *monster);
 void monster_check_apply(object *mon, object *item);
@@ -380,8 +387,8 @@ int pets_summon_golem(object *op, object *caster, int dir, object *spob);
 int pets_summon_object(object *op, object *caster, object *spell_ob, int dir, const char *stringarg);
 int pets_should_arena_attack(object *pet, object *owner, object *target);
 /* player.c */
-player *find_player_options(const char *plname, int options, const mapstruct *map);
 player *find_player(const char *plname);
+player *find_player_options(const char *plname, int options, const mapstruct *map);
 player *find_player_partial_name(const char *plname);
 player *find_player_socket(const socket_struct *ns);
 void display_motd(const object *op);
@@ -390,7 +397,7 @@ void send_news(const object *op);
 int playername_ok(const char *cp);
 player *get_player(player *p);
 void set_first_map(object *op);
-player *add_player(socket_struct *ns, int new_char);
+player *add_player(socket_struct *ns, int flags);
 object *get_nearest_player(object *mon);
 int path_to_player(object *mon, object *pl, unsigned mindiff);
 void give_initial_items(object *pl, treasurelist *items);
@@ -405,6 +412,8 @@ void roll_stats(object *op);
 void roll_again(object *op);
 void key_roll_stat(object *op, char key);
 void key_change_class(object *op, char key);
+int check_race_and_class(living *stats, archetype *race, archetype *opclass);
+int apply_race_and_class(object *op, archetype *race, archetype *opclass, living *stats);
 void key_confirm_quit(object *op, char key);
 int check_pick(object *op);
 int fire_bow(object *op, object *arrow, int dir, int wc_mod, sint16 sx, sint16 sy);
@@ -415,7 +424,7 @@ int move_player(object *op, int dir);
 int handle_newcs_player(object *op);
 void remove_unpaid_objects(object *op, object *env, int free_items);
 void do_some_living(object *op);
-void kill_player(object *op);
+void kill_player(object *op, const object *killer);
 void fix_weight(void);
 void fix_luck(void);
 void cast_dust(object *op, object *throw_ob, int dir);
@@ -429,19 +438,16 @@ int op_on_battleground(object *op, int *x, int *y, archetype **trophy);
 void dragon_ability_gain(object *who, int atnr, int level);
 void player_unready_range_ob(player *pl, object *ob);
 void player_set_state(player *pl, uint8 state);
-int apply_race_and_class(object *op, archetype *race, archetype *class);
 /* plugins.c */
 int user_event(object *op, object *activator, object *third, const char *message, int fix);
 int execute_event(object *op, int eventcode, object *activator, object *third, const char *message, int fix);
 int plugin_event_say(object *npc, talk_info *talk);
 int execute_global_event(int eventcode, ...);
 int plugins_init_plugin(const char *libfile);
-void cfapi_get_hooks(int *type, ...);
 int plugins_remove_plugin(const char *id);
-crossfire_plugin *plugins_find_plugin(const char *id);
 void plugins_display_list(object *op);
 command_array_struct *find_plugin_command(const char *cmd, command_array_struct *command);
-int initPlugins(void);
+void initPlugins(void);
 void cleanupPlugins(void);
 /* quest.c */
 int quest_get_player_state(player *pl, sstring quest_code);
@@ -452,6 +458,8 @@ void command_quest(object *op, const char *params);
 void dump_quests(void);
 void free_quest(void);
 void free_quest_definitions(void);
+void quest_send_initial_states(player *pl);
+void quest_first_player_save(player *pl);
 /* resurrection.c */
 int cast_raise_dead_spell(object *op, object *caster, object *spell, int dir, const char *arg);
 void dead_player(object *op);
@@ -462,9 +470,10 @@ int dispel_rune(object *op, object *caster, object *spell, object *skill, int di
 int trap_see(object *op, object *trap);
 int trap_show(object *trap, object *where);
 int trap_disarm(object *disarmer, object *trap, int risk, object *skill);
-void trap_adjust(object *trap, int difficulty);
 /* shop.c */
 uint64 query_cost(const object *tmp, object *who, int flag);
+StringBuffer *query_cost_string(const object *tmp, object *who, int flag, StringBuffer *buf);
+StringBuffer *cost_string_from_value(uint64 cost, int largest_coin, StringBuffer *buf);
 uint64 query_money(const object *op);
 int pay_for_amount(uint64 to_pay, object *pl);
 int pay_for_item(object *op, object *pl);
@@ -475,8 +484,6 @@ double shopkeeper_approval(const mapstruct *map, const object *player);
 int describe_shop(const object *op);
 int is_in_shop(object *ob);
 int coords_in_shop(mapstruct *map, int x, int y);
-StringBuffer *query_cost_string(const object *tmp, object *who, int flag, StringBuffer *buf);
-StringBuffer *cost_string_from_value(uint64 cost, int largest_coin, StringBuffer *buf);
 /* skills.c */
 int steal(object *op, int dir, object *skill);
 int pick_lock(object *pl, int dir, object *skill);
@@ -493,7 +500,7 @@ int remove_trap(object *op, object *skill);
 int pray(object *pl, object *skill);
 void meditate(object *pl, object *skill);
 int write_on_item(object *pl, const char *params, object *skill);
-int skill_throw(object *op, object *part, int dir, const char *params, object *skill);
+int skill_throw(object *op, object *part, int dir, object *skill);
 /* skill_util.c */
 void init_skills(void);
 void link_player_skills(object *op);
@@ -528,7 +535,7 @@ void polymorph(object *op, object *who, int level);
 int cast_polymorph(object *op, object *caster, object *spell_ob, int dir);
 int cast_create_missile(object *op, object *caster, object *spell, int dir, const char *stringarg);
 int cast_create_food(object *op, object *caster, object *spell_ob, int dir, const char *stringarg);
-int probe(object *op, object *caster, object *spell_ob, int dir);
+int probe(object *op, object *caster, object *spell_ob, int dir, int level);
 int makes_invisible_to(object *pl, object *mon);
 int cast_invisible(object *op, object *caster, object *spell_ob);
 int cast_earth_to_dust(object *op, object *caster, object *spell_ob);
@@ -565,6 +572,7 @@ sint16 SP_level_spellpoint_cost(object *caster, object *spell, int flags);
 int SP_level_dam_adjust(const object *caster, const object *spob);
 int SP_level_duration_adjust(const object *caster, const object *spob);
 int SP_level_range_adjust(const object *caster, const object *spob);
+int SP_level_wc_adjust(const object *caster, const object *spob);
 object *check_spell_known(object *op, const char *name);
 object *lookup_spell_by_name(object *op, const char *spname);
 int reflwall(mapstruct *m, int x, int y, object *sp_op);
