@@ -32,6 +32,9 @@
 #include <assert.h>
 #include <cfanim.h>
 #include <stdarg.h>
+#include <svnversion.h>
+
+CF_PLUGIN char SvnRevPlugin[] = SVN_REV;
 
 static CFanimation *first_animation = NULL;  /**< Animations we're currently processing. */
 
@@ -109,12 +112,13 @@ static long int initturn(const char *name, char *parameters, struct CFmovement_s
 static anim_move_result runturn(struct CFanimation_struct *animation, long int id, void *parameters) {
     object *op = animation->victim;
     int dir = id;
-    int face;
+    /*int face;*/
 
     if (animation->verbose)
         cf_log(llevDebug, "CFAnim: Turning in direction %ld\n", id);
     op->facing = dir;
-    cf_object_set_int_property(op, CFAPI_OBJECT_PROP_ANIMATION, face);
+    /** @todo fix suspicious or missing call */
+/*    cf_object_set_int_property(op, CFAPI_OBJECT_PROP_ANIMATION, face);*/
     return mr_finished;
 }
 
@@ -206,7 +210,7 @@ static anim_move_result runapply(struct CFanimation_struct *animation, long int
 }
 
 static long int initapplyobject(const char *name, char *parameters, struct CFmovement_struct *move_entity) {
-    move_entity->parameters = parameters ? cf_add_string(parameters) : NULL;
+    move_entity->parameters = parameters ? (void*)cf_add_string(parameters) : NULL;
     return 1;
 }
 
@@ -261,7 +265,7 @@ static anim_move_result runpickup(struct CFanimation_struct *animation, long int
 }
 
 static long int initpickupobject(const char *name, char *parameters, struct CFmovement_struct *move_entity) {
-    move_entity->parameters = parameters ? cf_add_string(parameters) : NULL;
+    move_entity->parameters = parameters ? (void*)cf_add_string(parameters) : NULL;
     return 1;
 }
 
@@ -686,23 +690,6 @@ static int is_animated_object(const object *ob) {
     return 0;
 }
 
-/**
- * Is specified player currently victim of a paralysing animation?
- * @param pl player to search for.
- * @return 1 if pl is part of animation, 0 else.
- */
-static int is_animated_player(object *pl) {
-    CFanimation *current;
-
-    for (current = first_animation; current; current = current->nextanimation)
-        if ((current->victim == pl) && (current->paralyze)) {
-            if (current->verbose)
-                cf_log(llevDebug, "CFAnim: Getting a command for a paralyzed player %s.\n", pl->name);
-            return 1;
-        }
-    return 0;
-}
-
 /**
  * Create a new animation.
  * @return new animation pointer inserted in the list of animations.
@@ -1152,14 +1139,14 @@ CF_PLUGIN int eventListener(int *type, ...) {
     int rv = 0;
     va_list args;
     char *buf, message[MAX_BUF], script[MAX_BUF];
-    object *who, *activator, *third, *event;
+    object *who, *activator/*, *third*/, *event;
     int query;
 
     va_start(args, type);
 
     who = va_arg(args, object *);
     activator = va_arg(args, object *);
-    third = va_arg(args, object *);
+    /*third =*/ va_arg(args, object *);
     buf = va_arg(args, char *);
 
     if (buf != NULL)
