@@ -52,6 +52,9 @@
 /*#include <stdarg.h>*/
 
 #include <sqlite3.h>
+#include <svnversion.h>
+
+CF_PLUGIN char SvnRevPlugin[] = SVN_REV;
 
 /** Current database format */
 #define CFLOGGER_CURRENT_FORMAT 3
@@ -200,10 +203,10 @@ static int update_table_format(const char *table, const char *newschema,
  */
 static void check_tables(void) {
     int format;
-    int err;
+    /*int err;*/
     format = 0;
 
-    err = sqlite3_exec(database, "select param_value from parameters where param_name = 'version';", check_tables_callback, &format, NULL);
+    /*err =*/ sqlite3_exec(database, "select param_value from parameters where param_name = 'version';", check_tables_callback, &format, NULL);
 
     /* Safety check. */
     if (format > CFLOGGER_CURRENT_FORMAT) {
@@ -626,7 +629,7 @@ CF_PLUGIN int cflogger_globalEventListener(int *type, ...) {
     va_list args;
     int rv = 0;
     player *pl;
-    object *op;
+    object *op/*, *op2*/;
     int event_code;
     mapstruct *map;
 
@@ -635,7 +638,6 @@ CF_PLUGIN int cflogger_globalEventListener(int *type, ...) {
 
     switch (event_code) {
     case EVENT_BORN:
-    case EVENT_PLAYER_DEATH:
     case EVENT_REMOVE:
     case EVENT_MUZZLE:
     case EVENT_KICK:
@@ -643,6 +645,12 @@ CF_PLUGIN int cflogger_globalEventListener(int *type, ...) {
         add_player_event(op, event_code);
         break;
 
+    case EVENT_PLAYER_DEATH:
+        op = va_arg(args, object *);
+        /*op2 =*/ va_arg(args, object *);
+        add_player_event(op, event_code);
+        break;
+
     case EVENT_LOGIN:
     case EVENT_LOGOUT:
         pl = va_arg(args, player *);
