@@ -34,6 +34,9 @@
 #include <cfnewspaper_proto.h>
 #endif
 #include <sqlite3.h>
+#include <svnversion.h>
+
+CF_PLUGIN char SvnRevPlugin[] = SVN_REV;
 
 f_plug_api gethook;
 
@@ -61,30 +64,6 @@ static void do_sql(const char *sql, sqlite3 *base) {
     }
 }
 
-static int get_living_id(object *living) {
-    char **line;
-    char *sql;
-    int nrow, ncolumn, id;
-
-    if (living->type == PLAYER)
-        sql = sqlite3_mprintf("select liv_id from living where liv_name='%q' and liv_is_player = 1", living->name);
-    else
-        sql = sqlite3_mprintf("select liv_id from living where liv_name='%q' and liv_is_player = 0 and liv_level = %d", living->name, living->level);
-    sqlite3_get_table(logger_database, sql, &line, &nrow, &ncolumn, NULL);
-    /* printf("get_table: nrow = %d, ncolumn = %d\n", nrow, ncolumn); */
-    if (nrow > 0)
-        id = atoi(line[ncolumn]);
-    else {
-        sqlite3_free(sql);
-        sql = sqlite3_mprintf("insert into living(liv_name, liv_is_player, liv_level) values('%q', %d, %d)", living->name, living->type == PLAYER ? 1 : 0, living->level);
-        do_sql(sql, logger_database);
-        id = sqlite3_last_insert_rowid(logger_database);
-    }
-    sqlite3_free(sql);
-    sqlite3_free_table(line);
-    return id;
-}
-
 static int get_region_id(region *reg) {
     char **line;
     char *sql;
@@ -113,29 +92,6 @@ static void format_time(timeofday_t *tod, char *buffer, int size) {
     snprintf(buffer, size, "%10d-%2d-%2d %2d:%2d", tod->year, tod->month, tod->day, tod->hour, tod->minute);
 }
 
-static int get_time_id(timeofday_t *tod, int create) {
-    char **line;
-    char *sql;
-    int nrow, ncolumn, id = 0;
-    char date[50];
-
-    format_time(tod, date, 50);
-
-    sql = sqlite3_mprintf("select time_id from time where time_time='%q'", date);
-    sqlite3_get_table(logger_database, sql, &line, &nrow, &ncolumn, NULL);
-    if (nrow > 0)
-        id = atoi(line[ncolumn]);
-    else if (create) {
-        sqlite3_free(sql);
-        sql = sqlite3_mprintf("insert into time(time_time) values( '%q' )", date);
-        do_sql(sql, logger_database);
-        id = sqlite3_last_insert_rowid(logger_database);
-    }
-    sqlite3_free(sql);
-    sqlite3_free_table(line);
-    return id;
-}
-
 static void read_parameters(void) {
 }
 
@@ -267,10 +223,12 @@ static void do_kills(char *buffer, int size, time_t start, time_t end, const cha
     int nrow, ncolumn;
     int err;
     char *msg;
-    const char *raw = "select sum(1) as deaths from kill_event inner join living on liv_id = ke_victim_id where liv_is_player = %d and ke_time >= %d and ke_time < %d %s";
+    const char *raw_players = "select sum(1) as deaths from kill_event inner join living on liv_id = ke_victim_id where liv_is_player = %d and ke_time >= %d and ke_time < %d %s";
+    const char *raw_monsters = "select sum(1) as deaths from kill_event inner join living on liv_id = ke_victim_id where liv_is_player = %d and ke_time >= %d and ke_time < %d";
 
-    sql = sqlite3_mprintf(raw, 1, start, end, reg);
+    sql = sqlite3_mprintf(raw_players, 1, start, end, reg);
     err = sqlite3_get_table(logger_database, sql, &results, &nrow, &ncolumn, &msg);
+    sqlite3_free(sql);
     if (err != SQLITE_OK) {
         cf_log(llevError, " [%s] error: %d [%s] for sql = %s\n", PLUGIN_NAME, err, msg, sql);
         sqlite3_free(msg);
@@ -287,8 +245,9 @@ static void do_kills(char *buffer, int size, time_t start, time_t end, const cha
         news_cat(buffer, size, format->many_player_death, deaths);
     news_cat(buffer, size, "\n");
 
-    sql = sqlite3_mprintf(raw, 0, start, end);
+    sql = sqlite3_mprintf(raw_monsters, 0, start, end);
     err = sqlite3_get_table(logger_database, sql, &results, &nrow, &ncolumn, &msg);
+    sqlite3_free(sql);
     if (err != SQLITE_OK) {
         cf_log(llevError, " [%s] error: %d [%s] for sql = %s\n", PLUGIN_NAME, err, msg, sql);
         sqlite3_free(msg);
@@ -337,7 +296,7 @@ static void do_world_kills(char *buffer, int size, time_t start, time_t end) {
     f.one_player_death = "Only one player died in the whole world, May Fido(tm) Have Mercy.";
     f.many_player_death = "Monsters all around the world were busy, %d players died.";
     f.no_monster_death = "No monster was killed at all, players must be tired!";
-    f.one_monster_death = "One poor monster was killed in the whole, too bad for it.";
+    f.one_monster_death = "One poor monster was killed in the whole world, too bad for it.";
     f.many_monster_death = "Bad day for monsters, with %d dead in their ranks.";
     do_kills(buffer, size, start, end, "", &f);
 }
@@ -367,6 +326,7 @@ static void get_newspaper_content(object *paper, paper_properties *properties, r
 
     sql = sqlite3_mprintf("select * from time where time_ingame < '%q' order by time_ingame desc", date);
     err = sqlite3_get_table(logger_database, sql, &results, &nrow, &ncolumn, &msg);
+    sqlite3_free(sql);
     if (err != SQLITE_OK) {
         cf_log(llevError, " [%s] error: %d [%s] for sql = %s\n", PLUGIN_NAME, err, msg, sql);
         sqlite3_free(msg);
@@ -394,10 +354,10 @@ CF_PLUGIN int eventListener(int *type, ...) {
     object *who;
     int event_code;
     object *activator;
-    object *third;
+    /*object *third;*/
     object *event;
-    char *buf;
-    int fix;
+    /*char *buf;*/
+    /*int fix;*/
     object *newspaper;
     paper_properties *paper;
     region *reg;
@@ -406,9 +366,9 @@ CF_PLUGIN int eventListener(int *type, ...) {
     who = va_arg(args, object *);
     /*event_code = va_arg(args, int);*/
     activator = va_arg(args, object *);
-    third = va_arg(args, object *);
-    buf = va_arg(args, char *);
-    fix = va_arg(args, int);
+    /*third =*/ va_arg(args, object *);
+    /*buf =*/ va_arg(args, char *);
+    /*fix =*/ va_arg(args, int);
     /*buf = va_arg(args, char *);*/
     event = va_arg(args, object *);
     event_code = event->subtype;
