@@ -60,18 +60,37 @@
 #include <cfpython.h>
 #include <stdarg.h>
 #include <node.h>
+#include <svnversion.h>
+
+CF_PLUGIN char SvnRevPlugin[] = SVN_REV;
 
 #define PYTHON_DEBUG   /* give us some general infos out */
 #define PYTHON_CACHE_SIZE 16    /* number of python scripts to store the bytecode of at a time */
 
+/**
+ * One compiled script, cached in memory.
+ */
 typedef struct {
-    sstring file;
-    PyCodeObject *code;
-    time_t cached_time, used_time;
+    sstring file;                   /**< Script full path. */
+    PyCodeObject *code;             /**< Compiled code, NULL if there was an error. */
+    time_t cached_time,             /**< Time this cache entry was created. */
+            used_time;              /**< Last use of this cache entry. */
 } pycode_cache_entry;
 
+/* This structure is used to define one python-implemented crossfire command.*/
+typedef struct PythonCmdStruct {
+    sstring name;   /* The name of the command, as known in the game.         */
+    sstring script; /* The name of the script file to bind.                   */
+    double speed;   /* The speed of the command execution.                    */
+} PythonCmd;
+
+/* This plugin allows up to 1024 custom commands.                            */
+#define NR_CUSTOM_CMD 1024
+
+/** Commands defined by scripts. */
 static PythonCmd CustomCommand[NR_CUSTOM_CMD];
 
+/** Cached compiled scripts. */
 static pycode_cache_entry pycode_cache[PYTHON_CACHE_SIZE];
 
 static void set_exception(const char *fmt, ...);
@@ -523,8 +542,8 @@ static PyObject *registerCommand(PyObject *self, PyObject *args) {
     }
     for (i = 0; i < NR_CUSTOM_CMD; i++) {
         if (CustomCommand[i].name == NULL) {
-            CustomCommand[i].name = cf_strdup_local(cmdname);
-            CustomCommand[i].script = cf_strdup_local(scriptname);
+            CustomCommand[i].name = cf_add_string(cmdname);
+            CustomCommand[i].script = cf_add_string(scriptname);
             CustomCommand[i].speed = cmdspeed;
             break;
         }
@@ -812,23 +831,48 @@ static FILE* cfpython_pyfile_asfile(PyObject* obj) {
 #endif
 }
 
+/**
+ * A Python object receiving the contents of Python's stderr, and used to output
+ * to the Crossfire log instead of stderr.
+ */
+static PyObject *catcher = NULL;
+
+/**
+ * Trace a Python error to the Crossfire log.
+ * This uses code from:
+ * http://stackoverflow.com/questions/4307187/how-to-catch-python-stdout-in-c-code
+ * See also in initPlugin() the parts about stdOutErr.
+ */
+static void log_python_error(void) {
+
+    PyErr_Print();
+
+    if (catcher != NULL) {
+        PyObject *output = PyObject_GetAttrString(catcher, "value"); //get the stdout and stderr from our catchOutErr object
+        PyObject* empty = PyString_FromString("");
+
+        cf_log_plain(llevError, PyString_AsString(output));
+        Py_DECREF(output);
+
+        PyObject_SetAttrString(catcher, "value", empty);
+        Py_DECREF(empty);
+    }
+
+    return;
+}
+
+
 /** Outputs the compiled bytecode for a given python file, using in-memory caching of bytecode */
 static PyCodeObject *compilePython(char *filename) {
-    PyObject *scriptfile;
+    PyObject *scriptfile = NULL;
     sstring sh_path;
     struct stat stat_buf;
     struct _node *n;
     int i;
     pycode_cache_entry *replace = NULL, *run = NULL;
-    if (!(scriptfile = cfpython_openpyfile(filename))) {
-        cf_log(llevDebug, "cfpython - The Script file %s can't be opened\n", filename);
-        return NULL;
-    }
+
     if (stat(filename, &stat_buf)) {
         cf_log(llevDebug, "cfpython - The Script file %s can't be stat:ed\n", filename);
-        if (scriptfile) {
-            Py_DECREF(scriptfile);
-        }
         return NULL;
     }
 
@@ -873,12 +917,16 @@ static PyCodeObject *compilePython(char *filename) {
             replace->file = cf_add_string(sh_path);
         }
 
-        /* Load, parse and compile */
-        if (!scriptfile && !(scriptfile = cfpython_openpyfile(filename))) {
+        /* Load, parse and compile. Note: because Pyhon may have been built with a
+         * different library than Crossfire, the FILE* it uses may be incompatible.
+         * Therefore we use PyFile to open the file, then convert to FILE* and get
+         * Python's own structure. Messy, but can't be helped...  */
+        if (!(scriptfile = cfpython_openpyfile(filename))) {
             cf_log(llevDebug, "cfpython - The Script file %s can't be opened\n", filename);
-            replace->code = NULL;
+            cf_free_string(sh_path);
             return NULL;
         } else {
+            /* Note: FILE* being opaque, it works, but the actual structure may be different! */
             FILE* pyfile = cfpython_pyfile_asfile(scriptfile);
             if ((n = PyParser_SimpleParseFile(pyfile, filename, Py_file_input))) {
                 replace->code = PyNode_Compile(n, filename);
@@ -886,7 +934,7 @@ static PyCodeObject *compilePython(char *filename) {
             }
 
             if (PyErr_Occurred())
-                PyErr_Print();
+                log_python_error();
             else
                 replace->cached_time = stat_buf.st_mtime;
             run = replace;
@@ -899,9 +947,10 @@ static PyCodeObject *compilePython(char *filename) {
         Py_DECREF(scriptfile);
     }
 
-    if (run)
+    if (run) {
+        run->used_time = time(NULL);
         return run->code;
-    else
+    } else
         return NULL;
 }
 
@@ -921,7 +970,7 @@ static int do_script(CFPContext *context, int silent) {
         PyDict_SetItemString(dict, "__builtins__", PyEval_GetBuiltins());
         ret = PyEval_EvalCode(pycode, dict, NULL);
         if (PyErr_Occurred()) {
-            PyErr_Print();
+            log_python_error();
         }
         Py_XDECREF(ret);
 #if 0
@@ -1047,7 +1096,6 @@ static void initConstants(PyObject *module) {
         { "TELEPORTER", TELEPORTER },
         { "CREATOR", CREATOR },
         { "SKILL", SKILL },
-        { "EXPERIENCE", EXPERIENCE },
         { "EARTHWALL", EARTHWALL },
         { "GOLEM", GOLEM },
         { "THROWN_OBJ", THROWN_OBJ },
@@ -1151,6 +1199,7 @@ static void initConstants(PyObject *module) {
         { "NDI_TAN", NDI_TAN },
         { "NDI_UNIQUE", NDI_UNIQUE },
         { "NDI_ALL", NDI_ALL },
+        { "NDI_ALL_DMS", NDI_ALL_DMS },
         { NULL, 0 }
     };
 
@@ -1365,6 +1414,18 @@ static PyObject* PyInit_Crossfire(void)
 CF_PLUGIN int initPlugin(const char *iversion, f_plug_api gethooksptr) {
     PyObject *m;
     int i;
+    /* Python code to redirect stdouts/stderr. */
+    const char *stdOutErr =
+"import sys\n\
+class CatchOutErr:\n\
+    def __init__(self):\n\
+        self.value = ''\n\
+    def write(self, txt):\n\
+        self.value += txt\n\
+catchOutErr = CatchOutErr()\n\
+sys.stdout = catchOutErr\n\
+sys.stderr = catchOutErr\n\
+";
 
     cf_init_plugin(gethooksptr);
     cf_log(llevDebug, "CFPython 2.0a init\n");
@@ -1400,6 +1461,12 @@ CF_PLUGIN int initPlugin(const char *iversion, f_plug_api gethooksptr) {
     private_data = PyDict_New();
     shared_data = PyDict_New();
 
+    /* Redirect Python's stderr to a special object so it can be put to
+     * the Crossfire log. */
+    m = PyImport_AddModule("__main__");
+    PyRun_SimpleString(stdOutErr);
+    catcher = PyObject_GetAttrString(m, "catchOutErr");
+
 #ifndef IS_PY3K
     /* add cjson module*/
     initcjson();
@@ -1490,6 +1557,7 @@ CF_PLUGIN void cfpython_runPluginCommand(object *op, const char *params) {
 CF_PLUGIN int postInitPlugin(void) {
     PyObject *scriptfile;
     char path[1024];
+    int i;
 
     cf_log(llevDebug, "CFPython 2.0a post init\n");
     initContextStack();
@@ -1518,6 +1586,13 @@ CF_PLUGIN int postInitPlugin(void) {
         Py_DECREF(scriptfile);
     }
 
+    for (i = 0; i < PYTHON_CACHE_SIZE; i++) {
+        pycode_cache[i].code = NULL;
+        pycode_cache[i].file = NULL;
+        pycode_cache[i].cached_time = 0;
+        pycode_cache[i].used_time = 0;
+    }
+
     return 0;
 }
 
@@ -1557,6 +1632,8 @@ CF_PLUGIN int cfpython_globalEventListener(int *type, ...) {
     case EVENT_PLAYER_DEATH:
         op = va_arg(args, object *);
         context->who = Crossfire_Object_wrap(op);
+        op = va_arg(args, object *);
+        context->activator = Crossfire_Object_wrap(op);
         snprintf(context->options, sizeof(context->options), "death");
         break;
 
@@ -1724,7 +1801,24 @@ CF_PLUGIN int eventListener(int *type, ...) {
 }
 
 CF_PLUGIN int   closePlugin(void) {
+    int i;
+
     cf_log(llevDebug, "CFPython 2.0a closing\n");
+
+    for (i = 0; i < NR_CUSTOM_CMD; i++) {
+        if (CustomCommand[i].name != NULL)
+            cf_free_string(CustomCommand[i].name);
+        if (CustomCommand[i].script != NULL)
+            cf_free_string(CustomCommand[i].script);
+    }
+
+    for (i = 0; i < PYTHON_CACHE_SIZE; i++) {
+        Py_XDECREF(pycode_cache[i].code);
+        if (pycode_cache[i].file != NULL)
+            cf_free_string(pycode_cache[i].file);
+    }
+
     Py_Finalize();
+
     return 0;
 }
