@@ -800,7 +800,7 @@ static PyObject *Object_GetArchetype(Crossfire_Object *whoptr, void *closure) {
 
 static PyObject *Object_GetNoSave(Crossfire_Object *whoptr, void *closure) {
     EXISTCHECK(whoptr);
-    return Py_BuildValue("i", cf_object_get_int_property(whoptr->obj, CFAPI_OBJECT_PROP_NO_SAVE));
+    return Py_BuildValue("i", cf_object_get_flag(whoptr->obj, FLAG_NO_SAVE));
 }
 
 static PyObject *Object_GetExists(Crossfire_Object *whoptr, void *closure) {
@@ -1708,17 +1708,6 @@ static int Object_SetUnique(Crossfire_Object *whoptr, PyObject *value, void *clo
     return 0;
 }
 
-static int Object_SetCanPassThru(Crossfire_Object *whoptr, PyObject *value, void *closure) {
-    int val;
-
-    EXISTCHECK_INT(whoptr);
-    if (!PyArg_Parse(value, "i", &val))
-        return -1;
-    /* FIXME */
-    /*cf_object_set_flag(whoptr->obj, FLAG_CAN_PASS_THRU, val);*/
-    return 0;
-}
-
 static int Object_SetRunAway(Crossfire_Object *whoptr, PyObject *value, void *closure) {
     int val;
 
@@ -1825,7 +1814,7 @@ static int Object_SetNoSave(Crossfire_Object *whoptr, PyObject *value, void *clo
     if (!PyArg_Parse(value, "i", &val))
         return -1;
 
-    cf_object_set_long_property(whoptr->obj, CFAPI_OBJECT_PROP_NO_SAVE, val);
+    cf_object_set_flag(whoptr->obj, FLAG_NO_SAVE, val);
     return 0;
 }
 
@@ -2455,7 +2444,10 @@ static PyObject *Crossfire_Object_RemoveDepletion(Crossfire_Object *who, PyObjec
     return Py_BuildValue("i", cf_object_remove_depletion(who->obj, level));
 }
 
-
+static PyObject *Crossfire_Object_Arrest(Crossfire_Object *who, PyObject *args) {
+    EXISTCHECK(who);
+    return Py_BuildValue("i", cf_player_arrest(who->obj));
+}
 
 static int Crossfire_Object_InternalCompare(Crossfire_Object *left, Crossfire_Object *right) {
     EXISTCHECK_INT(left);
