@@ -30,53 +30,80 @@
 #include <cfpython.h>
 #include <cfpython_party_private.h>
 
-static PyObject* Crossfire_Party_GetName( Crossfire_Party* partyptr, void* closure)
-{
-    return Py_BuildValue("s",cf_party_get_name(partyptr->party));
+static PyObject *Crossfire_Party_GetName(Crossfire_Party *partyptr, void *closure) {
+    return Py_BuildValue("s", cf_party_get_name(partyptr->party));
 }
 
-static PyObject* Crossfire_Party_GetPassword( Crossfire_Party* partyptr, void* closure)
-{
-    return Py_BuildValue("s",cf_party_get_password(partyptr->party));
+static PyObject *Crossfire_Party_GetPassword(Crossfire_Party *partyptr, void *closure) {
+    return Py_BuildValue("s", cf_party_get_password(partyptr->party));
 }
 
-static PyObject* Crossfire_Party_GetNext( Crossfire_Party* party, void* closure )
-{
+static PyObject *Crossfire_Party_GetNext(Crossfire_Party *party, void *closure) {
     return Crossfire_Party_wrap(cf_party_get_next(party->party));
 }
 
-static PyObject* Crossfire_Party_GetPlayers( Crossfire_Party* party, PyObject* args )
-{
-    PyObject* list;
-    player* pl;
+static PyObject *Crossfire_Party_GetPlayers(Crossfire_Party *party, PyObject *args) {
+    PyObject *list;
+    player *pl;
 
     list = PyList_New(0);
     pl = cf_party_get_first_player(party->party);
-    while (pl)
-    {
-        PyList_Append(list,Crossfire_Object_wrap(pl->ob));
-        pl = cf_party_get_next_player(party->party,pl);
+    while (pl) {
+        PyList_Append(list, Crossfire_Object_wrap(pl->ob));
+        pl = cf_party_get_next_player(party->party, pl);
     }
     return list;
 }
 
-PyObject *Crossfire_Party_wrap(partylist *what)
-{
+PyObject *Crossfire_Party_wrap(partylist *what) {
     Crossfire_Party *wrapper;
 
     /* return None if no object was to be wrapped */
-    if(what == NULL) {
+    if (what == NULL) {
         Py_INCREF(Py_None);
         return Py_None;
     }
 
     wrapper = PyObject_NEW(Crossfire_Party, &Crossfire_PartyType);
-    if(wrapper != NULL)
+    if (wrapper != NULL)
         wrapper->party = what;
     return (PyObject *)wrapper;
 }
 
-static int Crossfire_Party_InternalCompare(Crossfire_Party* left, Crossfire_Party* right)
-{
-    return (left->party < right->party ? -1 : ( left->party == right->party ? 0 : 1 ) );
+static int Crossfire_Party_InternalCompare(Crossfire_Party *left, Crossfire_Party *right) {
+    return (left->party < right->party ? -1 : (left->party == right->party ? 0 : 1));
+}
+
+static PyObject *Crossfire_Party_RichCompare(Crossfire_Party *left, Crossfire_Party *right, int op) {
+    int result;
+    if (!left
+        || !right
+        || !PyObject_TypeCheck((PyObject*)left, &Crossfire_PartyType)
+        || !PyObject_TypeCheck((PyObject*)right, &Crossfire_PartyType)) {
+        Py_INCREF(Py_NotImplemented);
+        return Py_NotImplemented;
+    }
+    result = Crossfire_Party_InternalCompare(left, right);
+    /* Based on how Python 3.0 (GPL compatible) implements it for internal types: */
+    switch (op) {
+        case Py_EQ:
+            result = (result == 0);
+            break;
+        case Py_NE:
+            result = (result != 0);
+            break;
+        case Py_LE:
+            result = (result <= 0);
+            break;
+        case Py_GE:
+            result = (result >= 0);
+            break;
+        case Py_LT:
+            result = (result == -1);
+            break;
+        case Py_GT:
+            result = (result == 1);
+            break;
+    }
+    return PyBool_FromLong(result);
 }
