@@ -24,35 +24,46 @@
 /*  You should have received a copy of the GNU General Public License        */
 /*  along with this program; if not, write to the Free Software              */
 /*  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.                */
-/*                                                                           */ /*****************************************************************************/
+/*                                                                           */
+/*****************************************************************************/
 #ifndef CFPYTHON_OBJECT_H
 #define CFPYTHON_OBJECT_H
+
 typedef struct {
     PyObject_HEAD
-            object *obj;
-            int valid;
-            object *del_event;
+    object *obj;
+    tag_t count;
 } Crossfire_Object;
+
 extern PyTypeObject Crossfire_ObjectType;
 
 typedef struct {
     PyObject_HEAD
-            object *obj;
-            int valid;
-            object *del_event;
+    object *obj;
+    tag_t count;
 } Crossfire_Player;
+
 extern PyTypeObject Crossfire_PlayerType;
 
-#define EXISTCHECK( ob ) \
-    { \
-    if (!ob || ((ob)->valid == 0)) { \
+#define EXISTCHECK(ob) { \
+    if (!ob || !ob->obj || (object_was_destroyed(ob->obj, ob->obj->count))) { \
         PyErr_SetString(PyExc_ReferenceError, "Crossfire object no longer exists"); \
         return NULL; \
     } }
-    
-#define EXISTCHECK_INT( ob ) \
-    { \
-    if (!ob || ((ob)->valid == 0)) { \
+
+/**
+ * This is meant to be used for parameters where you don't know if the type of
+ * the object is correct. It should NOT be used for the self pointer, since that
+ * will always be a compatible type.
+ */
+#define TYPEEXISTCHECK(ob) { \
+    if (!ob || !PyObject_TypeCheck((PyObject*)ob, &Crossfire_ObjectType) || !ob->obj || (object_was_destroyed(ob->obj, ob->obj->count))) { \
+        PyErr_SetString(PyExc_ReferenceError, "Not a Crossfire object or Crossfire object no longer exists"); \
+        return NULL; \
+    } }
+
+#define EXISTCHECK_INT(ob) { \
+    if (!ob || !ob->obj || (object_was_destroyed(ob->obj, ob->obj->count))) { \
         PyErr_SetString(PyExc_ReferenceError, "Crossfire object no longer exists"); \
         return -1; \
     } }
