@@ -249,7 +249,6 @@ static PyObject *Crossfire_Object_Clone(Crossfire_Object *who, PyObject *args);
 static PyObject *Crossfire_Object_Split(Crossfire_Object *who, PyObject *args);
 static PyObject *Crossfire_Object_Fix(Crossfire_Object *who, PyObject *args);
 static PyObject *Crossfire_Object_Say(Crossfire_Object *who, PyObject *args);
-static PyObject *Crossfire_Object_Pickup(Crossfire_Object *who, PyObject *args);
 static PyObject *Crossfire_Object_Take(Crossfire_Object *who, PyObject *args);
 static PyObject *Crossfire_Object_Teleport(Crossfire_Object *who, PyObject *args);
 static PyObject *Crossfire_Object_Reposition(Crossfire_Object *who, PyObject *args);
@@ -280,6 +279,7 @@ static PyObject *Crossfire_Object_Move(Crossfire_Object *who, PyObject *args);
 static PyObject *Crossfire_Object_ChangeAbil(Crossfire_Object *who, PyObject *args);
 static PyObject *Crossfire_Object_Event(Crossfire_Object *who, PyObject *args);
 static PyObject *Crossfire_Object_RemoveDepletion(Crossfire_Object *who, PyObject *args);
+static PyObject *Crossfire_Object_Arrest(Crossfire_Object *who, PyObject *args);
 static PyObject *Object_GetMaterial(Crossfire_Object *whoptr, void *closure);
 
 static int Crossfire_Object_InternalCompare(Crossfire_Object *left, Crossfire_Object *right);
@@ -462,6 +462,7 @@ static PyMethodDef ObjectMethods[] = {
     { "ChangeAbil",     (PyCFunction)Crossfire_Object_ChangeAbil,   METH_O,       NULL },
     { "Event",          (PyCFunction)Crossfire_Object_Event,        METH_VARARGS, NULL },
     { "RemoveDepletion",(PyCFunction)Crossfire_Object_RemoveDepletion,    METH_VARARGS, NULL },
+    { "Arrest",         (PyCFunction)Crossfire_Object_Arrest,    METH_VARARGS, NULL },
     { NULL, NULL, 0, NULL }
 };
 
