@@ -51,11 +51,13 @@
 # else
 #  define MODULEAPI __declspec(dllimport)
 # endif
-#elif HAVE_VISIBILITY
+#else
+#ifdef HAVE_VISIBILITY
 # define MODULEAPI __attribute__((visibility("default")))
 #else
 # define MODULEAPI
 #endif
+#endif
 
 #include <plugin_common.h>
 #include <cfrhg.h>
