@@ -31,11 +31,13 @@
 
 #ifdef WIN32
 #define CF_PLUGIN __declspec(dllexport)
-#elif HAVE_VISIBILITY
+#else
+#ifdef HAVE_VISIBILITY
 #define CF_PLUGIN __attribute__((visibility("default")))
 #else
 #define CF_PLUGIN
 #endif
+#endif
 
 #include <plugin.h>
 
@@ -145,6 +147,7 @@ extern object      *cf_object_split(object *orig_ob, uint32 nr, char *err, size_
 extern object      *cf_object_clone(object *op, int clonetype);
 extern int          cf_object_set_face(object *op, const char *face);
 extern int          cf_object_set_animation(object *op, const char *animation);
+extern object      *cf_identify(object *op);
 /* Maps */
 /*extern void        *cf_map_get_property(mapstruct *map, int propcode);*/
 extern sstring cf_map_get_sstring_property(mapstruct *map, int propcode);
@@ -195,6 +198,7 @@ extern partylist   *cf_player_get_party(object *op);
 extern void         cf_player_set_party(object *op, partylist *party);
 extern int          cf_player_can_pay(object *op);
 extern int          cf_player_knowledge_has(object *op, const char *knowledge);
+extern int          cf_player_arrest(object *who);
 
 /* Archetypes */
 extern archetype   *cf_archetype_get_first(void);
@@ -219,6 +223,9 @@ extern region      *cf_region_get_next(region *reg);
 extern region      *cf_region_get_parent(region *reg);
 extern const char  *cf_region_get_longname(region *reg);
 extern const char  *cf_region_get_message(region *reg);
+extern int         cf_region_get_jail_x(region *reg);
+extern int         cf_region_get_jail_y(region *reg);
+extern const char  *cf_region_get_jail_path(region *reg);
 
 /* Friendly list */
 extern object      *cf_friendlylist_get_first(void);
