@@ -64,7 +64,6 @@ static f_plug_api cfapiObject_transmute = NULL;
 static f_plug_api cfapiObject_remove = NULL;
 static f_plug_api cfapiObject_delete = NULL;
 static f_plug_api cfapiObject_clone = NULL;
-static f_plug_api cfapiObject_find = NULL;
 static f_plug_api cfapiObject_create = NULL;
 static f_plug_api cfapiObject_insert = NULL;
 static f_plug_api cfapiObject_split = NULL;
@@ -73,7 +72,6 @@ static f_plug_api cfapiObject_distance = NULL;
 static f_plug_api cfapiObject_update = NULL;
 static f_plug_api cfapiObject_clear = NULL;
 static f_plug_api cfapiObject_reset = NULL;
-static f_plug_api cfapiCheck_inventory = NULL;
 static f_plug_api cfapiObject_activate_rune = NULL;
 static f_plug_api cfapiObject_check_trigger = NULL;
 static f_plug_api cfapiObject_query_money = NULL;
@@ -105,7 +103,6 @@ static f_plug_api cfapiMap_change_light = NULL;
 static f_plug_api cfapiMap_trigger_connected = NULL;
 static f_plug_api cfapiPlayer_find = NULL;
 static f_plug_api cfapiPlayer_message = NULL;
-static f_plug_api cfapiPlayer_send_inventory = NULL;
 static f_plug_api cfapiObject_teleport = NULL;
 static f_plug_api cfapiObject_pickup = NULL;
 static f_plug_api cfapiObject_get_key = NULL;
@@ -162,7 +159,6 @@ int cf_init_plugin(f_plug_api getHooks) {
     GET_HOOK(cfapiObject_remove, "cfapi_object_remove", z);
     GET_HOOK(cfapiObject_delete, "cfapi_object_delete", z);
     GET_HOOK(cfapiObject_clone, "cfapi_object_clone", z);
-    GET_HOOK(cfapiObject_find, "cfapi_object_find", z);
     GET_HOOK(cfapiObject_create, "cfapi_object_create", z);
     GET_HOOK(cfapiObject_insert, "cfapi_object_insert", z);
     GET_HOOK(cfapiObject_split, "cfapi_object_split", z);
@@ -790,6 +786,21 @@ int cf_object_remove_depletion(object *op, int level) {
     return result;
 }
 
+/**
+ * Wrapper for identify().
+ * @copydoc identify()
+ * @param op
+ * @return 
+ */
+object *cf_identify(object *op) {
+    int type;
+    object *result;
+
+    cfapiObject_identify(&type, op, &result);
+    assert(type == CFAPI_POBJECT);
+    return result;
+}
+
 /**
  * Wrapper for find_player_partial_name().
  * @copydoc find_player_partial_name().
@@ -877,6 +888,17 @@ int cf_player_knowledge_has(object *op, const char *knowledge) {
     return value;
 }
 
+/**
+ * Wrapper for player_arrest().
+ * @copydoc player_arrest()
+ */
+int cf_player_arrest(object *who) {
+    int type, value;
+    cfapiObject_move(&type, 2, who, &value);
+    assert(type == CFAPI_INT);
+    return value;
+}
+
 /**
  * Wrapper for ready_map_name().
  * @copydoc ready_map_name()
@@ -1943,6 +1965,52 @@ const char *cf_region_get_message(region *reg) {
     return value;
 }
 
+/**
+ * Get region's jail x coordinate.
+ * @param reg
+ * region. Mustn't be NULL.
+ * @return
+ * region's x coordinate for jail.
+ */
+int cf_region_get_jail_x(region *reg) {
+    int type, value;
+
+    cfapiRegion_get_property(&type, reg, CFAPI_REGION_PROP_JAIL_X, &value);
+    assert(type == CFAPI_INT);
+    return value;
+}
+
+/**
+ * Get region's jail y coordinate.
+ * @param reg
+ * region. Mustn't be NULL.
+ * @return
+ * region's y coordinate for jail.
+ */
+int cf_region_get_jail_y(region *reg) {
+    int type, value;
+
+    cfapiRegion_get_property(&type, reg, CFAPI_REGION_PROP_JAIL_Y, &value);
+    assert(type == CFAPI_INT);
+    return value;
+}
+
+/**
+ * Get jail path of region.
+ * @param reg
+ * region. Mustn't be NULL.
+ * @return
+ * region's jail path, can be NULL.
+ */
+const char *cf_region_get_jail_path(region *reg) {
+    int type;
+    sstring value;
+
+    cfapiRegion_get_property(&type, reg, CFAPI_REGION_PROP_JAIL_PATH, &value);
+    assert(type == CFAPI_SSTRING);
+    return value;
+}
+
 /* Friendlylist functions. */
 
 /**
