@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_floor_c =
- *   "$Id: floor.c 12016 2009-06-24 19:17:15Z akirschbaum $";
+ *   "$Id: floor.c 14925 2011-07-30 21:01:42Z ryo_saeba $";
  */
 
 /*
@@ -86,7 +86,6 @@ static void put_floor(mapstruct *map, char **layout, int x, int y, object *floor
  */
 mapstruct *make_map_floor(char **layout, char *floorstyle, RMParms *RP) {
     char styledirname[256];
-    char stylefilepath[256];
     mapstruct *style_map = NULL;
     object *the_floor;
     mapstruct *newMap = NULL;
@@ -97,7 +96,6 @@ mapstruct *make_map_floor(char **layout, char *floorstyle, RMParms *RP) {
 
     /* get the style map */
     snprintf(styledirname, sizeof(styledirname), "%s", "/styles/floorstyles");
-    snprintf(stylefilepath, sizeof(stylefilepath), "%s/%s", styledirname, floorstyle);
     style_map = find_style(styledirname, floorstyle, -1);
     if (style_map == NULL)
         return newMap;
