@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_special_c =
- *   "$Id: special.c 14225 2011-01-08 18:22:04Z ryo_saeba $";
+ *   "$Id: special.c 15822 2011-11-20 10:16:12Z ryo_saeba $";
  */
 
 /*
@@ -166,8 +166,14 @@ int find_spot_for_submap(mapstruct *map, char **layout, int *ix, int *iy, int xs
     if (2*xsize > MAP_WIDTH(map) || 2*ysize > MAP_HEIGHT(map))
         return 0;
 
-    /* search a bit for a completely free spot. */
-    for (tries = 0; tries < 20; tries++) {
+    tries = 20;
+    if (!settings.special_break_map) {
+        /* can't break layout, so try harder */
+        tries = 50;
+    }
+
+    /* search for a completely free spot. */
+    for (; tries >= 0; tries--) {
         /* pick a random location in the layout */
         i = RANDOM()%(MAP_WIDTH(map)-xsize-2)+1;
         j = RANDOM()%(MAP_HEIGHT(map)-ysize-2)+1;
@@ -180,7 +186,7 @@ int find_spot_for_submap(mapstruct *map, char **layout, int *ix, int *iy, int xs
     }
 
     /* if we failed, relax the restrictions */
-    if (is_occupied) { /* failure, try a relaxed placer. */
+    if (is_occupied && settings.special_break_map) { /* failure, try a relaxed placement if allowed. */
         /* pick a random location in the layout */
         for (tries = 0; tries < 10; tries++) {
             i = RANDOM()%(MAP_WIDTH(map)-xsize-2)+1;
@@ -253,17 +259,20 @@ void place_fountain_with_specials(mapstruct *map) {
  * @param RP
  * parameters from which map was generated.
  */
-void place_special_exit(mapstruct *map, int hole_type, RMParms *RP) {
+void place_special_exit(mapstruct *map, int hole_type, const RMParms *RP) {
     int ix, iy, i = -1;
-    char buf[HUGE_BUF];
+    char *buf;
     const char *style, *decor, *mon;
     mapstruct *exit_style = find_style("/styles/misc", "obscure_exits", -1);
     int g_xsize, g_ysize;
-    object *the_exit = object_new();
+    object *the_exit;
+    RMParms hole;
 
     if (!exit_style)
         return;
 
+    the_exit = object_new();
+
     object_copy(pick_random_object(exit_style), the_exit);
 
     while (i < 0) {
@@ -317,12 +326,40 @@ void place_special_exit(mapstruct *map, int hole_type, RMParms *RP) {
     if (g_ysize < MIN_RANDOM_MAP_SIZE)
         g_ysize = MIN_RANDOM_MAP_SIZE;
 
-    write_parameters_to_string(buf, g_xsize, g_ysize, RP->wallstyle, RP->floorstyle, mon,
-        "none", style, decor, "none", RP->exitstyle, NULL, NULL, NULL,
-        OPT_WALLS_ONLY, 0, 0, 1, RP->dungeon_level, RP->dungeon_level,
-        RP->difficulty, RP->difficulty, -1, 1, 0, 0, 0, 0, RP->difficulty_increase);
-    the_exit->slaying = add_string("/!");
+    memset(&hole, 0, sizeof(hole));
+    hole.Xsize = g_xsize;
+    hole.Ysize = g_ysize;
+    strcpy(hole.wallstyle, RP->wallstyle);
+    strcpy(hole.floorstyle, RP->floorstyle);
+    strcpy(hole.monsterstyle, mon);
+    strcpy(hole.treasurestyle, "none");
+    strcpy(hole.layoutstyle, style);
+    strcpy(hole.decorstyle, decor);
+    strcpy(hole.doorstyle, "none");
+    strcpy(hole.exitstyle, RP->exitstyle);
+    strcpy(hole.final_map, "");
+    strcpy(hole.exit_on_final_map, "");
+    strcpy(hole.this_map, "");
+    hole.layoutoptions1 = OPT_WALLS_ONLY;
+    hole.layoutoptions2 = 0;
+    hole.symmetry = 1;
+    hole.dungeon_depth = RP->dungeon_level;
+    hole.dungeon_level = RP->dungeon_level;
+    hole.difficulty = RP->difficulty;
+    hole.difficulty_given = RP->difficulty;
+    hole.decoroptions = -1;
+    hole.orientation = 1;
+    hole.origin_x = 0;
+    hole.origin_y = 0;
+    hole.random_seed = 0;
+    hole.treasureoptions = 0;
+    hole.difficulty_increase = RP->difficulty_increase;
+
+    buf = stringbuffer_finish(write_map_parameters_to_string(&hole));
     object_set_msg(the_exit, buf);
+    free(buf);
+
+    the_exit->slaying = add_string("/!");
 
     object_insert_in_map_at(the_exit, map, NULL, 0, ix+freearr_x[i], iy+freearr_y[i]);
 }
