@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_standalone_c =
- *   "$Id: standalone.c 14102 2010-11-19 06:35:42Z mwedel $";
+ *   "$Id: standalone.c 15527 2011-11-06 17:43:01Z ryo_saeba $";
  */
 
 /*
@@ -37,6 +37,7 @@
 #include <room_gen.h>
 #include <random_map.h>
 #include <rproto.h>
+#include <sproto.h>
 
 int main(int argc, char *argv[]) {
     char InFileName[1024], OutFileName[1024];
@@ -206,15 +207,12 @@ object *find_skill_by_number(object *who, int skillno) {
     return NULL;
 }
 
-void esrv_del_item(player *pl, int tag) {
+void esrv_del_item(player *pl, object *ob) {
 }
 
 void esrv_update_spells(player *pl) {
 }
 
-void trap_adjust(object *ob, int x) {
-}
-
 void rod_adjust(object *rod) {
 }
 
