@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_wall_c =
- *   "$Id: wall.c 12599 2010-03-08 18:33:07Z akirschbaum $";
+ *   "$Id: wall.c 14927 2011-07-31 17:28:51Z ryo_saeba $";
  */
 
 /*
@@ -179,7 +179,6 @@ int surround_flag4(mapstruct *map, int i, int j, RMParms *RP) {
  */
 void make_map_walls(mapstruct *map, char **layout, char *w_style, RMParms *RP) {
     char styledirname[256];
-    char stylefilepath[256];
     mapstruct *style_map = NULL;
     object *the_wall;
 
@@ -187,7 +186,6 @@ void make_map_walls(mapstruct *map, char **layout, char *w_style, RMParms *RP) {
     if (!strcmp(w_style, "none"))
         return;
     snprintf(styledirname, sizeof(styledirname), "%s", "/styles/wallstyles");
-    snprintf(stylefilepath, sizeof(stylefilepath), "%s/%s", styledirname, w_style);
     style_map = find_style(styledirname, w_style, -1);
     if (style_map == NULL)
         return;
