@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_attack_c =
- *   "$Id: attack.c 14118 2010-11-22 19:57:45Z ryo_saeba $";
+ *   "$Id: attack.c 15075 2011-09-10 12:47:41Z ryo_saeba $";
  */
 /*
     CrossFire, A Multiplayer game for X-windows
@@ -739,7 +739,9 @@ static int attack_ob_simple(object *op, object *hitter, int base_dam, int base_w
                 return 0;
             if (hitter->current_weapon->anim_suffix)
                 apply_anim_suffix(hitter, hitter->current_weapon->anim_suffix);
-        }
+        } else if (hitter->chosen_skill &&  hitter->chosen_skill->anim_suffix)
+            /* if no weapon, then skill (karate, wraith feed) attack */
+            apply_anim_suffix(hitter, hitter->chosen_skill->anim_suffix);
     }
     op_tag = op->count;
     hitter_tag = hitter->count;
@@ -770,14 +772,13 @@ static int attack_ob_simple(object *op, object *hitter, int base_dam, int base_w
 
     /* See if we hit the creature */
     if (roll >= 20 || op->stats.ac >= base_wc-roll) {
-        int hitdam = base_dam;
         if (settings.casting_time == TRUE) {
             if (hitter->type == PLAYER && hitter->casting_time > -1) {
                 hitter->casting_time = -1;
                 draw_ext_info(NDI_UNIQUE, 0, hitter, MSG_TYPE_ATTACK, MSG_TYPE_ATTACK_FUMBLE,
                               "You attacked and lost your spell!");
             }
-            if (op->casting_time > -1 && hitdam > 0) {
+            if (op->casting_time > -1 && base_dam > 0) {
                 op->casting_time = -1;
                 if (op->type == PLAYER)  {
                     draw_ext_info(NDI_UNIQUE, 0, op, MSG_TYPE_ATTACK, MSG_TYPE_ATTACK_FUMBLE,
@@ -826,8 +827,8 @@ static int attack_ob_simple(object *op, object *hitter, int base_dam, int base_w
         /* Need to do at least 1 damage, otherwise there is no point
          * to go further and it will cause FPE's below.
          */
-        if (hitdam <= 0)
-            hitdam = 1;
+        if (base_dam <= 0)
+            base_dam = 1;
 
         type = hitter->attacktype;
         if (!type)
@@ -849,7 +850,7 @@ static int attack_ob_simple(object *op, object *hitter, int base_dam, int base_w
         /* In the new attack code, it should handle multiple attack
          * types in its area, so remove it from here.
          */
-        dam = hit_player(op, random_roll(1, hitdam, hitter, PREFER_HIGH), hitter, type, 1);
+        dam = hit_player(op, random_roll(1, base_dam, hitter, PREFER_HIGH), hitter, type, 1);
         if (object_was_destroyed(op, op_tag)
         || object_was_destroyed(hitter, hitter_tag)
         || abort_attack(op, hitter, simple_attack)) {
@@ -1215,7 +1216,7 @@ static int hit_with_one_attacktype(object *op, object *hitter, int dam, uint32 a
                 else if (attacknum == ATNR_SLOW)
                     slow_living(op, hitter, dam);
                 else if (attacknum == ATNR_PARALYZE)
-                    paralyze_living(op, hitter, dam);
+                    paralyze_living(op, dam);
                 else if (attacknum == ATNR_FEAR)
                     scare_creature(op, hitter);
                 else if (attacknum == ATNR_CANCELLATION)
@@ -1351,8 +1352,14 @@ static int hit_with_one_attacktype(object *op, object *hitter, int dam, uint32 a
                 || !god->slaying
                 || strstr(god->slaying, undead_name) == NULL)
                     div = 2;
-                /* Give a bonus if you resist turn undead */
-                if (op->level*div < get_turn_bonus(owner->stats.Wis)+owner->level+(op->resist[ATNR_TURN_UNDEAD]/100))
+
+                /* The previous code was highly suspect - resist turn undead/100 would
+                 * at best give a bonus of 1 - increase that to resist turn undead/20 -
+                 * this gives a bit higher bonus.  Also the bonus was added to the wrong
+                 * side of the equation, actually making it easier to turn creatures
+                 * if they had that resistance.
+                 */
+                if ((op->level*div + (op->resist[ATNR_TURN_UNDEAD] / 20)) < (get_turn_bonus(owner->stats.Wis)+owner->level))
                     scare_creature(op, owner);
             } else
                 dam = 0; /* don't damage non undead - should we damage undead? */
@@ -1441,6 +1448,14 @@ static int hit_with_one_attacktype(object *op, object *hitter, int dam, uint32 a
     return dam;
 }
 
+/*
+ * This function is defined in party.c, but conditionally, something "make proto"
+ * doesn't handle. So define it locally.
+ */
+#ifdef PARTY_KILL_LOG
+void party_add_kill(partylist *party, const char *killer, const char *dead, long exp);
+#endif
+
 /**
  * An object was killed, handle various things (logging, messages, ...).
  *
@@ -1733,7 +1748,7 @@ static int kill_object(object *op, int dam, object *hitter) {
         }
         /* Need to run kill_player (just in case, make sure is not wiz) */
         if (!QUERY_FLAG(op, FLAG_WIZ))
-            kill_player(op);
+            kill_player(op, owner->type == PLAYER ? owner : hitter);
     }
     /* This was return -1 - that doesn't seem correct - if we return -1, process
      * continues in the calling function.
@@ -2236,26 +2251,11 @@ void blind_living(object *op, object *hitter, int dam) {
  *
  * @param op
  * victim.
- * @param hitter
- * who is attacking.
  * @param dam
  * damage to deal.
  */
-void paralyze_living(object *op, object *hitter, int dam) {
+void paralyze_living(object *op, int dam) {
     float effect, max;
-    /* object *tmp; */
-
-    /* This is strange stuff... someone knows for what this is
-     * written? Well, i think this can and should be removed
-    */
-
-/*
-    tmp = map_find_by_type(op->map, op->x, op->y, PARAIMAGE);
-    if (tmp == NULL) {
-        tmp = clone_arch(PARAIMAGE);
-        object_insert_in_map_at(tmp, op->map, tmp, INS_NO_MERGE|INS_NO_WALK_ON, op->x, op->y);
-    }
-*/
 
     /* Do this as a float - otherwise, rounding might very well reduce this to 0 */
     effect = (float)dam*3.0*(100.0-op->resist[ATNR_PARALYZE])/100;
@@ -2264,15 +2264,11 @@ void paralyze_living(object *op, object *hitter, int dam) {
         return;
 
     op->speed_left -= FABS(op->speed)*effect;
-/*  tmp->stats.food += (signed short)
-        effect/op->speed;*/
 
     /* max number of ticks to be affected for. */
     max = (100-op->resist[ATNR_PARALYZE])/2;
     if (op->speed_left < -(FABS(op->speed)*max))
         op->speed_left = (float)-(FABS(op->speed)*max);
-
-/*  tmp->stats.food = (signed short)(max/FABS(op->speed)); */
 }
 
 /**
