@@ -1,13 +1,12 @@
 /*
  * static char *rcsid_ban_c =
- *   "$Id: ban.c 5894 2007-03-25 20:41:32Z ryo_saeba $";
+ *   "$Id: ban.c 12020 2009-06-25 09:24:32Z akirschbaum $";
  */
 
-/*
- * Ban.c
- * Code was grabbed from the netrek source and modified to work with
- * crossfire. This function checks a file in the lib directory for any
- * banned players. If it finds one it returns a 1. Wildcards can be used.
+/**
+ * @file
+ * This code was grabbed from the Netrek source and modified to work with
+ * Crossfire.
  */
 
 #include <global.h>
@@ -26,16 +25,17 @@
 #endif /* win32 */
 
 /**
- * Check if a player and/or host is banned.
+ * Check if a player and/or host is banned. Wildcards can be used.
  *
- * @param login the player name to check; NULL to check only the host name
+ * @param login
+ * player name to check; NULL to check only the host name.
+ * @param host
+ * host name to check.
  *
- * @param host the host name to check
- *
- * @return 1=player/host is banned; 0=player/host is not banned
+ * @return
+ * 1=player/host is banned; 0=player/host is not banned
  */
-int checkbanned(const char *login, const char *host)
-{
+int checkbanned(const char *login, const char *host) {
     FILE *bannedfile;
     char buf[MAX_BUF];
     char log_buf0[160], host_buf[64], line_buf[160];
@@ -51,11 +51,10 @@ int checkbanned(const char *login, const char *host)
     int inverse_ban = 0;
 
     for (loop = 0; loop < 2; loop++) {  /* have to check both ban files now */
-
         /* First time through look for BANFILE */
 
         if (loop == 0) {
-            sprintf(buf, "%s/%s", settings.confdir, BANFILE);
+            snprintf(buf, sizeof(buf), "%s/%s", settings.confdir, BANFILE);
             bannedfile = fopen(buf, "r");
             if (bannedfile == NULL) {
                 LOG(llevDebug, "Could not find file Banned file\n");
@@ -66,7 +65,7 @@ int checkbanned(const char *login, const char *host)
         /* Second time through look for BANISHFILE */
 
         if (loop == 1) {
-            sprintf(buf, "%s/%s", settings.localdir, BANISHFILE);
+            snprintf(buf, sizeof(buf), "%s/%s", settings.localdir, BANISHFILE);
             bannedfile = fopen(buf, "r");
             if (bannedfile == NULL) {
                 LOG(llevDebug, "Could not find file Banish file\n");
@@ -83,7 +82,7 @@ int checkbanned(const char *login, const char *host)
             hits = 0;
 
             /* Split line up */
-            if(*line_buf == '#' || *line_buf == '\n')
+            if (*line_buf == '#' || *line_buf == '\n')
                 continue;
 
             indexpos = strrchr(line_buf, '@');
@@ -118,7 +117,7 @@ int checkbanned(const char *login, const char *host)
               LOG(llevDebug, "    Checking Banned <%s> and <%s>.\n", log_buf, host_buf);
             */
 
-            if(*log_buf=='*')
+            if (*log_buf == '*')
                 hits = 1;
             else if (login != NULL && strcmp(login, log_buf) == 0)
                 hits = 1;
@@ -129,14 +128,12 @@ int checkbanned(const char *login, const char *host)
 
                     /* break out now. otherwise hits will get reset to one */
                     break;
-                }
-                else if (strstr(host, host_buf) != NULL) { /* Lock out subdomains (eg, "*@usc.edu" */
+                } else if (strstr(host, host_buf) != NULL) { /* Lock out subdomains (eg, "*@usc.edu" */
                     hits++;
 
                     /* break out now. otherwise hits will get reset to one */
                     break;
-                }
-                else if (strcmp(host, host_buf) == 0) { /* Lock out specific host */
+                } else if (strcmp(host, host_buf) == 0) { /* Lock out specific host */
                     hits++;
 
                     /* break out now. otherwise hits will get reset to one */
@@ -150,7 +147,6 @@ int checkbanned(const char *login, const char *host)
         if (hits >= 2) {
             return(!inverse_ban);
         }
-
     }
 
     return(0);
