@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_c_new_c =
- *   "$Id: c_new.c 12316 2009-12-20 18:34:13Z akirschbaum $";
+ *   "$Id: c_new.c 13558 2010-08-05 20:53:39Z ryo_saeba $";
  */
 
 /*
@@ -92,11 +92,9 @@ static command_array_struct *find_command_element(const char *cmd, command_array
  * player who is issuing the command
  * @param command
  * the actual command with its arguments.
- * @return
- * 0 if invalid command, else actual command's return value (which may be zero).
  */
-int execute_newserver_command(object *pl, char *command) {
-    command_array_struct *csp;
+void execute_newserver_command(object *pl, char *command) {
+    command_array_struct *csp, sent;
     char *cp, *low;
 
     pl->contr->has_hit = 0;
@@ -121,7 +119,7 @@ int execute_newserver_command(object *pl, char *command) {
     for (low = command; *low; low++)
         *low = tolower(*low);
 
-    csp = find_plugin_command(command, pl);
+    csp = find_plugin_command(command, &sent);
     if (!csp)
         csp = find_command_element(command, Commands, CommandsSize);
     if (!csp)
@@ -134,9 +132,8 @@ int execute_newserver_command(object *pl, char *command) {
         draw_ext_info_format(NDI_UNIQUE, 0, pl,
                              MSG_TYPE_COMMAND, MSG_TYPE_COMMAND_ERROR,
                              "'%s' is not a valid command.",
-                             "'%s' is not a valid command.",
                              command);
-        return 0;
+        return;
     }
 
     pl->speed_left -= csp->time;
@@ -154,7 +151,7 @@ int execute_newserver_command(object *pl, char *command) {
     if (csp->time && pl->speed_left < -2.0) {
         LOG(llevDebug, "execute_newclient_command: Player issued command that takes more time than he has left.\n");
     }
-    return csp->func(pl, cp);
+    csp->func(pl, cp);
 }
 
 /**
@@ -164,20 +161,18 @@ int execute_newserver_command(object *pl, char *command) {
  * player.
  * @param params
  * additional parameters.
- * @return
- * 0.
  */
-int command_run(object *op, char *params) {
+void command_run(object *op, const char *params) {
     int dir;
 
     dir = atoi(params);
     if (dir < 0 || dir >= 9) {
         draw_ext_info(NDI_UNIQUE, 0, op, MSG_TYPE_COMMAND, MSG_TYPE_COMMAND_ERROR,
-                      "Can't run into a non adjacent square.", NULL);
-        return 0;
+                      "Can't run into a non adjacent square.");
+        return;
     }
     op->contr->run_on = 1;
-    return move_player(op, dir);
+    move_player(op, dir);
 }
 
 /**
@@ -190,9 +185,8 @@ int command_run(object *op, char *params) {
  * @return
  * 1.
  */
-int command_run_stop(object *op, char *params) {
+void command_run_stop(object *op, const char *params) {
     op->contr->run_on = 0;
-    return 1;
 }
 
 /**
@@ -202,20 +196,18 @@ int command_run_stop(object *op, char *params) {
  * player.
  * @param params
  * additional parameters.
- * @return
- * 0.
  */
-int command_fire(object *op, char *params) {
+void command_fire(object *op, const char *params) {
     int dir;
 
     dir = atoi(params);
     if (dir < 0 || dir >= 9) {
         draw_ext_info(NDI_UNIQUE, 0, op, MSG_TYPE_COMMAND, MSG_TYPE_COMMAND_ERROR,
-                      "Can't fire to a non adjacent square.", NULL);
-        return 0;
+                      "Can't fire to a non adjacent square.");
+        return;
     }
     op->contr->fire_on = 1;
-    return move_player(op, dir);
+    move_player(op, dir);
 }
 
 /**
@@ -225,10 +217,7 @@ int command_fire(object *op, char *params) {
  * player.
  * @param params
  * ignored.
- * @return
- * 0.
  */
-int command_fire_stop(object *op, char *params) {
+void command_fire_stop(object *op, const char *params) {
     op->contr->fire_on = 0;
-    return 1;
 }
