@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_c_object_c =
- *   "$Id: c_object.c 14102 2010-11-19 06:35:42Z mwedel $";
+ *   "$Id: c_object.c 16343 2011-12-28 22:45:32Z ryo_saeba $";
  */
 /*
     CrossFire, A Multiplayer game for X-windows
@@ -368,7 +368,7 @@ static void pick_up_object(object *pl, object *op, object *tmp, int nrof) {
     if (tmp->inv)
         weight += tmp->carrying*(100-tmp->stats.Str)/100;
 
-    effective_weight_limit = get_weight_limit(MIN(pl->stats.Str, MAX_STAT));
+    effective_weight_limit = get_weight_limit(MIN(pl->stats.Str, settings.max_stat));
 
     if (pl->weight+pl->carrying+weight > effective_weight_limit) {
         draw_ext_info(0, 0, pl, MSG_TYPE_COMMAND, MSG_TYPE_COMMAND_FAILURE,
@@ -450,7 +450,6 @@ void pick_up(object *op, object *alt) {
     object *tmp = NULL, *tmp1;
     mapstruct *tmp_map = NULL;
     int count;
-    tag_t tag;
 
     /* Decide which object to pick. */
     if (alt) {
@@ -572,7 +571,6 @@ void pick_up(object *op, object *alt) {
         return;
     }
 
-    tag = tmp->count;
     pick_up_object(op, alt, tmp, count);
     if (op->type == PLAYER)
         op->contr->count = 0;
@@ -680,8 +678,7 @@ void command_take(object *op, const char *params) {
  * if non zero, then nrof objects is tried to put into sack, else everything is put.
  */
 void put_object_in_sack(object *op, object *sack, object *tmp, uint32 nrof) {
-    tag_t tmp_tag, tmp2_tag;
-    object *tmp2, *sack2, *orig = sack;
+    object *sack2, *orig = sack;
     char name_sack[MAX_BUF], name_tmp[MAX_BUF];
 
     if (sack == tmp)
@@ -754,9 +751,7 @@ void put_object_in_sack(object *op, object *sack, object *tmp, uint32 nrof) {
     /* we want to put some portion of the item into the container */
     if (nrof && tmp->nrof != nrof) {
         char failure[MAX_BUF];
-        object *tmp2 = tmp;
 
-        tmp2_tag = tmp2->count;
         tmp = object_split(tmp, nrof, failure, sizeof(failure));
 
         if (!tmp) {
@@ -783,8 +778,8 @@ void put_object_in_sack(object *op, object *sack, object *tmp, uint32 nrof) {
     draw_ext_info_format(NDI_UNIQUE, 0, op, MSG_TYPE_COMMAND, MSG_TYPE_COMMAND_SUCCESS,
                          "You put the %s in %s.",
                          name_tmp, name_sack);
-    tmp_tag = tmp->count;
-    tmp2 = object_insert_in_ob(tmp, sack);
+
+    object_insert_in_ob(tmp, sack);
     if (!QUERY_FLAG(op, FLAG_NO_FIX_PLAYER))
         fix_object(op); /* This is overkill, fix_player() is called somewhere */
     /* in object.c */
@@ -1353,9 +1348,11 @@ void command_mark(object *op, const char *params) {
  * player.
  * @param tmp
  * monster being examined.
+ * @param level
+ * level of the probe, to have a persistant marker for some duration.
  */
-void examine_monster(object *op, object *tmp) {
-    object *mon = HEAD(tmp);
+void examine_monster(object *op, object *tmp, int level) {
+    object *mon = HEAD(tmp), *probe;
 
     if (QUERY_FLAG(mon, FLAG_UNDEAD))
         draw_ext_info(NDI_UNIQUE, 0, op, MSG_TYPE_COMMAND, MSG_TYPE_COMMAND_EXAMINE,
@@ -1407,10 +1404,31 @@ void examine_monster(object *op, object *tmp) {
     if (object_present_in_ob(POISONING, mon) != NULL)
         draw_ext_info(NDI_UNIQUE, 0, op, MSG_TYPE_COMMAND, MSG_TYPE_COMMAND_EXAMINE,
                       "It looks very ill.");
+
+    if (level < 15)
+        return;
+
+    probe = object_find_by_type_and_name(mon, FORCE, "probe_force");
+    if (probe != NULL && probe->level > level)
+        return;
+
+    if (probe == NULL) {
+        probe = create_archetype(FORCE_NAME);
+        free_string(probe->name);
+        probe->name = add_string("probe_force");
+        SET_FLAG(probe, FLAG_APPLIED);
+        SET_FLAG(probe, FLAG_PROBE);
+        object_insert_in_ob(probe, mon);
+        fix_object(mon);
+    }
+    probe->level = level;
+    if (level / 10 > probe->duration)
+        probe->duration = level / 10;
 }
 
 /**
- * Player examines some object.
+ * Player examines some object. The item may be identified automatically
+ * if the player has the correct skill for that.
  *
  * @param op
  * player.
@@ -1612,7 +1630,7 @@ void examine(object *op, object *tmp) {
                 snprintf(buf, sizeof(buf), "%s would cost you %s.", tmp->nrof > 1 ? "They" : "It", value);
                 free(value);
             } else {
-                value = stringbuffer_finish(query_cost_string(tmp, op, F_SELL+F_SHOP, NULL));
+                value = stringbuffer_finish(query_cost_string(tmp, op, F_SELL|F_SHOP, NULL));
                 snprintf(buf, sizeof(buf), "You are offered %s for %s.", value, tmp->nrof > 1 ? "them" : "it");
                 free(value);
             }
@@ -1622,7 +1640,7 @@ void examine(object *op, object *tmp) {
     }
 
     if (QUERY_FLAG(tmp, FLAG_MONSTER))
-        examine_monster(op, tmp);
+        examine_monster(op, tmp, 0);
 
     /* Is this item buildable? */
     if (QUERY_FLAG(tmp, FLAG_IS_BUILDABLE))
@@ -1650,6 +1668,8 @@ void examine(object *op, object *tmp) {
     }
     draw_ext_info(NDI_UNIQUE, 0, op, MSG_TYPE_COMMAND, MSG_TYPE_COMMAND_EXAMINE,
                   " "); /* Blank line */
+
+    knowledge_item_can_be_used_alchemy(op, tmp);
 }
 
 /**
@@ -2028,7 +2048,6 @@ void command_rename_item(object *op, const char *params) {
     object *tmp;
     char *closebrace;
     size_t counter;
-    tag_t tag;
 
     if (*params != '\0') {
         /* Let's skip white spaces */
@@ -2193,7 +2212,6 @@ void command_rename_item(object *op, const char *params) {
                              name, buf);
     }
 
-    tag = item->count;
     tmp = object_merge(item, NULL);
     if (tmp == NULL) {
         /* object was not merged - if it was, object_merge() handles updating for us. */
@@ -2212,7 +2230,6 @@ void command_rename_item(object *op, const char *params) {
 void command_lock_item(object *op, const char *params) {
     object *item;
     object *tmp;
-    tag_t tag;
     char name[HUGE_BUF];
 
     if (*params == '\0' || strlen(params) == 0) {
@@ -2239,7 +2256,6 @@ void command_lock_item(object *op, const char *params) {
         SET_FLAG(item, FLAG_INV_LOCKED);
     }
 
-    tag = item->count;
     tmp = object_merge(item, NULL);
     if (tmp == NULL) {
         /* object was not merged, if it was object_merge() handles updates for us */
