@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_c_range_c =
- *   "$Id: c_range.c 12667 2010-03-19 15:04:19Z akirschbaum $";
+ *   "$Id: c_range.c 13889 2010-09-26 10:02:47Z ryo_saeba $";
  */
 
 /*
@@ -47,11 +47,9 @@
  * player.
  * @param params
  * spell.
- * @return
- * 1 for success, 0 for failure.
  */
-int command_invoke(object *op, char *params) {
-    return command_cast_spell(op, params, 'i');
+void command_invoke(object *op, const char *params) {
+    command_cast_spell(op, params, 'i');
 }
 
 /**
@@ -61,11 +59,9 @@ int command_invoke(object *op, char *params) {
  * player.
  * @param params
  * spell.
- * @return
- * 1 for success, 0 for failure.
  */
-int command_cast(object *op, char *params) {
-    return command_cast_spell(op, params, 'c');
+void command_cast(object *op, const char *params) {
+    command_cast_spell(op, params, 'c');
 }
 
 /**
@@ -75,12 +71,10 @@ int command_cast(object *op, char *params) {
  * player.
  * @param params
  * spell.
- * @return
- * 1 for success, 0 for failure.
  * @todo remove.
  */
-int command_prepare(object *op, char *params) {
-    return command_cast_spell(op, params, 'p');
+void command_prepare(object *op, const char *params) {
+    command_cast_spell(op, params, 'p');
 }
 
 /**
@@ -122,41 +116,44 @@ static void show_matching_spells(object *op, const char *params) {
         }
     } FOR_INV_FINISH();
     if (!num_found) {
-        /* If a matching string was passed along, now try it without that
-         * string.  It is odd to do something like 'cast trans',
-         * and it say you have no spells, when really, you do, but just
-         * nothing that matches.
-         */
         if (*params != '\0')
-            show_matching_spells(op, "");
+            draw_ext_info_format(NDI_UNIQUE, 0, op, MSG_TYPE_COMMAND, MSG_TYPE_COMMAND_ERROR,
+                          "You know no spells like '%s'.", params);
         else
-            draw_ext_info(NDI_UNIQUE, 0, op, MSG_TYPE_COMMAND, MSG_TYPE_COMMAND_ERROR,
-                          "You know no spells", NULL);
-    } else {
-        /* Note in the code below that we make some
-         * presumptions that there will be a colon in the
-         * string.  given the code above, this is always
-         * the case.
-         */
-        qsort(spell_sort, num_found, MAX_BUF, (int (*)(const void *, const void *))strcmp);
-        strcpy(tmp, "asdfg"); /* Dummy string so initial compare fails */
-        for (i = 0; i < num_found; i++) {
-            /* Different skill name, so print banner */
-            if (strncmp(tmp, spell_sort[i], strlen(tmp))) {
-                strcpy(tmp, spell_sort[i]);
-                cp = strchr(tmp, ':');
-                *cp = '\0';
+            draw_ext_info_format(NDI_UNIQUE, 0, op, MSG_TYPE_COMMAND, MSG_TYPE_COMMAND_ERROR,
+                          "You know no spells.");
+
+        return;
+    }
+
+    if (*params != '\0')
+        draw_ext_info_format(NDI_UNIQUE, 0, op, MSG_TYPE_COMMAND, MSG_TYPE_COMMAND_SUCCESS,
+                      "You know the following '%s' spells:", params);
+    else
+        draw_ext_info(NDI_UNIQUE, 0, op, MSG_TYPE_COMMAND, MSG_TYPE_COMMAND_SUCCESS,
+                      "You know the following spells:");
+
+    /* Note in the code below that we make some
+     * presumptions that there will be a colon in the
+     * string.  given the code above, this is always
+     * the case.
+     */
+    qsort(spell_sort, num_found, MAX_BUF, (int (*)(const void *, const void *))strcmp);
+    strcpy(tmp, "asdfg"); /* Dummy string so initial compare fails */
+    for (i = 0; i < num_found; i++) {
+        /* Different skill name, so print banner */
+        if (strncmp(tmp, spell_sort[i], strlen(tmp))) {
+            strcpy(tmp, spell_sort[i]);
+            cp = strchr(tmp, ':');
+            *cp = '\0';
 
-                draw_ext_info_format(NDI_UNIQUE, 0, op, MSG_TYPE_COMMAND, MSG_TYPE_COMMAND_SUCCESS,
-                                     "\n[fixed]%s spells %.*s <lvl> <sp>",
-                                     "\n%s spells %.*s <lvl> <sp>",
-                                     tmp, (int)(12-strlen(tmp)), "              ");
-            }
             draw_ext_info_format(NDI_UNIQUE, 0, op, MSG_TYPE_COMMAND, MSG_TYPE_COMMAND_SUCCESS,
-                                 "[fixed]%s",
-                                 "%s",
-                                 strchr(spell_sort[i], ':')+1);
+                                 "\n[fixed]%s spells %.*s <lvl> <sp>",
+                                 tmp, (int)(12-strlen(tmp)), "              ");
         }
+        draw_ext_info_format(NDI_UNIQUE, 0, op, MSG_TYPE_COMMAND, MSG_TYPE_COMMAND_SUCCESS,
+                             "[fixed]%s",
+                             strchr(spell_sort[i], ':')+1);
     }
 }
 
@@ -171,23 +168,23 @@ static void show_matching_spells(object *op, const char *params) {
  * spell name.
  * @param command
  * first letter of the spell type (c=cast, i=invoke, p=prepare).
- * @return
- * 0 if success, 1 for failure.
  */
-int command_cast_spell(object *op, char *params, char command) {
+void command_cast_spell(object *op, const char *params, char command) {
     int castnow = 0;
-    char *cp;
+    char *cp, cpy[MAX_BUF];
     object *spob;
 
+    strncpy(cpy, params, sizeof(cpy));
+
     if (command == 'i')
         castnow = 1;
 
-    if (*params != '\0') {
+    if (*cpy != '\0') {
         tag_t spellnumber = 0;
-        if ((spellnumber = atoi(params)) != 0)
+        if ((spellnumber = atoi(cpy)) != 0)
             spob = object_find_by_tag(op, spellnumber);
         else
-            spob = lookup_spell_by_name(op, params);
+            spob = lookup_spell_by_name(op, cpy);
 
         if (spob && spob->type == SPELL) {
             /* Now grab any extra data, if there is any.  Forward pass
@@ -195,14 +192,14 @@ int command_cast_spell(object *op, char *params, char command) {
              */
             if (spellnumber) {
                 /* if we passed a number, the options start at the second word */
-                cp = strchr(params, ' ');
+                cp = strchr(cpy, ' ');
                 if (cp) {
                     cp++;
                     if (!strncmp(cp, "of ", 3))
                         cp += 3;
                 }
-            } else if (strlen(params) > strlen(spob->name)) {
-                cp = params+strlen(spob->name);
+            } else if (strlen(cpy) > strlen(spob->name)) {
+                cp = cpy+strlen(spob->name);
                 *cp = 0;
                 cp++;
                 if (!strncmp(cp, "of ", 3))
@@ -212,10 +209,9 @@ int command_cast_spell(object *op, char *params, char command) {
 
             if (spob->skill && !find_skill_by_name(op, spob->skill)) {
                 draw_ext_info_format(NDI_UNIQUE, 0, op, MSG_TYPE_SKILL, MSG_TYPE_SKILL_MISSING,
-                                     "You need the skill %s to cast %s!",
                                      "You need the skill %s to cast %s!",
                                      spob->skill, spob->name);
-                return 1;
+                return;
             }
 
             /* Remove control of the golem */
@@ -229,6 +225,8 @@ int command_cast_spell(object *op, char *params, char command) {
                 op->contr->golem_count = 0;
             }
 
+            /* This assignment is need for casting_time logic */
+            op->spell = spob;
             if (castnow) {
                 cast_spell(op, op, op->facing, spob, cp);
             } else {
@@ -236,6 +234,7 @@ int command_cast_spell(object *op, char *params, char command) {
                 sstring required = object_get_value(spob, "casting_requirements");
                 op->contr->ranges[range_magic] = spob;
                 op->contr->shoottype = range_magic;
+
                 if (cp != NULL) {
                     strncpy(op->contr->spellparam, cp, MAX_BUF);
                     op->contr->spellparam[MAX_BUF-1] = '\0';
@@ -244,20 +243,16 @@ int command_cast_spell(object *op, char *params, char command) {
                 }
                 draw_ext_info_format(NDI_UNIQUE, 0, op, MSG_TYPE_COMMAND, MSG_TYPE_COMMAND_SUCCESS,
                                      "You ready the spell %s%s%s",
-                                     NULL,
                                      spob->name, required ? " which consumes for each invocation " : "", required ? required : "");
             }
-            return 0;
+            return;
         } /* else fall through to below and print spells */
     } /* params supplied */
 
     /* We get here if cast was given without options or we could not find
      * the requested spell.  List all the spells the player knows.
      */
-    draw_ext_info(NDI_UNIQUE, 0, op, MSG_TYPE_COMMAND, MSG_TYPE_COMMAND_ERROR,
-                  "Cast what spell?  Choose one of:", NULL);
-    show_matching_spells(op, params);
-    return 1;
+    show_matching_spells(op, cpy);
 }
 
 /**************************************************************************/
@@ -335,18 +330,17 @@ void change_spell(object *op, char k) {
     switch (op->contr->shoottype) {
     case range_none:
         draw_ext_info(NDI_UNIQUE, 0, op, MSG_TYPE_COMMAND, MSG_TYPE_COMMAND_ERROR,
-                      "No ranged attack chosen.", NULL);
+                      "No ranged attack chosen.");
         break;
 
     case range_golem:
         draw_ext_info(NDI_UNIQUE, 0, op, MSG_TYPE_COMMAND, MSG_TYPE_COMMAND_SUCCESS,
-                      "You regain control of your golem.", NULL);
+                      "You regain control of your golem.");
         break;
 
     case range_bow:
         query_name(op->contr->ranges[range_bow], name, MAX_BUF);
         draw_ext_info_format(NDI_UNIQUE, 0, op, MSG_TYPE_COMMAND, MSG_TYPE_COMMAND_SUCCESS,
-                             "Switched to %s and %s.",
                              "Switched to %s and %s.",
                              name,
                              op->contr->ranges[range_bow]->race ? op->contr->ranges[range_bow]->race : "nothing");
@@ -354,7 +348,6 @@ void change_spell(object *op, char k) {
 
     case range_magic:
         draw_ext_info_format(NDI_UNIQUE, 0, op, MSG_TYPE_COMMAND, MSG_TYPE_COMMAND_SUCCESS,
-                             "Switched to spells (%s).",
                              "Switched to spells (%s).",
                              op->contr->ranges[range_magic]->name);
         break;
@@ -362,14 +355,12 @@ void change_spell(object *op, char k) {
     case range_misc:
         query_base_name(op->contr->ranges[range_misc], 0, name, MAX_BUF);
         draw_ext_info_format(NDI_UNIQUE, 0, op, MSG_TYPE_COMMAND, MSG_TYPE_COMMAND_SUCCESS,
-                             "Switched to %s.",
                              "Switched to %s.",
                              name);
         break;
 
     case range_skill:
         draw_ext_info_format(NDI_UNIQUE, 0, op, MSG_TYPE_COMMAND, MSG_TYPE_COMMAND_SUCCESS,
-                             "Switched to skill: %s",
                              "Switched to skill: %s",
                              op->chosen_skill ? op->chosen_skill->name : "none");
         break;
@@ -386,13 +377,10 @@ void change_spell(object *op, char k) {
  * player.
  * @param params
  * arguments to the command.
- * @return
- * 0.
  */
-int command_rotateshoottype(object *op, char *params) {
+void command_rotateshoottype(object *op, const char *params) {
     if (*params == '\0')
         change_spell(op, '+');
     else
         change_spell(op, params[0]);
-    return 0;
 }
