@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_c_wiz_c =
- *   "$Id: c_wiz.c 14149 2010-12-04 22:41:11Z akirschbaum $";
+ *   "$Id: c_wiz.c 16870 2012-01-28 11:46:31Z ryo_saeba $";
  */
 
 /*
@@ -772,6 +772,38 @@ void command_freeze(object *op, const char *params) {
     pl->ob->speed_left = -(pl->ob->speed*ticks);
 }
 
+/**
+ * Put a player into jail, taking into account cursed exits and player's region.
+ * @param who player to put in jail
+ * @retval 0 player was moved to jail.
+ * @retval -1 no jail found.
+ * @retval -2 couldn't move to jail (map loading error, or already at jail's position).
+ * @retval -3 op isn't a player.
+ */
+int player_arrest(object *who) {
+    object *dummy;
+    mapstruct *cur;
+    int x, y;
+
+    if (who->type != PLAYER)
+        return -3;
+
+    dummy = get_jail_exit(who);
+    if (!dummy) {
+        return -1;
+    }
+    cur = who->map;
+    x = who->x;
+    y = who->y;
+    enter_exit(who, dummy);
+    object_free2(dummy, FREE_OBJ_NO_DESTROY_CALLBACK);
+
+    if (cur == who->map && x == who->x && y == who->y)
+        return -2;
+
+    return 0;
+}
+
 /**
  * Wizard jails player.
  *
@@ -781,8 +813,8 @@ void command_freeze(object *op, const char *params) {
  * player to jail.
  */
 void command_arrest(object *op, const char *params) {
-    object *dummy;
     player *pl;
+    int ret;
 
     if (!op)
         return;
@@ -794,15 +826,22 @@ void command_arrest(object *op, const char *params) {
     pl = get_other_player_from_name(op, params);
     if (!pl)
         return;
-    dummy = get_jail_exit(pl->ob);
-    if (!dummy) {
+
+    ret = player_arrest(pl->ob);
+    if (ret == -1) {
         /* we have nowhere to send the prisoner....*/
         draw_ext_info(NDI_UNIQUE, 0, op, MSG_TYPE_COMMAND, MSG_TYPE_COMMAND_ERROR,
                       "Can't jail player, there is no map to hold them");
         return;
     }
-    enter_exit(pl->ob, dummy);
-    object_free2(dummy, FREE_OBJ_NO_DESTROY_CALLBACK);
+    if (ret == -2) {
+        /* something prevented jailing the player */
+        draw_ext_info(NDI_UNIQUE, 0, op, MSG_TYPE_COMMAND, MSG_TYPE_COMMAND_ERROR,
+          "Can't jail player, map loading issue or already in jail's position");
+        return;
+
+    }
+
     draw_ext_info(NDI_UNIQUE, 0, pl->ob, MSG_TYPE_ADMIN, MSG_TYPE_ADMIN_DM,
                   "You have been arrested.");
     draw_ext_info_format(NDI_UNIQUE, 0, op, MSG_TYPE_COMMAND, MSG_TYPE_COMMAND_DM,
@@ -936,7 +975,7 @@ void command_create(object *op, const char *params) {
     uint32 i;
     int magic, set_magic = 0, set_nrof = 0, gotquote, gotspace;
     uint32 nrof;
-    char *cp, *bp, *bp2, *bp3, *bp4, *endline, cpy[MAX_BUF];
+    char *cp, *bp, *bp2, *bp3, *endline, cpy[MAX_BUF];
     archetype *at, *at_spell = NULL;
     const artifact *art = NULL;
 
@@ -1033,7 +1072,7 @@ void command_create(object *op, const char *params) {
                 art = find_artifactlist(at->clone.type)->items;
 
                 do {
-                    if (!strcmp(art->item->name, cp))
+                    if (!strcmp(art->item->name, cp) && legal_artifact_combination(&at->clone, art))
                         break;
                     art = art->next;
                 } while (art != NULL);
@@ -1070,6 +1109,7 @@ void command_create(object *op, const char *params) {
     if (need_identify(tmp)) {
         SET_FLAG(tmp, FLAG_IDENTIFIED);
         CLEAR_FLAG(tmp, FLAG_KNOWN_MAGICAL);
+        object_give_identified_properties(tmp);
     }
 
     /*
@@ -1080,7 +1120,6 @@ void command_create(object *op, const char *params) {
      * any spaces there don't count.
      */
     while (*bp2 && bp2 <= endline) {
-        bp4 = NULL;
         gotspace = 0;
         gotquote = 0;
         /* find the first quote */
@@ -1706,7 +1745,7 @@ void command_abil(object *op, const char *params) {
         return;
     }
 
-    if (iii < MIN_STAT || iii > MAX_STAT) {
+    if (iii < MIN_STAT || iii > settings.max_stat) {
         draw_ext_info(NDI_UNIQUE, 0, op, MSG_TYPE_COMMAND, MSG_TYPE_COMMAND_ERROR,
                       "Illegal range of stat.\n");
         return;
@@ -2462,13 +2501,11 @@ void command_stack_clear(object *op, const char *params) {
  * object specifier.
  */
 void command_diff(object *op, const char *params) {
-    object *left, *right, *top;
+    object *left, *right;
     char *diff;
     StringBuffer *sb;
     int left_from, right_from;
 
-    top = NULL;
-
     left = get_dm_object(op->contr, &params, &left_from);
     if (!left) {
         draw_ext_info(NDI_UNIQUE, 0, op, MSG_TYPE_COMMAND, MSG_TYPE_COMMAND_ERROR,
