@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_commands_c =
- *   "$Id: commands.c 12750 2010-03-30 02:28:23Z kbulgrien $";
+ *   "$Id: commands.c 13414 2010-06-19 15:28:21Z ryo_saeba $";
  */
 
 /*
@@ -247,6 +247,8 @@ command_array_struct WizCommands [] = {
     { "plugin", command_loadplugin,              0.0 },
     { "pluglist", command_listplugins,           0.0 },
     { "plugout", command_unloadplugin,           0.0 },
+    { "purge_quest_state", command_purge_quest,  0.0 },
+    { "purge_quests", command_purge_quest_definitions,  0.0 },
     { "remove", command_remove,                  0.0 },
     { "reset", command_reset,                    0.0 },
     { "set_god", command_setgod,                 0.0 },
