@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_daemon_c =
- *   "$Id: daemon.c 6191 2007-05-05 21:04:41Z ryo_saeba $";
+ *   "$Id: daemon.c 11212 2009-01-21 23:25:57Z akirschbaum $";
  */
 
 /*
@@ -26,9 +26,11 @@
     The author can be reached via e-mail to crossfire-devel@real-time.com
 */
 
-/*
- * BecomeDaemon.c
- * shamelessly swiped from xdm source code.
+/**
+ * @file
+ * Daemon mode for the server.
+ *
+ * Shamelessly swiped from xdm source code.
  * Appropriate copyrights kept, and hereby follow
  * ERic mehlhaff, 3/11/92
  *
@@ -51,7 +53,6 @@
  * Author:  Keith Packard, MIT X Consortium
  */
 
-
 #include <global.h>
 #ifndef __CEXTRACT__
 #include <sproto.h>
@@ -65,46 +66,48 @@
 #include <stdio.h>
 #include <sys/file.h>
 
-void become_daemon()
-{
-  register int i;
-  int forkresult;
- 
-  fputs("\n========================\n",logfile);    
-  fputs("Begin New Server Session\n",logfile);    
-  fputs("========================\n\n",logfile);    
+/**
+ * Starts the server as a daemon.
+ */
+void become_daemon(void) {
+    register int i;
+    int forkresult;
+
+    fputs("\n========================\n", logfile);
+    fputs("Begin New Server Session\n", logfile);
+    fputs("========================\n\n", logfile);
     /*
      * fork so that the process goes into the background automatically. Also
      * has a nice side effect of having the child process get inherited by
      * init (pid 1).
      */
 
-    if ( (forkresult = fork ()) ){	/* if parent */
-	  if(forkresult < 0 ){
-		perror("Fork error!");
-	  }
-	  exit (0);			/* then no more work to do */
-      }
+    if ((forkresult = fork())) {   /* if parent */
+        if (forkresult < 0) {
+            perror("Fork error!");
+        }
+        exit(0);    /* then no more work to do */
+    }
 
     /*
      * Close standard file descriptors and get rid of controlling tty
      */
 
-    close (0); 
-    close (1);
-    close (2);
+    close(0);
+    close(1);
+    close(2);
 
     /*
      * Set up the standard file descriptors.
      */
-    (void) open ("/dev/null", O_RDONLY);	/* root inode already in core */
-    (void) dup2 (0, 1);
-    (void) dup2 (0, 2);
+    (void)open("/dev/null", O_RDONLY);  /* root inode already in core */
+    (void)dup2(0, 1);
+    (void)dup2(0, 2);
 
-    if ((i = open ("/dev/tty", O_RDWR)) >= 0) {	/* did open succeed? */
+    if ((i = open("/dev/tty", O_RDWR)) >= 0) {  /* did open succeed? */
 #if (defined(SYSV) || defined(hpux)) && defined(TIOCTTY)
-	int zero = 0;
-	(void) ioctl (i, TIOCTTY, &zero);
+        int zero = 0;
+        (void)ioctl(i, TIOCTTY, &zero);
 #else
 
 #  ifdef HAVE_SYS_TERMIOS_H
@@ -114,20 +117,19 @@ void become_daemon()
 #      include <sys/ttycom.h>
 #    endif
 #  endif
-	(void) ioctl (i, TIOCNOTTY, (char *) 0);    /* detach, BSD style */
+        (void)ioctl(i, TIOCNOTTY, (char *)0);     /* detach, BSD style */
 #endif
-	(void) close (i);
+        (void)close(i);
     }
 
-
 #ifdef HAVE_SETSID
     setsid();
 #else
-/* Are these really different?  */
+    /* Are these really different?  */
 #  if defined(SYSV) || defined(SVR4)
-      setpgrp (0, 0);
+    setpgrp(0, 0);
 #  else /* Non SYSV machines */
-      setpgrp (0, getpid());
+    setpgrp(0, getpid());
 #  endif
 #endif
 }
