@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_disease_c =
- *   "$Id: disease.c 13308 2010-05-28 06:12:12Z kbulgrien $";
+ *   "$Id: disease.c 16358 2011-12-29 08:56:15Z ryo_saeba $";
  */
 /*
     CrossFire, A Multiplayer game for X-windows
@@ -331,6 +331,8 @@ int infect_object(object *victim, object *disease, int force) {
     object *new_disease;
     object *owner;
 
+    victim = HEAD(victim);
+
     /* don't infect inanimate objects */
     if (!QUERY_FLAG(victim, FLAG_MONSTER) && !(victim->type == PLAYER))
         return 0;
@@ -461,6 +463,7 @@ static void do_symptoms(object *disease) {
     if (symptom == NULL) {
         /* no symptom?  need to generate one! */
         object *new_symptom;
+        int reduce_level = 0;
 
         /* first check and see if the carrier of the disease is immune.  If so, no symptoms!  */
         if (!is_susceptible_to_disease(victim, disease))
@@ -469,8 +472,12 @@ static void do_symptoms(object *disease) {
         /* check for an actual immunity */
         /* do an immunity check */
         tmp = object_find_by_type_and_name(HEAD(victim), SIGN, disease->name);
-        if (tmp != NULL && tmp->level >= disease->level)
-            return;  /*Immune! */
+        if (tmp != NULL) {
+            if (tmp->level >= disease->level)
+                return;  /*Immune! */
+            /* partially immune */
+            reduce_level = tmp->level;
+        }
 
         new_symptom = create_archetype(ARCH_SYMPTOM);
 
@@ -494,7 +501,7 @@ static void do_symptoms(object *disease) {
 
         FREE_AND_COPY(new_symptom->name, disease->name);
         FREE_AND_COPY(new_symptom->name_pl, disease->name);
-        new_symptom->level = disease->level;
+        new_symptom->level = disease->level - reduce_level;
         new_symptom->speed = disease->speed;
         new_symptom->value = 0;
         new_symptom->stats.Str = disease->stats.Str;
@@ -543,7 +550,7 @@ static void do_symptoms(object *disease) {
             cur_stat = (int)(scale * cur_stat);
             set_attr_value(&symptom->stats, i, cur_stat);
         }
-        check_stat_bounds(&symptom->stats, -MAX_STAT, MAX_STAT);
+        check_stat_bounds(&symptom->stats, -settings.max_stat, settings.max_stat);
 
         symptom->stats.dam = (int)(scale*disease->stats.dam);
         symptom->stats.sp = (int)(scale*disease->stats.sp);
@@ -680,12 +687,14 @@ void check_physically_infect(object *victim, object *hitter) {
  * @param caster
  * spell object used for curing. If NULL all diseases are removed, else only those of lower level than
  * caster or randomly chosen.
+ * @param skill
+ * skill to give experience to, can be NULL.
  * @retval 0
  * no disease was cured.
  * @retval 1
  * at least one disease was cured.
  */
-int cure_disease(object *sufferer, object *caster) {
+int cure_disease(object *sufferer, object *caster, sstring skill) {
     int casting_level;
     int cure = 0;
 
@@ -708,7 +717,7 @@ int cure_disease(object *sufferer, object *caster) {
                 object_remove(disease);
                 cure = 1;
                 if (caster)
-                    change_exp(caster, disease->stats.exp, caster->chosen_skill ? caster->chosen_skill->skill : NULL, 0);
+                    change_exp(caster, disease->stats.exp, skill, 0);
                 object_free_drop_inventory(disease);
             }
         }
