@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_gods_c =
- *   "$Id: gods.c 13698 2010-09-02 17:39:41Z ryo_saeba $";
+ *   "$Id: gods.c 14970 2011-08-11 20:44:45Z ryo_saeba $";
  */
 
 /*
@@ -48,7 +48,7 @@
 static int worship_forbids_use(object *op, object *exp_obj, uint32 flag, const char *string);
 static void stop_using_item(object *op, int type, int number);
 static void update_priest_flag(const object *god, object *exp_ob, uint32 flag);
-static void god_intervention(object *op, const object *god, object *skill);
+static void god_intervention(object *op, const object *god, object *skill, object *altar);
 static int god_examines_priest(object *op, const object *god);
 static int god_examines_item(const object *god, object *item);
 static const char *get_god_for_race(const char *race);
@@ -270,6 +270,19 @@ static int god_gives_present(object *op, const object *god, treasure *tr) {
         return 0;
 
     tmp = arch_to_object(tr->item);
+
+    /*
+     * Give inventory if needed, for instance Lythander's pipe.
+     * Use high level and magic so something IS put in inventory.
+     */
+    fix_generated_item(tmp, NULL, 120, 120, GT_ONLY_GOOD);
+
+    /* And just in case nothing was put and something is needed, bail out. */
+    if ((tmp->type == ROD || tmp->type == WAND) && (tmp->inv == NULL)) {
+        object_free2(tmp, 0);
+        return 0;
+    }
+
     query_short_name(tmp, name, HUGE_BUF);
     draw_ext_info_format(NDI_UNIQUE, 0, op, MSG_TYPE_ITEM, MSG_TYPE_ITEM_ADD,
                          "%s lets %s appear in your hands.",
@@ -331,7 +344,7 @@ void pray_at_altar(object *pl, object *altar, object *skill) {
         bonus = MAX(1, bonus+MAX(pl->stats.luck, -3)); /* -- DAMN -- */
 
         if (((random_roll(0, 399, pl, PREFER_LOW))-bonus) < 0)
-            god_intervention(pl, pl_god, skill);
+            god_intervention(pl, pl_god, skill, altar);
     } else { /* praying to another god! */
         uint64 loss = 0;
         int angry = 1;
@@ -480,7 +493,6 @@ int become_follower(object *op, const object *new_god) {
         if (QUERY_FLAG(item, FLAG_STARTEQUIP)
         && item->invisible
         && (item->type != SKILL)
-        && (item->type != EXPERIENCE)
         && (item->type != FORCE)
         && (item->type != SPELL)) {
             player_unready_range_ob(op->contr, item);
@@ -736,7 +748,6 @@ static void update_priest_flag(const object *god, object *exp_ob, uint32 flag) {
 archetype *determine_holy_arch(const object *god, const char *type) {
     treasure *tr;
     int count;
-    archetype *last;
     object *item;
 
     if (!god || !god->randomitems) {
@@ -745,7 +756,6 @@ archetype *determine_holy_arch(const object *god, const char *type) {
     }
 
     count = 0;
-    last = NULL;
     for (tr = god->randomitems->items; tr != NULL; tr = tr->next) {
         if (!tr->item)
             continue;
@@ -983,8 +993,10 @@ static int god_enchants_weapon(object *op, const object *god, object *tr, object
  * god player is praying to.
  * @param skill
  * player's praying skill.
+ * @param altar
+ * where the player is praying.
  */
-static void god_intervention(object *op, const object *god, object *skill) {
+static void god_intervention(object *op, const object *god, object *skill, object *altar) {
     treasure *tr;
 
     if (!god || !god->randomitems) {
@@ -1002,6 +1014,9 @@ static void god_intervention(object *op, const object *god, object *skill) {
     draw_ext_info(NDI_UNIQUE, 0, op, MSG_TYPE_SKILL, MSG_TYPE_SKILL_PRAY,
                   "You feel a holy presence!");
 
+    if (altar->anim_suffix != NULL)
+        apply_anim_suffix(altar, altar->anim_suffix);
+
     for (tr = god->randomitems->items; tr != NULL; tr = tr->next) {
         object *item;
 
