@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_init_c =
- *   "$Id: init.c 14252 2011-01-27 05:43:40Z mwedel $";
+ *   "$Id: init.c 16018 2011-12-03 15:13:09Z ryo_saeba $";
  */
 
 /*
@@ -189,18 +189,26 @@ static void showscoresparm(const char *data) {
  * Change the server's port. Will exit() if invalid value.
  *
  * @param val
- * port to use. Must be a valid one, between 1 and 32765 inclusive.
+ * port to use. Must be a valid one, between 1 and 65535 inclusive.
  */
 static void set_csport(const char *val) {
-    settings.csport = atoi(val);
-#ifndef WIN32 /* ***win32: set_csport: we remove csport error secure check here, do this later */
-    if (settings.csport <= 0
-    || settings.csport > 32765
-    || (settings.csport < 1024 && getuid() != 0)) {
-        LOG(llevError, "%d is an invalid csport number.\n", settings.csport);
+    int port = atoi(val);
+    if (port <= 0 || port > 65535) {
+        LOG(llevError, "%d is an invalid csport number, must be between 1 and 65535.\n", port);
         exit(1);
     }
-#endif /* win32 */
+    settings.csport = port;
+}
+
+/**
+ * Disable a plugin.
+ * @param name plugin's name, without extension.
+ */
+static void set_disable_plugin(const char *name) {
+    linked_char *disable = calloc(1, sizeof(linked_char));
+    disable->next = settings.disabled_plugins;
+    disable->name = strdup(name);
+    settings.disabled_plugins = disable;
 }
 
 /** Typedefs used when calling option handlers. */
@@ -257,6 +265,7 @@ static struct Command_Line_Options options[] = {
     { "-tmpdir", 1, 1, set_tmpdir },
     { "-log", 1, 1, set_logfile },
     { "-detach", 0, 1, set_daemon },
+    { "-disable-plugin", 1, 1, set_disable_plugin },
 
 #ifdef WIN32
     /* Windows service stuff */
@@ -365,15 +374,6 @@ static materialtype_t *get_empty_mat(void) {
         mt->save[i] = 0;
         mt->mod[i] = 0;
     }
-    mt->chance = 0;
-    mt->difficulty = 0;
-    mt->magic = 0;
-    mt->damage = 0;
-    mt->wc = 0;
-    mt->ac = 0;
-    mt->sp = 0;
-    mt->weight = 100;
-    mt->value = 100;
     mt->next = NULL;
     return mt;
 }
@@ -446,24 +446,6 @@ static void load_materials(void) {
                 mt->mod[i] = (sint8)value;
                 cp = next;
             }
-        } else if (sscanf(cp, "chance %d\n", &value)) {
-            mt->chance = (sint8)value;
-        } else if (sscanf(cp, "diff %d\n", &value)) {
-            mt->difficulty = (sint8)value;
-        } else if (sscanf(cp, "magic %d\n", &value)) {
-            mt->magic = (sint8)value;
-        } else if (sscanf(cp, "damage %d\n", &value)) {
-            mt->damage = (sint8)value;
-        } else if (sscanf(cp, "wc %d\n", &value)) {
-            mt->wc = (sint8)value;
-        } else if (sscanf(cp, "ac %d\n", &value)) {
-            mt->ac = (sint8)value;
-        } else if (sscanf(cp, "sp %d\n", &value)) {
-            mt->sp = (sint8)value;
-        } else if (sscanf(cp, "weight %d\n", &value)) {
-            mt->weight = value;
-        } else if (sscanf(cp, "value %d\n", &value)) {
-            mt->value = value;
         }
     }
     free(mt->next);
@@ -492,17 +474,18 @@ static void free_materials(void) {
  * information, having it here probably makes more sense.
  */
 static void load_settings(void) {
-    char buf[MAX_BUF], *cp;
-    int has_val, comp;
+    char buf[MAX_BUF], *cp, dummy[1];
+    int has_val;
     FILE *fp;
 
+    dummy[0] = '\0';
     snprintf(buf, sizeof(buf), "%s/settings", settings.confdir);
 
     /* We don't require a settings file at current time, but down the road,
      * there will probably be so many values that not having a settings file
      * will not be a good thing.
      */
-    if ((fp = open_and_uncompress(buf, 0, &comp, "r")) == NULL) {
+    if ((fp = fopen(buf, "r")) == NULL) {
         LOG(llevError, "Warning: No settings file found\n");
         return;
     }
@@ -525,7 +508,7 @@ static void load_settings(void) {
                 *cp++ = 0;
             has_val = 1;
         } else {
-            cp = "";
+            cp = dummy;
             has_val = 0;
         }
 
@@ -866,17 +849,17 @@ static void load_settings(void) {
         } else if (!strcasecmp(buf, "starting_stat_min")) {
             int val = atoi(cp);
 
-            if (val < 1 || val > MAX_STAT || val > settings.starting_stat_max)
+            if (val < 1 || val > settings.max_stat || val > settings.starting_stat_max)
                 LOG(llevError, "load_settings: starting_stat_min (%d) need to be within %d-%d (%d)\n",
-                    val, 1, MAX_STAT, settings.starting_stat_max);
+                    val, 1, settings.max_stat, settings.starting_stat_max);
             else
                 settings.starting_stat_min = val;
         } else if (!strcasecmp(buf, "starting_stat_max")) {
             int val = atoi(cp);
 
-            if (val < 1 || val > MAX_STAT || val<settings.starting_stat_min)
+            if (val < 1 || val > settings.max_stat || val<settings.starting_stat_min)
                 LOG(llevError, "load_settings: starting_stat_max (%d) need to be within %d-%d (%d)\n",
-                    val, 1, MAX_STAT, settings.starting_stat_min);
+                    val, 1, settings.max_stat, settings.starting_stat_min);
             else
                 settings.starting_stat_max = val;
         } else if (!strcasecmp(buf, "starting_stat_points")) {
@@ -901,11 +884,27 @@ static void load_settings(void) {
                     NUM_STATS * 3,  NUM_STATS * 18);
             else
                 settings.roll_stat_points = val;
+        } else if (!strcasecmp(buf, "special_break_map")) {
+            if (!strcasecmp(cp, "on") || !strcasecmp(cp, "true")) {
+                settings.special_break_map = TRUE;
+            } else if (!strcasecmp(cp, "off") || !strcasecmp(cp, "false")) {
+                settings.special_break_map = FALSE;
+            } else {
+                LOG(llevError, "load_settings: unknown value for special_break_map: %s\n", cp);
+            }
+        } else if (!strcasecmp(buf, "ignore_plugin_compatibility")) {
+            if (!strcasecmp(cp, "on") || !strcasecmp(cp, "true")) {
+                settings.ignore_plugin_compatibility = TRUE;
+            } else if (!strcasecmp(cp, "off") || !strcasecmp(cp, "false")) {
+                settings.ignore_plugin_compatibility = FALSE;
+            } else {
+                LOG(llevError, "load_settings: unknown value for ignore_plugin_compatibility: %s\n", cp);
+            }
         } else {
             LOG(llevError, "Unknown value in settings file: %s\n", buf);
         }
     }
-    close_and_delete(fp, comp);
+    fclose(fp);
     if (settings.log_timestamp_format == NULL)
         settings.log_timestamp_format = strdup_local("%y/%m/%d %H:%M:%S");
 
@@ -981,6 +980,12 @@ void free_server(void) {
     free_races();
     free_quest();
     free_quest_definitions();
+    while (settings.disabled_plugins) {
+        linked_char *next = settings.disabled_plugins->next;
+        free(settings.disabled_plugins->name);
+        free(settings.disabled_plugins);
+        settings.disabled_plugins = next;
+    }
 }
 
 static void usage(void) {
@@ -1028,6 +1033,9 @@ static void help(void) {
     printf(" -mt <name>   Dumps out list of treasures for a monster.\n");
     printf(" -mexp        Dumps out the experience table.\n");
     printf(" -mq          Dumps out the list of defined quests.\n");
+    printf(" -disable-plugin\n"
+           "              Disables specified plugin. Use the name without the extension.\n"
+           "              Can be specified multiple times. 'All' disables all plugins.\n");
     exit(0);
 }
 
@@ -1092,14 +1100,13 @@ static void init_beforeplay(void) {
 static void init_startup(void) {
     char buf[MAX_BUF];
     FILE *fp;
-    int comp;
 
 #ifdef SHUTDOWN_FILE
     snprintf(buf, sizeof(buf), "%s/%s", settings.confdir, SHUTDOWN_FILE);
-    if ((fp = open_and_uncompress(buf, 0, &comp, "r")) != NULL) {
+    if ((fp = fopen(buf, "r")) != NULL) {
         while (fgets(buf, MAX_BUF-1, fp) != NULL)
             printf("%s", buf);
-        close_and_delete(fp, comp);
+        fclose(fp);
         exit(1);
     }
 #endif
@@ -1245,7 +1252,6 @@ static void rec_sigpipe(int i) {
     fatal_signal(1); /*Might consider to uncomment this line */
 #endif
 }
-#endif
 
 #ifdef SIGBUS
 /**
@@ -1260,7 +1266,6 @@ static void rec_sigbus(int i) {
 }
 #endif
 
-#ifndef DEBUG
 /**
  * SIGTERM handler.
  *
