@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_login_c =
- *   "$Id: login.c 14125 2010-11-24 19:01:48Z akirschbaum $";
+ *   "$Id: login.c 16766 2012-01-21 11:30:34Z ryo_saeba $";
  */
 
 /*
@@ -119,7 +119,6 @@ void delete_character(const char *name) {
  */
 int verify_player(const char *name, char *password) {
     char buf[MAX_BUF];
-    int comp;
     FILE *fp;
 
     if (strpbrk(name, "/.\\") != NULL) {
@@ -133,7 +132,7 @@ int verify_player(const char *name, char *password) {
         return 1;
     }
 
-    fp = open_and_uncompress(buf, 0, &comp, "r");
+    fp = fopen(buf, "r");
     if (fp == NULL)
         return 1;
 
@@ -146,16 +145,16 @@ int verify_player(const char *name, char *password) {
         if (!strncmp(buf, "password ", 9)) {
             buf[strlen(buf)-1] = 0; /* remove newline */
             if (check_password(password, buf+9)) {
-                close_and_delete(fp, comp);
+                fclose(fp);
                 return 0;
             }
 
-            close_and_delete(fp, comp);
+            fclose(fp);
             return 2;
         }
     }
     LOG(llevDebug, "Could not find a password line in player %s\n", name);
-    close_and_delete(fp, comp);
+    fclose(fp);
     return 1;
 }
 
@@ -349,7 +348,7 @@ int save_player(object *op, int flag) {
         fprintf(fp, "party_rejoin_name %s\n", pl->party->partyname);
         fprintf(fp, "party_rejoin_password %s\n", party_get_password(pl->party));
     }
-    fprintf(fp, "language %d\n", pl->language);
+    fprintf(fp, "language %s\n", i18n_get_language_code(pl->language));
     fprintf(fp, "ticks_played %u\n", pl->ticks_played);
     fprintf(fp, "endplst\n");
 
@@ -429,6 +428,14 @@ int save_player(object *op, int flag) {
         esrv_send_inventory(op, op);
 
     chmod(filename, SAVE_MODE);
+
+    /* if this is the first player save, quest or knowledge states can be unsaved */
+    if (!op->contr->has_directory) {
+        op->contr->has_directory = 1;
+        knowledge_first_player_save(op->contr);
+        quest_first_player_save(op->contr);
+    }
+
     return 1;
 }
 
@@ -500,9 +507,8 @@ void check_login(object *op, int check_pass) {
     FILE *fp;
     char filename[MAX_BUF];
     char buf[MAX_BUF], bufall[MAX_BUF];
-    int i, value, comp;
+    int i, value;
     uint32 uvalue;
-    long checksum = 0;
     player *pl = op->contr, *pltmp;
     int correct = 0;
     time_t elapsed_save_time = 0;
@@ -544,7 +550,7 @@ void check_login(object *op, int check_pass) {
      * the password.  Return control to the higher level dispatch,
      * since the rest of this just deals with loading of the file.
      */
-    fp = open_and_uncompress(filename, 1, &comp, "r");
+    fp = fopen(filename, "r");
     if (fp == NULL) {
         confirm_password(op);
         return;
@@ -562,7 +568,6 @@ void check_login(object *op, int check_pass) {
 
     if (fgets(bufall, MAX_BUF, fp) != NULL) {
         if (!strncmp(bufall, "checksum ", 9)) {
-            checksum = strtol(bufall+9, (char **)NULL, 16);
             (void)fgets(bufall, MAX_BUF, fp);
         }
         if (sscanf(bufall, "password %s\n", buf)) {
@@ -716,9 +721,7 @@ void check_login(object *op, int check_pass) {
             strncpy(party_password, val_string, sizeof(party_password));
             party_password[sizeof(party_password) - 1] = 0;
         } else if (!strcmp(buf, "language")) {
-            if (value < 0 || value >= NUM_LANGUAGES)
-                value = 0;
-            pl->language = value;
+            pl->language = i18n_get_language_by_code(val_string);
         }
         else if (!strcmp(buf, "ticks_played")) {
             pl->ticks_played = uvalue;
@@ -738,7 +741,7 @@ void check_login(object *op, int check_pass) {
     pl->ob = op;
     /* this loads the standard objects values. */
     load_object(fp, op, LO_NEWFILE, 0);
-    close_and_delete(fp, comp);
+    fclose(fp);
 
     CLEAR_FLAG(op, FLAG_NO_FIX_PLAYER);
 
@@ -816,7 +819,7 @@ void check_login(object *op, int check_pass) {
     if (op->stats.hp < 0) {
         draw_ext_info(NDI_UNIQUE, 0, op, MSG_TYPE_ADMIN, MSG_TYPE_ADMIN_LOGIN,
                       "Your character was dead last time you played.");
-        kill_player(op);
+        kill_player(op, NULL);
         if (pl->state != ST_PLAYING)
             return;
     }
@@ -841,8 +844,12 @@ void check_login(object *op, int check_pass) {
      */
     fix_object(op);
 
+    pl->has_directory = 1;
+
     esrv_send_inventory(op, op);
     esrv_send_pickup(pl);
+    quest_send_initial_states(pl);
+    knowledge_send_known(pl);
 
     CLEAR_FLAG(op, FLAG_FRIENDLY);
 
