@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_main_c =
- *    "$Id: main.c 7244 2007-09-26 06:00:09Z mwedel $";
+ *    "$Id: main.c 11217 2009-01-22 18:50:58Z akirschbaum $";
  */
 
 /*
@@ -26,12 +26,24 @@
     The authors can be reached via e-mail at crossfire-devel@real-time.com
 */
 
-#include <global.h>
-#ifndef __CEXTRACT__
-#include <sproto.h>
-#endif
+/**
+ * @file
+ * Server main entry point.
+ */
 
-int main(int argc, char **argv)
-{
-    return server_main(argc,argv);
+#include <global.h>
+#include <sproto.h>
+
+/**
+ * Main entry point.
+ *
+ * @param argc
+ * length of argv.
+ * @param argv
+ * command-line options.
+ * @return
+ * 0.
+ */
+int main(int argc, char **argv) {
+    return server_main(argc, argv);
 }
