@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_monster_c =
- *    "$Id: monster.c 14069 2010-11-06 17:59:53Z ryo_saeba $";
+ *    "$Id: monster.c 15541 2011-11-06 19:21:14Z ryo_saeba $";
  */
 
 /*
@@ -494,7 +494,8 @@ int monster_compute_path(object *source, object *target, int default_dir) {
  * @param op
  * monster. Must have FLAG_MONSTER set.
  */
-static void monster_do_living(object *op) {
+void monster_do_living(object *op) {
+    assert(op);
     assert(QUERY_FLAG(op, FLAG_MONSTER));
 
     /*  generate hp, if applicable */
@@ -630,7 +631,7 @@ static int monster_move_no_enemy(object *op) {
  */
 int monster_move(object *op) {
     int dir, diff;
-    object *owner, *enemy, *part, *oph;
+    object *owner, *enemy, *part;
     rv_vector rv;
 
     /* Monsters not on maps don't do anything.  These monsters are things
@@ -639,9 +640,6 @@ int monster_move(object *op) {
     if (!op->map)
         return 0;
 
-    /* for target facing, we copy this value here for fast access */
-    oph = HEAD(op);                       /* force update the head - one arch one pic */
-
     if (QUERY_FLAG(op, FLAG_NO_ATTACK)) { /* we never ever attack */
         object_set_enemy(op, NULL);
         enemy = NULL;
@@ -654,6 +652,8 @@ int monster_move(object *op) {
         }
     }
 
+    monster_do_living(op);
+
     if (QUERY_FLAG(op, FLAG_SLEEP)
     || QUERY_FLAG(op, FLAG_BLIND)
     || (op->map->darkness > 0 && !QUERY_FLAG(op, FLAG_SEE_IN_DARK) && !QUERY_FLAG(op, FLAG_SEE_INVISIBLE))) {
@@ -671,8 +671,6 @@ int monster_move(object *op) {
     if (op->will_apply)
         monster_apply_below(op); /* Check for items to apply below */
 
-    monster_do_living(op);
-
     /* If we don't have an enemy, do special movement or the like */
     if (!enemy) {
         return monster_move_no_enemy(op);
@@ -2016,7 +2014,7 @@ void monster_do_say(const mapstruct *map, const char *message) {
  * @param message what is being said.
  * @return new StringBuffer containing the text.
  */
-StringBuffer *monster_format_say(const object* npc, const char *message) {
+static StringBuffer *monster_format_say(const object* npc, const char *message) {
     char name[MAX_BUF];
     StringBuffer *buf;
 
