@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_pets_c =
- *    "$Id: pets.c 13518 2010-07-26 18:04:41Z ryo_saeba $";
+ *    "$Id: pets.c 14545 2011-06-12 14:44:40Z ryo_saeba $";
  */
 
 /*
@@ -452,20 +452,16 @@ void pets_move(object *ob) {
  * caster of the spell
  * @param dir
  * direction the monster should be placed in.
- * @param is_golem
- * if set then this is a golem spell.
  * @return
  * suitable golem.
  */
-static object *fix_summon_pet(archetype *at, object *op, int dir, int is_golem) {
+static object *fix_summon_pet(archetype *at, object *op, int dir) {
     archetype *atmp;
     object *tmp = NULL, *prev = NULL, *head = NULL;
 
     for (atmp = at; atmp != NULL; atmp = atmp->more) {
         tmp = arch_to_object(atmp);
         if (atmp == at) {
-            if (!is_golem)
-                SET_FLAG(tmp, FLAG_MONSTER);
 
             /* Ensure the golem can actually move if no move_type defined.
              * This check is redundant since this is checked at server startup. */
@@ -479,8 +475,7 @@ static object *fix_summon_pet(archetype *at, object *op, int dir, int is_golem)
                 tmp->stats.exp = 0;
                 add_friendly_object(tmp);
                 SET_FLAG(tmp, FLAG_FRIENDLY);
-                if (is_golem)
-                    CLEAR_FLAG(tmp, FLAG_MONSTER);
+                CLEAR_FLAG(tmp, FLAG_MONSTER);
             } else if (QUERY_FLAG(op, FLAG_FRIENDLY)) {
                 object *owner = object_get_owner(op);
 
@@ -491,7 +486,7 @@ static object *fix_summon_pet(archetype *at, object *op, int dir, int is_golem)
                     SET_FLAG(tmp, FLAG_FRIENDLY);
                 }
             }
-            if (op->type != PLAYER || !is_golem) {
+            if (op->type != PLAYER) {
                 tmp->attack_movement = PETMOVE;
                 tmp->speed_left = -1;
                 tmp->type = 0;
@@ -743,7 +738,7 @@ int pets_summon_golem(object *op, object *caster, int dir, object *spob) {
         return 0;
     }
     /* basically want to get proper map/coordinates for this object */
-    tmp = fix_summon_pet(at, op, dir, GOLEM);
+    tmp = fix_summon_pet(at, op, dir);
     if (tmp == NULL) {
         draw_ext_info(NDI_UNIQUE, 0, op,
                       MSG_TYPE_SPELL, MSG_TYPE_SPELL_FAILURE,
@@ -781,6 +776,7 @@ int pets_summon_golem(object *op, object *caster, int dir, object *spob) {
     /* but monsters can.  reserve these for players. */
     if (op->type == PLAYER) {
         tmp->stats.hp += spob->duration+SP_level_duration_adjust(caster, spob);
+        tmp->stats.maxhp = tmp->stats.hp;
         if (!spob->stats.dam)
             tmp->stats.dam += SP_level_dam_adjust(caster, spob);
         else
@@ -790,7 +786,7 @@ int pets_summon_golem(object *op, object *caster, int dir, object *spob) {
         if (spob->attacktype)
             tmp->attacktype = spob->attacktype;
     }
-    tmp->stats.wc -= SP_level_range_adjust(caster, spob);
+    tmp->stats.wc -= SP_level_wc_adjust(caster, spob);
 
     /* limit the speed to 0.3 for non-players, 1 for players. */
 
