@@ -51,6 +51,7 @@ typedef struct quest_state {
     int state;                  /**< State for the player. */
     int was_completed;          /**< Whether the quest was completed once or not, indepandently of the state. */
     int is_complete;            /**< Whether the quest is complete in the current playthrough */
+    int sent_to_client;         /**< Whether this state was sent to the client or not. */
     struct quest_state *next;   /**< Next quest on the list. */
 } quest_state;
 
@@ -88,6 +89,8 @@ typedef struct quest_definition {
     sstring quest_title;            /**< Quest title for player. */
     sstring quest_description;      /**< Quest longer description. */
     int quest_restart;              /**< If non zero, can be restarted. */
+    int face;                       /**< Face associated with this quest. */
+    uint32 client_code;             /**< The code used to communicate with the client, merely a unique index. */
     quest_step_definition *steps;   /**< Quest steps. */
     struct quest_definition *parent;/**< Parent for this quest, NULL if it is a 'top-level' quest */
     struct quest_definition *next;  /**< Next quest in the definition list. */
@@ -336,6 +339,18 @@ static int load_quests_from_file(const char *filename) {
                 free_string(questname);
                 continue;
             }
+
+            if (strncmp(read, "face ", 5) == 0) {
+                int face;
+                read[strlen(read) - 1] = '\0';
+                face = find_face(read + 5, 0);
+                if (face == 0) {
+                    LOG(llevError, "Quest %s has invalid face %s.\n", quest->quest_code, read + 5);
+                } else {
+                    quest->face = face;
+                }
+                continue;
+            }
         }
 
         if (read[0] == '#')
@@ -348,7 +363,13 @@ static int load_quests_from_file(const char *filename) {
             if (quest_get_by_code(quest->quest_code)) {
                 LOG(llevError, "Quest %s is listed in file %s, but this quest has already been defined\n", quest->quest_code, filename);
             }
+            /* Set a default face, which will be overwritten if a face is defined. */
+            quest->face = find_face("quest_generic.111", 0);
             quest->next = quests;
+            if (quests != NULL)
+                quest->client_code = quests->client_code + 1;
+            else
+                quest->client_code = 1;
             quests = quest;
             in = QUESTFILE_QUEST;
             loaded_quests++;
@@ -372,7 +393,12 @@ static int load_quests_from_file(const char *filename) {
 
         LOG(llevError, "quest: invalid file format for %s, I don't know what to do with the line %s\n", final, read);
     }
-    LOG(llevError, "quest: quest definition file %s read in, ends with state %d\n", final, in);
+
+    fclose(file);
+
+    if (in != 0)
+        LOG(llevError, "quest: quest definition file %s read in, ends with state %d\n", final, in);
+
     return loaded_quests;
 }
 
@@ -447,7 +473,7 @@ static void quest_read_player_data(quest_player *pq) {
     FILE *file;
     char final[MAX_BUF], read[MAX_BUF], data[MAX_BUF];
     StringBuffer *buf = NULL;
-    quest_state *qs = NULL;
+    quest_state *qs = NULL, *prev = NULL;
     int warned = 0, state;
     quest_definition *quest = NULL;
 
@@ -466,8 +492,12 @@ static void quest_read_player_data(quest_player *pq) {
         if (sscanf(read, "quest %s\n", data)) {
             qs = get_new_quest_state();
             qs->code = add_string(data);
-            qs->next = pq->quests;
-            pq->quests = qs;
+            if (prev == NULL) {
+                pq->quests = qs;
+            } else {
+                prev->next = qs;
+            }
+            prev = qs;
             quest = quest_get_by_code(qs->code);
             if (quest == NULL) {
                 LOG(llevDebug, "Unknown quest %s in quest file %s", qs->code, final);
@@ -581,8 +611,14 @@ static quest_state *get_or_create_state(quest_player *pq, sstring name) {
         if (!qs)
             fatal(OUT_OF_MEMORY);
         qs->code = add_refcount(name);
-        qs->next = pq->quests;
-        pq->quests = qs;
+        if (pq->quests != NULL) {
+            quest_state *last;
+            for (last = pq->quests ; last->next != NULL; last = last->next)
+                ;
+            last->next = qs;
+        } else {
+            pq->quests = qs;
+        }
     }
 
     return qs;
@@ -740,7 +776,41 @@ static void quest_set_state(player *pl, sstring quest_code, int state, int start
         draw_ext_info_format(NDI_UNIQUE, 0, pl->ob, MSG_TYPE_COMMAND, MSG_TYPE_COMMAND_INFO, "New objective for the quest '%s':", quest->quest_title);
         draw_ext_info(NDI_UNIQUE, 0, pl->ob, MSG_TYPE_COMMAND, MSG_TYPE_COMMAND_INFO, step->step_description);
     }
-    quest_write_player_data(pq);
+
+    if (pl->socket.notifications > 0) {
+        SockList sl;
+        SockList_Init(&sl);
+
+        if (qs->sent_to_client) {
+            SockList_AddString(&sl, "updquest ");
+        } else {
+            SockList_AddString(&sl, "addquest ");
+        }
+
+        SockList_AddInt(&sl, quest->client_code);
+        if (qs->sent_to_client == 0) {
+            SockList_AddLen16Data(&sl, quest->quest_title, strlen(quest->quest_title));
+            if (quest->face && !(pl->socket.faces_sent[quest->face]&NS_FACESENT_FACE))
+                esrv_send_face(&pl->socket, quest->face, 0);
+            SockList_AddInt(&sl, quest->face);
+            SockList_AddChar(&sl, quest->quest_restart ? 1 : 0);
+            SockList_AddInt(&sl, quest->parent ? quest->parent->client_code : 0);
+        }
+
+        SockList_AddChar(&sl, (step == NULL || step->is_completion_step) ? 1 : 0);
+        if (step != NULL)
+            SockList_AddLen16Data(&sl, step->step_description, strlen(step->step_description));
+        else
+            SockList_AddShort(&sl, 0);
+
+        Send_With_Handling(&pl->socket, &sl);
+        SockList_Term(&sl);
+
+        qs->sent_to_client = 1;
+    }
+
+    if (pl->has_directory)
+        quest_write_player_data(pq);
     update_quests(pl);
     LOG(llevDebug, "quest_set_player_state %s %s %d\n", pl->ob->name, quest_code, state);
 
@@ -992,7 +1062,6 @@ void quest_start(player *pl, sstring quest_code, int state) {
     quest_player *pq;
     quest_state *q;
     quest_definition *quest;
-    quest_step_definition *step;
 
     quest = quest_get(quest_code);
     if (!quest) {
@@ -1007,8 +1076,6 @@ void quest_start(player *pl, sstring quest_code, int state) {
         LOG(llevDebug, "quest_start: negative state %d for %s quest %s\n", state, pl->ob->name, quest_code);
     }
 
-    step = quest_get_step(quest, state);
-
     /* if completed already, assume the player can redo it */
     if (q->state > 0) {
         LOG(llevDebug, "quest_start: warning: player %s has already started quest %s\n", pl->ob->name, quest_code);
@@ -1129,6 +1196,7 @@ void free_quest(void) {
         next = pq->next;
         free_state(pq);
         free_string(pq->player_name);
+        free(pq);
         pq = next;
     }
     player_states = NULL;
@@ -1172,3 +1240,76 @@ void free_quest_definitions(void) {
     quests = NULL;
     quests_loaded = 0;
 }
+
+/**
+ * Send the current quest states for the specified player, if the client
+ * supports those notifications.
+ * @param pl who to send quests for.
+ */
+void quest_send_initial_states(player *pl) {
+    quest_player *states = NULL;
+    quest_state *state = NULL;
+    SockList sl;
+    size_t size;
+    quest_definition *quest;
+    quest_step_definition *step;
+
+    if (pl->socket.notifications < 1)
+        return;
+
+    /* ensure quest definitions are loaded */
+    quest_load_definitions();
+
+    states = get_or_create_quest(pl);
+
+    SockList_Init(&sl);
+    SockList_AddString(&sl, "addquest ");
+    for (state = states->quests; state != NULL; state = state->next) {
+
+        quest = quest_get_by_code(state->code);
+        if (state->state == -1)
+            step = NULL;
+        else
+            step = quest_get_step(quest, state->state);
+
+        size = 2 + (2 + strlen(quest->quest_title)) + 4 + 1 + (2 + (step != NULL ? strlen(step->step_description) : 0));
+
+        if (SockList_Avail(&sl) < size) {
+            Send_With_Handling(&pl->socket, &sl);
+            SockList_Reset(&sl);
+            SockList_AddString(&sl, "addquest ");
+        }
+
+        SockList_AddInt(&sl, quest->client_code);
+        SockList_AddLen16Data(&sl, quest->quest_title, strlen(quest->quest_title));
+        if (quest->face && !(pl->socket.faces_sent[quest->face]&NS_FACESENT_FACE))
+            esrv_send_face(&pl->socket, quest->face, 0);
+        SockList_AddInt(&sl, quest->face);
+        SockList_AddChar(&sl, quest->quest_restart ? 1 : 0);
+        SockList_AddInt(&sl, quest->parent ? quest->parent->client_code : 0);
+        SockList_AddChar(&sl, (step == NULL || step->is_completion_step) ? 1 : 0);
+        if (step != NULL)
+            SockList_AddLen16Data(&sl, step->step_description, strlen(step->step_description));
+        else
+            SockList_AddShort(&sl, 0);
+
+        state->sent_to_client = 1;
+    }
+
+    Send_With_Handling(&pl->socket, &sl);
+    SockList_Term(&sl);
+}
+
+/**
+ * Ensure the quest state is correctly saved for a player.
+ * This function should only be called once, when the player's save directory
+ * is created. All other quest functions save the state automatically, but save
+ * can only happen when the player directory exists.
+ * @param pl who to save quests for.
+ */
+void quest_first_player_save(player *pl) {
+    quest_player *qp = get_quest(pl);
+    if (qp != NULL && qp->quests != NULL) {
+        quest_write_player_data(qp);
+    }
+}
