@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_resurrection_c =
- *   "$Id: resurrection.c 12599 2010-03-08 18:33:07Z akirschbaum $";
+ *   "$Id: resurrection.c 13308 2010-05-28 06:12:12Z kbulgrien $";
  */
 
 /*
@@ -105,7 +105,6 @@ static int resurrect_player(object *op, char *playername, object *spell) {
 
     if (!(deadplayer = fopen(oldname, "r"))) {
         draw_ext_info_format(NDI_UNIQUE, 0, op, MSG_TYPE_SPELL, MSG_TYPE_SPELL_FAILURE,
-                             "The soul of %s cannot be reached.",
                              "The soul of %s cannot be reached.",
                              playername);
         return 0;
@@ -113,7 +112,6 @@ static int resurrect_player(object *op, char *playername, object *spell) {
 
     if (!access(newname, 0)) {
         draw_ext_info_format(NDI_UNIQUE, 0, op, MSG_TYPE_SPELL, MSG_TYPE_SPELL_FAILURE,
-                             "The soul of %s has already been reborn!",
                              "The soul of %s has already been reborn!",
                              playername);
         fclose(deadplayer);
@@ -122,7 +120,6 @@ static int resurrect_player(object *op, char *playername, object *spell) {
 
     if (!(liveplayer = fopen(newname, "w"))) {
         draw_ext_info_format(NDI_UNIQUE, 0, op, MSG_TYPE_SPELL, MSG_TYPE_SPELL_FAILURE,
-                             "The soul of %s cannot be re-embodied at the moment.",
                              "The soul of %s cannot be re-embodied at the moment.",
                              playername);
         LOG(llevError, "Cannot write player in resurrect_player!\n");
@@ -156,7 +153,6 @@ static int resurrect_player(object *op, char *playername, object *spell) {
     fclose(deadplayer);
     unlink(oldname);
     draw_ext_info_format(NDI_UNIQUE, 0, op, MSG_TYPE_SPELL, MSG_TYPE_SPELL_SUCCESS,
-                         "%s lives again!",
                          "%s lives again!",
                          playername);
 
@@ -195,7 +191,6 @@ int cast_raise_dead_spell(object *op, object *caster, object *spell, int dir, co
     if (spell->last_heal) {
         if (!arg) {
             draw_ext_info_format(NDI_UNIQUE, 0, op, MSG_TYPE_SPELL, MSG_TYPE_SPELL_FAILURE,
-                                 "Cast %s on who?",
                                  "Cast %s on who?",
                                  spell->name);
             return 0;
@@ -224,7 +219,7 @@ int cast_raise_dead_spell(object *op, object *caster, object *spell, int dir, co
 
         if (temp == NULL) {
             draw_ext_info(NDI_UNIQUE, 0, op, MSG_TYPE_SPELL, MSG_TYPE_SPELL_FAILURE,
-                          "You need a body for this spell.", NULL);
+                          "You need a body for this spell.");
             return 0;
         }
         strcpy(name_to_resurrect, temp->name);
