@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_rune_c =
- *   "$Id: rune.c 14152 2010-12-05 12:24:05Z ryo_saeba $";
+ *   "$Id: rune.c 15527 2011-11-06 17:43:01Z ryo_saeba $";
  */
 
 /*
@@ -484,51 +484,3 @@ int trap_disarm(object *disarmer, object *trap, int risk, object *skill) {
         return 0;
     }
 }
-
-/**
- * Adjust trap difficulty to the map.
- * The default traps are too strong for wimpy level 1 players, and
- * unthreatening to anyone of high level
- *
- * @param trap
- * trap to adjust.
- * @param difficulty
- * map difficulty.
- */
-void trap_adjust(object *trap, int difficulty) {
-    int i;
-
-    /* now we set the trap level to match the difficulty of the level
-     * the formula below will give a level from 1 to (2*difficulty) with
-     * a peak probability at difficulty
-     */
-
-    trap->level = rndm(0, difficulty-1)+rndm(0, difficulty-1);
-    if (trap->level < 1)
-        trap->level = 1;
-
-    /* set the hiddenness of the trap, similar formula to above */
-    trap->stats.Cha = rndm(0, 19)+rndm(0, difficulty-1)+rndm(0, difficulty-1);
-
-    if (!trap->other_arch && !trap->inv) {
-        /* set the damage of the trap.
-         * we get 0-4 pts of damage per level of difficulty of the map in
-         * the trap
-         */
-
-        trap->stats.dam = 0;
-        for (i = 0; i < difficulty; i++)
-            trap->stats.dam += rndm(0, 4);
-
-        /*  the poison trap special case */
-        if (trap->attacktype&AT_POISON) {
-            trap->stats.dam = rndm(0, difficulty-1);
-            if (trap->stats.dam < 1)
-                trap->stats.dam = 1;
-        }
-
-        /*  so we get an appropriate amnt of exp for AT_DEATH traps */
-        if (trap->attacktype&AT_DEATH)
-            trap->stats.dam = 127;
-    }
-}
