@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_server_c =
- *    "$Id: server.c 13861 2010-09-23 17:45:36Z ryo_saeba $";
+ *    "$Id: server.c 17458 2012-03-11 17:08:11Z ryo_saeba $";
  */
 
 /*
@@ -209,6 +209,11 @@ static void enter_map(object *op, mapstruct *newmap, int x, int y) {
 
     if (out_of_map(newmap, x, y)) {
         LOG(llevError, "enter_map: supplied coordinates are not within the map! (%s: %d, %d)\n", newmap->path, x, y);
+        /* If op has invalid (probably -1,-1) coordinates, force them to a correct value, else issues later on. */
+        if (op->x == x)
+            op->x = MAP_ENTER_X(newmap);
+        if (op->y == y)
+            op->y = MAP_ENTER_Y(newmap);
         x = MAP_ENTER_X(newmap);
         y = MAP_ENTER_Y(newmap);
         if (out_of_map(newmap, x, y)) {
@@ -532,8 +537,6 @@ static void enter_fixed_template_map(object *pl, object *exit_ob) {
 
         create_pathname(sourcemap, path, MAX_BUF);
         new_map = load_original_map(path, MAP_PLAYER_UNIQUE);
-        if (new_map)
-            apply_auto_fix(new_map);
     }
 
     if (new_map) {
@@ -641,8 +644,6 @@ static void enter_unique_map(object *op, object *exit_ob) {
         if (!newmap) {
             create_pathname(EXIT_PATH(exit_ob), path, sizeof(path));
             newmap = load_original_map(path, MAP_PLAYER_UNIQUE);
-            if (newmap)
-                apply_auto_fix(newmap);
         }
     } else { /* relative directory */
         char reldir[HUGE_BUF], tmpc[HUGE_BUF], *cp;
@@ -662,8 +663,6 @@ static void enter_unique_map(object *op, object *exit_ob) {
             if (!newmap) {
                 create_pathname(path_combine_and_normalize(reldir, EXIT_PATH(exit_ob), tmpc, sizeof(tmpc)), path, sizeof(path));
                 newmap = load_original_map(path, MAP_PLAYER_UNIQUE);
-                if (newmap)
-                    apply_auto_fix(newmap);
             }
         } else {
             /* The exit is unique, but the map we are coming from is not unique.  So
@@ -1209,11 +1208,14 @@ void cleanup(void) {
     free_all_readable();
     free_all_god();
     free_all_anim();
+    i18n_free();
     free_loader();
     free_globals();
     free_server();
     object_free_all_data();
     free_knowledge();
+    free_quest();
+    free_quest_definitions();
     /* See what the string data that is out there that hasn't been freed. */
     /*    LOG(llevDebug, "%s", ss_dump_table(0xff));*/
 #endif
@@ -1295,13 +1297,13 @@ int forbid_play(void) {
     FILE *fp;
     time_t clock;
     struct tm *tm;
-    int i, start, stop, forbit = 0, comp;
+    int i, start, stop, forbit = 0;
 
     clock = time(NULL);
     tm = (struct tm *)localtime(&clock);
 
     snprintf(buf, sizeof(buf), "%s/%s", settings.confdir, PERM_FILE);
-    if ((fp = open_and_uncompress(buf, 0, &comp, "r")) == NULL)
+    if ((fp = fopen(buf, "r")) == NULL)
         return 0;
 
     while (fgets(buf, sizeof(buf), fp)) {
@@ -1326,7 +1328,7 @@ int forbid_play(void) {
         }
     }
 
-    close_and_delete(fp, comp);
+    fclose(fp);
 
     return forbit;
 #else
@@ -1351,6 +1353,10 @@ extern unsigned long todtick;
  * doing the various things.
  */
 static void do_specials(void) {
+
+    if (!(pticks%10))
+        knowledge_process_incremental();
+
 #ifdef WATCHDOG
     if (!(pticks%503))
         watchdog();
