@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_skill_util_c =
- *   "$Id: skill_util.c 14070 2010-11-06 18:02:34Z ryo_saeba $";
+ *   "$Id: skill_util.c 16506 2012-01-07 18:22:35Z ryo_saeba $";
  */
 /*
     CrossFire, A Multiplayer game for X-windows
@@ -64,6 +64,10 @@ static void attack_melee_weapon(object *op, int dir, const char *string, object
  * Will contain a number-name mapping for skills, initialized by init_skills().
  */
 const char *skill_names[NUM_SKILLS];
+/**
+ * Will contain the face numbers for the skills, initialized by init_skill().
+ */
+int skill_faces[NUM_SKILLS];
 
 /**
  * This just sets up the ::skill_names table above. The index into the array is set up by the
@@ -73,8 +77,10 @@ void init_skills(void) {
     int i;
     archetype *at;
 
-    for (i = 0; i < NUM_SKILLS; i++)
+    for (i = 0; i < NUM_SKILLS; i++) {
         skill_names[i] = NULL;
+        skill_faces[i] = -1;
+    }
 
     for (at = first_archetype; at != NULL; at = at->next) {
         if (at->clone.type == SKILL) {
@@ -85,6 +91,8 @@ void init_skills(void) {
                     at->clone.subtype, skill_names[at->clone.subtype], at->clone.skill);
             } else {
                 skill_names[at->clone.subtype] = add_refcount(at->clone.skill);
+                if (at->clone.face != NULL)
+                    skill_faces[at->clone.subtype] = at->clone.face->number;
             }
         }
     }
@@ -553,7 +561,7 @@ int do_skill(object *op, object *part, object *skill, int dir, const char *strin
         break;
 
     case SK_THROWING:
-        success = skill_throw(op, part, dir, string, skill);
+        success = skill_throw(op, part, dir, skill);
         break;
 
     case SK_SET_TRAP:
