@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_skills_c =
- *   "$Id: skills.c 14102 2010-11-19 06:35:42Z mwedel $";
+ *   "$Id: skills.c 16383 2011-12-30 20:00:44Z ryo_saeba $";
  */
 /*
     CrossFire, A Multiplayer game for X-windows
@@ -149,8 +149,8 @@ static int attempt_steal(object *op, object *who, object *skill) {
          * might be to use force objects for this - MSW 2009/02/24
          */
         op->stats.Wis += (op->stats.Int/5)+1;
-        if (op->stats.Wis > MAX_STAT)
-            op->stats.Wis = MAX_STAT;
+        if (op->stats.Wis > settings.max_stat)
+            op->stats.Wis = settings.max_stat;
     }
     if (op->type == PLAYER && QUERY_FLAG(op, FLAG_WIZ)) {
         draw_ext_info(NDI_UNIQUE, 0, who, MSG_TYPE_SKILL, MSG_TYPE_SKILL_FAILURE,
@@ -179,7 +179,6 @@ static int attempt_steal(object *op, object *who, object *skill) {
         if (QUERY_FLAG(inv, FLAG_WAS_WIZ)
         || QUERY_FLAG(inv, FLAG_APPLIED)
         || !(inv->type)
-        || inv->type == EXPERIENCE
         || inv->type == SPELL
         || QUERY_FLAG(inv, FLAG_STARTEQUIP)
         || QUERY_FLAG(inv, FLAG_NO_STEAL)
@@ -1761,23 +1760,18 @@ int write_on_item(object *pl, const char *params, object *skill) {
 
 /**
  * Find an object to throw.
- * If we request an object, then
- * we search for it in the inventory of the owner (you've
- * got to be carrying something in order to throw it!).
- * If we didnt request an object, then the top object in inventory
- * (that is "throwable", ie no throwing your skills away!)
- * is the object of choice. Also check to see if object is
- * 'throwable' (ie not applied cursed obj, worn, etc).
+ * If there is a suitable marked item, use it.
+ * Else find the first item that is of the correct race.
  *
  * @param op
  * object wishing to throw.
- * @param request
- * requested item to throw.
+ * @param race
+ * 'throwing' race.
  * @return
  * throwable object, NULL if none suitable found.
  */
-static object *find_throw_ob(object *op, const char *request) {
-    object *tmp, *other = NULL;
+static object *find_throw_ob(object *op, sstring race) {
+    object *tmp;
     char name[MAX_BUF];
 
     if (!op) { /* safety */
@@ -1794,29 +1788,32 @@ static object *find_throw_ob(object *op, const char *request) {
         }
     }
 
-    /* look through the inventory */
+    /* look through the inventory if no marked found */
     if (tmp == NULL) {
         FOR_INV_PREPARE(op, tmp2) {
-            /* can't toss invisible or inv-locked items */
-            if (tmp2->invisible || QUERY_FLAG(tmp2, FLAG_INV_LOCKED))
+            /* can't toss invisible items */
+            if (tmp2->invisible)
                 continue;
-            query_name(tmp2, name, MAX_BUF);
-            if (!request
-                || !strcmp(name, request)
-                || !strcmp(tmp2->name, request)) {
-                if (QUERY_FLAG(tmp2, FLAG_IS_THROWN)) {
-                    tmp = tmp2;
+
+            if (tmp2->type == CONTAINER && QUERY_FLAG(tmp2, FLAG_APPLIED) && tmp2->race == race) {
+                tmp = find_throw_ob(tmp2, race);
+                if (tmp != NULL) {
                     break;
                 }
-                if (other == NULL)
-                    other = tmp2;
             }
+
+            /* if not a container, then don't look if locked */
+            if (tmp2->type == CONTAINER || QUERY_FLAG(tmp2, FLAG_INV_LOCKED))
+                continue;
+
+            if (tmp2->race == race) {
+                tmp = tmp2;
+                break;
+            }
+
         } FOR_INV_FINISH();
     }
 
-    if (tmp == NULL)
-        tmp = other;
-
     /* this should prevent us from throwing away
      * cursed items, worn armour, etc. Only weapons
      * can be thrown from 'hand'.
@@ -1913,7 +1910,6 @@ static object *make_throw_ob(object *orig) {
  */
 static int do_throw(object *op, object *part, object *toss_item, int dir, object *skill) {
     object *throw_ob = toss_item, *left = NULL;
-    tag_t left_tag;
     int eff_str = 0, str = op->stats.Str, dam = 0;
     int pause_f, weight_f = 0, mflags;
     float str_factor = 1.0, load_factor = 1.0, item_factor = 1.0;
@@ -1949,10 +1945,10 @@ static int do_throw(object *op, object *part, object *toss_item, int dir, object
      * we use the concept of 'effective strength' as defined below.
      */
 
-    /* if str exceeds MAX_STAT (30, eg giants), lets assign a str_factor > 1 */
-    if (str > MAX_STAT) {
-        str_factor = (float)str/(float)MAX_STAT;
-        str = MAX_STAT;
+    /* if str exceeds settings.max_stat (30, eg giants), lets assign a str_factor > 1 */
+    if (str > settings.max_stat) {
+        str_factor = (float)str/(float)settings.max_stat;
+        str = settings.max_stat;
     }
 
     /* the more we carry, the less we can throw. Limit only on players */
@@ -1978,10 +1974,10 @@ static int do_throw(object *op, object *part, object *toss_item, int dir, object
     eff_str = str*MIN(load_factor, 1.0);
     eff_str = (float)eff_str*item_factor*str_factor;
 
-    /* alas, arrays limit us to a value of MAX_STAT (30). Use str_factor to
+    /* alas, arrays limit us to a value of settings.max_stat (30). Use str_factor to
      * account for super-strong throwers. */
-    if (eff_str > MAX_STAT)
-        eff_str = MAX_STAT;
+    if (eff_str > settings.max_stat)
+        eff_str = settings.max_stat;
 
 #ifdef DEBUG_THROW
     LOG(llevDebug, "%s carries %d, eff_str=%d\n", op->name, op->carrying, eff_str);
@@ -2022,8 +2018,6 @@ static int do_throw(object *op, object *part, object *toss_item, int dir, object
     } /* if object can't be thrown */
 
     left = throw_ob; /* these are throwing objects left to the player */
-    /* BUG? The value in left_tag doesn't seem to be used. */
-    left_tag = left->count;
 
     /* sometimes object_split() can't split an object (because op->nrof==0?)
      * and returns NULL. We must use 'left' then
@@ -2076,7 +2070,7 @@ static int do_throw(object *op, object *part, object *toss_item, int dir, object
     throw_ob->speed = MIN(1.0, throw_ob->speed); /* no faster than an arrow! */
 
     /* item damage. Eff_str and item weight influence damage done */
-    weight_f = MIN(throw_ob->weight/2000, MAX_STAT);
+    weight_f = MIN(throw_ob->weight/2000, settings.max_stat);
     throw_ob->stats.dam += (dam/3)+get_dam_bonus(weight_f)+(throw_ob->weight/15000)-2;
 
     /* chance of breaking. Proportional to force used and weight of item */
@@ -2097,7 +2091,7 @@ static int do_throw(object *op, object *part, object *toss_item, int dir, object
         throw_ob->stats.wc -= throw_ob->magic+throw_ob->inv->stats.wc;
         /* only throw objects get directional faces */
         if (GET_ANIM_ID(throw_ob) && NUM_ANIMATIONS(throw_ob))
-            SET_ANIMATION(throw_ob, dir);
+            object_update_turn_face(throw_ob);
     } else {
         /* some materials will adjust properties.. */
         if (throw_ob->material&M_LEATHER) {
@@ -2177,8 +2171,6 @@ static int do_throw(object *op, object *part, object *toss_item, int dir, object
  * actual part of op throwing.
  * @param dir
  * direction to throw into.
- * @param params
- * optional message, used to find object to throw.
  * @param skill
  * throwing skill.
  * @retval 0
@@ -2186,11 +2178,11 @@ static int do_throw(object *op, object *part, object *toss_item, int dir, object
  * @retval 1
  * skill was successfully used.
  */
-int skill_throw(object *op, object *part, int dir, const char *params, object *skill) {
+int skill_throw(object *op, object *part, int dir, object *skill) {
     object *throw_ob;
 
     if (op->type == PLAYER)
-        throw_ob = find_throw_ob(op, params);
+        throw_ob = find_throw_ob(op, find_string("throwing"));
     else
         throw_ob = monster_find_throw_ob(op);
 
