@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_spell_attack_c =
- *   "$Id: spell_attack.c 13723 2010-09-04 09:15:12Z ryo_saeba $";
+ *   "$Id: spell_attack.c 17054 2012-02-11 16:43:03Z ryo_saeba $";
  */
 
 /*
@@ -94,8 +94,7 @@ int fire_bolt(object *op, object *caster, int dir, object *spob) {
     tmp->stats.Con = spob->stats.Con;
 
     tmp->direction = dir;
-    if (QUERY_FLAG(tmp, FLAG_IS_TURNABLE))
-        SET_ANIMATION(tmp, dir);
+    object_update_turn_face(tmp);
 
     object_set_owner(tmp, op);
     set_spell_skill(op, caster, spob, tmp);
@@ -558,9 +557,8 @@ int cast_smite_spell(object *op, object *caster, int dir, object *spell) {
     const object *god = find_god(determine_god(op));
     int range;
 
-    /* BUG? The value in range doesn't seem to be used. */
     range = spell->range+SP_level_range_adjust(caster, spell);
-    target = get_pointed_target(op, dir, 50, spell->stats.grace ? SPELL_GRACE : SPELL_MANA);
+    target = get_pointed_target(op, dir, range, spell->stats.grace ? SPELL_GRACE : SPELL_MANA);
 
     /* Bunch of conditions for casting this spell.  Note that only
      * require a god if this is a cleric spell (requires grace).
@@ -906,7 +904,7 @@ int cast_curse(object *op, object *caster, object *spell_ob, int dir) {
 int mood_change(object *op, object *caster, object *spell) {
     object *tmp, *head;
     const object *god;
-    int done_one, range, mflags, level, at, best_at;
+    int done_one, range, mflags, level, at, best_at, immunity_chance = 50;
     sint16 x, y, nx, ny;
     mapstruct *m;
     const char *race;
@@ -917,6 +915,14 @@ int mood_change(object *op, object *caster, object *spell) {
     god = find_god(determine_god(op));
     level = caster_level(caster, spell);
     range = spell->range+SP_level_range_adjust(caster, spell);
+    race = object_get_value(spell, "immunity_chance");
+    if (race != NULL) {
+        immunity_chance = atoi(race);
+        if (immunity_chance < 0 || immunity_chance > 100) {
+            LOG(llevError, "ignoring invalid immunity_chance %d for %s\n", immunity_chance, spell->arch->name);
+            immunity_chance = 50;
+        }
+    }
 
     /* On the bright side, no monster should ever have a race of GOD_...
      * so even if the player doesn't worship a god, if race=GOD_.., it
@@ -990,9 +996,13 @@ int mood_change(object *op, object *caster, object *spell) {
                  */
                 if (head->level > level)
                     continue;
-                if (random_roll(0, 100, caster, PREFER_LOW) >= (20+MIN(50, 2*(level-head->level))))
-                    /* Failed, no effect */
+                if (random_roll(0, 100, caster, PREFER_LOW) >= (20+MIN(50, 2*(level-head->level)))) {
+                    /* Additionnally, randomly make the monster immune to that spell. */
+                    if (random_roll(0, 100, caster, PREFER_HIGH) <= immunity_chance) {
+                        object_set_value(head, "no_mood_change", "1", 1);
+                    }
                     continue;
+                }
 
                 /*
                  * There was no way to ensure immunity, so added a key/value for that.
