@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_spell_util_c =
- *   "$Id: spell_util.c 13852 2010-09-21 21:05:20Z ryo_saeba $";
+ *   "$Id: spell_util.c 16793 2012-01-22 15:44:23Z ryo_saeba $";
  */
 
 
@@ -404,6 +404,37 @@ int SP_level_range_adjust(const object *caster, const object *spob) {
     return adj;
 }
 
+/**
+ * Returns adjusted wc based on the caster and the spell.
+ *
+ * @param caster
+ * who is casting.
+ * @param spob
+ * spell we are adjusting.
+ * @return
+ * adjusted wc (positive is best).
+ */
+int SP_level_wc_adjust(const object *caster, const object *spob) {
+    int level = caster_level(caster, spob);
+    int adj = level - min_casting_level(caster, spob), irate;
+    sstring rate;
+
+    rate = object_get_value(spob, "wc_increase_rate");
+
+    if (rate == NULL)
+        return 0;
+
+    if (adj < 0)
+        adj = 0;
+
+    irate = atoi(rate);
+    if (irate > 0)
+        adj /= irate;
+    else
+        adj = 0;
+    return adj;
+}
+
 /**
  * Checks to see if player knows the spell.  If the name is the same
  * as an existing spell, we presume they know it.
@@ -656,6 +687,11 @@ int fire_arch_from_position(object *op, object *caster, sint16 x, sint16 y, int
     int mflags;
     mapstruct *m;
 
+    if (dir < 0 || dir > 8) {
+        LOG(llevError, "Invalid direction %d in fire_arch_from_position for %s\n", dir, spell->name);
+        dir = RANDOM() % 8 + 1;
+    }
+
     if (spell->other_arch == NULL)
         return 0;
 
@@ -692,8 +728,8 @@ int fire_arch_from_position(object *op, object *caster, sint16 x, sint16 y, int
         tmp->stats.maxhp = spell->range+SP_level_range_adjust(caster, spell);
         tmp->dam_modifier = spell->stats.food+SP_level_dam_adjust(caster, spell);
 
-        if (QUERY_FLAG(tmp, FLAG_IS_TURNABLE))
-            SET_ANIMATION(tmp, dir);
+        tmp->direction = dir;
+        object_update_turn_face(tmp);
 
         object_set_owner(tmp, op);
     } else {
@@ -753,8 +789,7 @@ int fire_arch_from_position(object *op, object *caster, sint16 x, sint16 y, int
             if (!tailor_god_spell(tmp, op))
                 return 0;
         }
-        if (QUERY_FLAG(tmp, FLAG_IS_TURNABLE))
-            SET_ANIMATION(tmp, dir);
+        object_update_turn_face(tmp);
 
         tmp = object_insert_in_map_at(tmp, tmp->map, op, 0, tmp->x, tmp->y);
         if (tmp != NULL)
@@ -1098,7 +1133,7 @@ static void prayer_failure(object *op, int failure, int power) {
                              "%s requires you to pray NOW. You comply, ignoring all else.",
                              godname);
 
-        paralyze_living(op, op, 99);
+        paralyze_living(op, 99);
     } else if (failure <= -150) { /* blast the immediate area */
         tmp = create_archetype(GOD_POWER);
         draw_ext_info_format(NDI_UNIQUE, 0, op, MSG_TYPE_SPELL, MSG_TYPE_SPELL_FAILURE,
@@ -1144,7 +1179,7 @@ void spell_failure(object *op, int failure, int power, object *skill) {
     } else if (failure <= -60 && failure > -80) { /* paralysis */
         draw_ext_info(NDI_UNIQUE, 0, op, MSG_TYPE_SPELL, MSG_TYPE_SPELL_FAILURE,
                       "Your magic stuns you!");
-        paralyze_living(op, op, 99);
+        paralyze_living(op, 99);
     } else if (failure <= -80) { /* blast the immediate area */
         object *tmp;
 
@@ -1245,9 +1280,9 @@ static void transmute_item_to_flower(object *op) {
     if (QUERY_FLAG(item, FLAG_APPLIED))
         apply_manual(op, item, AP_NOPRINT|AP_IGNORE_CURSE|AP_UNAPPLY);
     object_remove(item);
-    flower->weight = item->nrof ? item->nrof*item->weight : item->weight;
+    flower->weight = item->nrof ? ((sint32)item->nrof)*item->weight : item->weight;
     item->weight = 0;
-    esrv_del_item(op->contr, item->count);
+    esrv_del_item(op->contr, item);
     object_insert_in_ob(item, force);
 
     query_short_name(item, name, HUGE_BUF);
@@ -1330,7 +1365,8 @@ static int spell_consume_items(object *op, const object *spell_ob) {
     char *copy;
     char *ingredients[10];
     object *found[10];
-    int count, i, nrof[10];
+    int count, i;
+    uint32 nrof[10];
     char name_ob[MAX_BUF];
     const char *name2;
 
@@ -1541,7 +1577,7 @@ int cast_spell(object *op, object *caster, int dir, object *spell_ob, char *stri
 
             /* player/monster is trying to cast the spell.  might fumble it */
             if (spell_ob->stats.grace
-            && random_roll(0, 99, op, PREFER_HIGH) < (spell_ob->level/(float)MAX(1, op->level)*get_cleric_chance(op->stats.Wis))) {
+                && random_roll(0, 99, op, PREFER_HIGH) < (get_cleric_chance(op->stats.Wis) * spell_ob->level/MAX(1, op->level))) {
                 play_sound_player_only(op->contr, SOUND_TYPE_SPELL, spell_ob, 0, "fumble");
                 draw_ext_info(NDI_UNIQUE, 0, op, MSG_TYPE_SPELL, MSG_TYPE_SPELL_FAILURE,
                               "You fumble the spell.");
@@ -1803,7 +1839,11 @@ int cast_spell(object *op, object *caster, int dir, object *spell_ob, char *stri
         break;
 
     case SP_PROBE:
-        success = probe(op, caster, spell_ob, dir);
+        if (op != caster)
+            cast_level = caster->level;
+        else
+            cast_level = skill != NULL ? skill->level : op->level;
+        success = probe(op, caster, spell_ob, dir, cast_level);
         break;
 
     case SP_HEALING:
