@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_sock_info_c =
- *   "$Id: info.c 12620 2010-03-12 20:17:40Z akirschbaum $";
+ *   "$Id: info.c 14057 2010-11-06 11:22:31Z ryo_saeba $";
  */
 
 /*
@@ -63,51 +63,37 @@ void print_ext_msg(socket_struct *ns, int color, uint8 type, uint8 subtype, cons
     SockList_Term(&sl);
 }
 
-/**
- * For printing messages to a file
- * \param colr message color
- * \param pl player to send to. Can be NULL
- * \param tmp message to send. Can be NULL
- *
- * This writes the message to a logfile.  Since the only
- * function that calls this is draw_ext_info() below,
- * and the only event it will call this routine is if the
- * player is null, it always print to the logfile.
- *
- */
-
-static void print_message(int colr, const object *pl, const char *tmp) {
-    if (tmp == NULL) {
-        tmp = "[NULL]";
-    }
-    fprintf(logfile, "%s\n", tmp);
-}
-
 /**
  * Sends message to player(s).
  *
- * @param flags Various flags - mostly color, plus a few specials.
+ * @param flags Various flags - mostly color, plus a few specials.  If NDI_ALL
+ * or NDI_ALL_DMS is set, pl is ignored and the message is resent to all
+ * players or all DMs individually.
  *
- * @param pri Priority.  It is a little odd - the lower the value, the more
- * important it is.  Thus, 0 gets sent no matter what.  Otherwise, the
- * value must be less than the listening level that the player has set.
- * Unfortunately, there is no clear guideline on what each level does what.
+ * @param pri Priority.  The lower the value, the more important it is.  Thus,
+ * 0 gets sent no matter what.  Otherwise, the value must be less than the
+ * listening level that the player has set.  Unfortunately, there is no clear
+ * guideline on what each level does what.
  *
- * @param pl Can be passed as NULL - in fact, this will be done if NDI_ALL is
- * set in the flags.
+ * @param pl Who to send the message to.  pl may be NULL, particularly if
+ * flags has NDI_ALL or NDI_DMS set since it is ignored in that case.  If
+ * NDI_ALL and NDI_DMS are not set, when pl is NULL, nobody gets the message.
+ * This is sometimes useful when a function that can be invoked by a player
+ * is automatically called by some other mechanism.  For example, if a player
+ * tries to put something in a container, they should get a message that tells
+ * them they cannot put it in an unsuitable container, but when auto-pickup is
+ * at work, all containers are tried, even unsuitable ones, and so messages
+ * should not be sent to the player.
  *
  * @param type The type MSG_TYPE for the type of message.
  *
- * @param subtype The type MSG_TYPE for the type of message.
+ * @param subtype The subtype of the message.
  *
- * @param message The message to send for clients that support draw_ext_info.
- *
- * @param oldmessage is for clients that do not support it.  oldmessage can be
- * NULL, in which case this function will strip out the tags of message.
+ * @param message The message to send.
  */
 void draw_ext_info(
     int flags, int pri, const object *pl, uint8 type,
-    uint8 subtype, const char *message, const char *oldmessage) {
+    uint8 subtype, const char *message) {
 
     if ((flags&NDI_ALL) || (flags&NDI_ALL_DMS)) {
         player *tmppl;
@@ -115,24 +101,20 @@ void draw_ext_info(
         for (tmppl = first_player; tmppl != NULL; tmppl = tmppl->next) {
             if ((flags&NDI_ALL_DMS) && !QUERY_FLAG(tmppl->ob, FLAG_WIZ))
                 continue;
-            draw_ext_info((flags&~NDI_ALL&~NDI_ALL_DMS), pri, tmppl->ob, type, subtype, message, oldmessage);
+            draw_ext_info((flags&~NDI_ALL&~NDI_ALL_DMS), pri, tmppl->ob, type, subtype, message);
         }
 
         return;
     }
 
-    if (!pl || (pl->type == PLAYER && pl->contr == NULL)) {
-        /* Write to the socket? */
-        print_message(0, NULL, oldmessage);
+    if (!pl || (pl->type == PLAYER && pl->contr == NULL))
         return;
-    }
     if (pl->type != PLAYER)
         return;
     if (pri >= pl->contr->listening)
         return;
 
     print_ext_msg(&pl->contr->socket, flags&NDI_COLOR_MASK, type, subtype, message);
-
 }
 
 /**
@@ -141,8 +123,7 @@ void draw_ext_info(
  *  This function is the same as draw_ext_info, but takes varargs format.
  *  Otherwise, the meaning of all the fields is the same.  This is perhaps not
  *  the most efficient as we do vsnprintf on both the old and newbuf, but it
- *  simplifies the code greatly since we can just call draw_ext_info.  Also,
- *  hopefully at some point, need for old_format will go away.
+ *  simplifies the code greatly since we can just call draw_ext_info.
  *
  * @param flags Various flags - mostly color, plus a few specials.
  *
@@ -158,61 +139,53 @@ void draw_ext_info(
  *
  * @param subtype The type MSG_TYPE for the type of message.
  *
- * @param new_format
- *
- * @param old_format
+ * @param format The message to send, with optional format specifiers.
  */
-void draw_ext_info_format(int flags, int pri, const object *pl, uint8 type, uint8 subtype, const char *new_format, const char *old_format, ...) {
-    char newbuf[HUGE_BUF], oldbuf[HUGE_BUF];
+void draw_ext_info_format(int flags, int pri, const object *pl, uint8 type, uint8 subtype, const char *format, ...) {
+    char buf[HUGE_BUF];
     va_list ap;
 
-    if (!old_format)
-        old_format = new_format;
-
-    va_start(ap, old_format);
-    vsnprintf(oldbuf, HUGE_BUF, old_format, ap);
-    va_end(ap);
-    va_start(ap, old_format);
-    vsnprintf(newbuf, HUGE_BUF, new_format, ap);
+    va_start(ap, format);
+    vsnprintf(buf, HUGE_BUF, format, ap);
     va_end(ap);
 
-    draw_ext_info(flags, pri, pl, type, subtype, newbuf, oldbuf);
+    draw_ext_info(flags, pri, pl, type, subtype, buf);
 }
 
 /**
  * Writes to everyone on the specified map
  */
-void ext_info_map(int color, const mapstruct *map, uint8 type, uint8 subtype, const char *str1, const char *str2) {
+void ext_info_map(int color, const mapstruct *map, uint8 type, uint8 subtype, const char *str1) {
     player *pl;
 
     for (pl = first_player; pl != NULL; pl = pl->next)
         if (pl->ob != NULL && pl->ob->map == map) {
-            draw_ext_info(color, 0, pl->ob, type, subtype, str1, str2);
+            draw_ext_info(color, 0, pl->ob, type, subtype, str1);
         }
 }
 
 /**
  * Writes to everyone on the map *except *op.  This is useful for emotions.
  */
-void ext_info_map_except(int color, const mapstruct *map, const object *op, uint8 type, uint8 subtype, const char *str1, const char *str2) {
+void ext_info_map_except(int color, const mapstruct *map, const object *op, uint8 type, uint8 subtype, const char *str1) {
     player *pl;
 
     for (pl = first_player; pl != NULL; pl = pl->next)
         if (pl->ob != NULL && pl->ob->map == map && pl->ob != op) {
-            draw_ext_info(color, 0, pl->ob, type, subtype, str1, str2);
+            draw_ext_info(color, 0, pl->ob, type, subtype, str1);
         }
 }
 
 /**
  * Writes to everyone on the map except op1 and op2
  */
-void ext_info_map_except2(int color, const mapstruct *map, const object *op1, const object *op2, int type, int subtype, const char *str1, const char *str2) {
+void ext_info_map_except2(int color, const mapstruct *map, const object *op1, const object *op2, int type, int subtype, const char *str1) {
     player *pl;
 
     for (pl = first_player; pl != NULL; pl = pl->next)
         if (pl->ob != NULL && pl->ob->map == map
                 && pl->ob != op1 && pl->ob != op2) {
-            draw_ext_info(color, 0, pl->ob, type, subtype, str1, str2);
+            draw_ext_info(color, 0, pl->ob, type, subtype, str1);
         }
 }
 
@@ -314,7 +287,7 @@ static void magic_mapping_mark_recursive(object *pl, char *map_mark, int px, int
     int x, y, dx, dy, mflags, l;
     sint16 nx, ny;
     mapstruct *mp;
-    New_Face *f;
+    const New_Face *f;
     object *ob;
 
     for (dx = -1; dx <= 1; dx++) {
@@ -377,7 +350,7 @@ void magic_mapping_mark(object *pl, char *map_mark, int strength) {
     int x, y, mflags, l;
     sint16 nx, ny;
     mapstruct *mp;
-    New_Face *f;
+    const New_Face *f;
     object *ob;
 
     for (x = -strength; x < strength; x++) {
@@ -422,8 +395,6 @@ void draw_magic_map(object *pl) {
     int x, y;
     char map_mark[MAGIC_MAP_SIZE*MAGIC_MAP_SIZE];
     int xmin, xmax, ymin, ymax;
-    /* This is to prevent stack smashing below. */
-    int max_width;
     SockList sl;
 
     if (pl->type != PLAYER) {
@@ -444,10 +415,9 @@ void draw_magic_map(object *pl) {
     ymin = MAGIC_MAP_SIZE;
     xmax = 0;
     ymax = 0;
-    max_width = (MAP_WIDTH(pl->map) > MAGIC_MAP_SIZE) ? MAGIC_MAP_SIZE : MAP_WIDTH(pl->map);
     for (x = 0; x < MAGIC_MAP_SIZE; x++) {
         for (y = 0; y < MAGIC_MAP_SIZE; y++) {
-            if (map_mark[x+max_width*y]&~FACE_FLOOR) {
+            if (map_mark[x+MAGIC_MAP_SIZE*y]&~FACE_FLOOR) {
                 xmin = MIN(x, xmin);
                 xmax = MAX(x, xmax);
                 ymin = MIN(y, ymin);
