@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_init_c =
- *    "$Id: init.c 13986 2010-10-10 14:17:30Z anmaster $";
+ *    "$Id: init.c 17000 2012-02-07 18:56:31Z ryo_saeba $";
  */
 
 /*
@@ -44,7 +44,6 @@
 #ifndef WIN32 /* ---win32 exclude include files */
 #include <sys/types.h>
 #include <sys/time.h>
-#include <sys/socket.h>
 #include <netinet/in.h>
 #include <netdb.h>
 #endif /* win32 */
@@ -61,9 +60,13 @@
 
 /** Socket information. */
 Socket_Info socket_info;
+
 /**
  * Established connections for clients not yet playing.  See the page on
  * @ref page_connection "the login process" for a description of its use.
+ * Socket at index 0 is the socket listening for connections, and must not
+ * be freed.
+ * If this socket becomes invalid, then the server will try to reopen it.
  */
 socket_struct *init_sockets;
 
@@ -108,13 +111,16 @@ void init_connection(socket_struct *ns, const char *from_ip) {
     ns->faceset = 0;
     ns->facecache = 0;
     ns->sound = 0;
+    ns->sounds_this_tick = 0;
     ns->monitor_spells = 0;
     ns->darkness = 1;
     ns->status = Ns_Add;
     ns->mapx = 11;
     ns->mapy = 11;
     ns->look_position = 0;
+    ns->container_position = 0;
     ns->update_look = 0;
+    ns->update_inventory = 0;
     ns->tick = 0;
     ns->is_bot = 0;
     ns->num_look_objects = DEFAULT_NUM_LOOK_OBJECTS;
@@ -123,6 +129,7 @@ void init_connection(socket_struct *ns, const char *from_ip) {
     ns->account_name = NULL;
     ns->account_chars = NULL;
     ns->login_method = 0;
+    ns->notifications = 0;
 
     /* we should really do some checking here - if total clients overflows
      * we need to do something more intelligent, because client id's will start
@@ -162,20 +169,122 @@ void init_connection(socket_struct *ns, const char *from_ip) {
     Send_With_Handling(ns, &sl);
     SockList_Term(&sl);
 #ifdef CS_LOGSTATS
-    if (socket_info.nconns > cst_tot.max_conn)
-        cst_tot.max_conn = socket_info.nconns;
-    if (socket_info.nconns > cst_lst.max_conn)
-        cst_lst.max_conn = socket_info.nconns;
+    if (socket_info.allocated_sockets > cst_tot.max_conn)
+        cst_tot.max_conn = socket_info.allocated_sockets;
+    if (socket_info.allocated_sockets > cst_lst.max_conn)
+        cst_lst.max_conn = socket_info.allocated_sockets;
 #endif
 }
 
-/** This sets up the socket and reads all the image information into memory. */
-void init_server(void) {
-    struct sockaddr_in insock;
-    struct protoent *protox;
+/**
+ * This opens *ns for listening to connections.
+ * The structure must be allocated already and
+ * ns->listen must be initialized.
+ * No other variable is changed.
+ */
+void init_listening_socket(socket_struct *ns) {
     struct linger linger_opt;
+    char buf1[MAX_BUF], buf2[MAX_BUF];
     char err[MAX_BUF];
 
+    if (ns == NULL || ns->listen == NULL) {
+        LOG(llevError, "init_listening_socket: missing listen info in socket_struct?!\n");
+        fatal(SEE_LAST_ERROR);
+    }
+
+    ns->status = Ns_Dead;
+
+    ns->fd = socket(ns->listen->family, ns->listen->socktype, ns->listen->protocol);
+    if (ns->fd == -1) {
+        LOG(llevError, "Cannot create socket: %s\n", strerror_local(errno, err, sizeof(err)));
+        return;
+    }
+
+    linger_opt.l_onoff = 0;
+    linger_opt.l_linger = 0;
+    if (setsockopt(ns->fd, SOL_SOCKET, SO_LINGER, (char *)&linger_opt, sizeof(struct linger))) {
+        LOG(llevError, "Cannot setsockopt(SO_LINGER): %s\n", strerror_local(errno, err, sizeof(err)));
+    }
+/* Would be nice to have an autoconf check for this.  It appears that
+ * these functions are both using the same calling syntax, just one
+ * of them needs extra valus passed.
+ */
+#if defined(__osf__) || defined(hpux) || defined(sgi) || defined(NeXT) || \
+    defined(__sun__) || defined(__linux__) || defined(SVR4) ||          \
+    defined(__FreeBSD__) || defined(__OpenBSD__) ||                     \
+    defined(WIN32) /* ---win32 add this here */  ||                     \
+    defined(__GNU__) /* HURD */
+    {
+#ifdef WIN32
+        char tmp = 1;
+#else
+        int tmp = 1;
+#endif
+
+        if (setsockopt(ns->fd, SOL_SOCKET, SO_REUSEADDR, &tmp, sizeof(tmp))) {
+            LOG(llevError, "Cannot setsockopt(SO_REUSEADDR): %s\n", strerror_local(errno, err, sizeof(err)));
+        }
+#ifdef HAVE_GETADDRINFO
+        if ((ns->listen->family == AF_INET6) && setsockopt(ns->fd, IPPROTO_IPV6, IPV6_V6ONLY, &tmp, sizeof(tmp))) {
+            LOG(llevError, "Cannot setsockopt(IPV6_V6ONLY): %s\n", strerror_local(errno, err, sizeof(err)));
+        }
+#endif
+    }
+#else
+    if (setsockopt(ns->fd, SOL_SOCKET, SO_REUSEADDR, (char *)NULL, 0)) {
+        LOG(llevError, "Cannot setsockopt(SO_REUSEADDR): %s\n", strerror_local(errno, err, sizeof(err)));
+    }
+#endif
+
+    if (bind(ns->fd, ns->listen->addr, ns->listen->addrlen) == (-1)) {
+#ifdef HAVE_GETNAMEINFO
+        getnameinfo(ns->listen->addr, ns->listen->addrlen, buf1, sizeof(buf1), buf2, sizeof(buf2), NI_NUMERICHOST|NI_NUMERICSERV);
+#else
+        short port;
+        long ip;
+
+        ip = ntohl(((struct sockaddr_in *)ns->listen->addr)->sin_addr.s_addr);
+        port = ntohs(((struct sockaddr_in *)ns->listen->addr)->sin_port);
+        snprintf(buf1, sizeof(buf1), "%ld.%ld.%ld.%ld", (ip>>24)&255, (ip>>16)&255, (ip>>8)&255, ip&255);
+        snprintf(buf2, sizeof(buf2), "%d", port&65535);
+#endif
+        LOG(llevError, "Cannot bind socket to [%s]:%s: %s\n", buf1, buf2, strerror_local(errno, err, sizeof(err)));
+#ifdef WIN32 /* ***win32: close() -> closesocket() */
+        shutdown(ns->fd, SD_BOTH);
+        closesocket(ns->fd);
+#else
+        close(ns->fd);
+#endif /* win32 */
+        ns->fd = -1;
+        return;
+    }
+    if (listen(ns->fd, 5) == (-1))  {
+        LOG(llevError, "Cannot listen on socket: %s\n", strerror_local(errno, err, sizeof(err)));
+#ifdef WIN32 /* ***win32: close() -> closesocket() */
+        shutdown(ns->fd, SD_BOTH);
+        closesocket(ns->fd);
+#else
+        close(ns->fd);
+#endif /* win32 */
+        ns->fd = -1;
+        return;
+    }
+    ns->status = Ns_Add;
+}
+
+/** This sets up the socket and reads all the image information into memory.
+ * @todo fix socket_info.max_filedescriptor hack. */
+void init_server(void) {
+    int i, e, listen_socket_count;
+#ifdef HAVE_GETADDRINFO
+    struct addrinfo *ai, *ai_p;
+    struct addrinfo hints;
+    char buf[MAX_BUF];
+#else
+    struct sockaddr_in *insock;
+    struct protoent *protox;
+#endif
+
 #ifdef WIN32 /* ***win32  -  we init a windows socket */
     WSADATA w;
 
@@ -196,9 +305,22 @@ void init_server(void) {
 #endif
 #endif /* win32 */
 
+    /*
+     * There is a bug on FreeBSD 9 in that the value we get here is over 1024,
+     * which is the limit FD_ZERO and friends will use.
+     * So later on file descriptors are not correctly cleared, and select() fails.
+     * Therefore here's a hack to prevent that, but the real solution would be
+     * to figure why this happens and how to fix it.
+     * Nicolas W, 2012 feb 07.
+     */
+    if (socket_info.max_filedescriptor > 1024) {
+        LOG(llevDebug, "warning, socket_info.max_filedescriptor is %d, setting to 1024.\n", socket_info.max_filedescriptor);
+        socket_info.max_filedescriptor = 1024;
+    }
+    /* end of hack */
+
     socket_info.timeout.tv_sec = 0;
     socket_info.timeout.tv_usec = 0;
-    socket_info.nconns = 0;
 
 #ifdef CS_LOGSTATS
     memset(&cst_tot, 0, sizeof(CS_Stats));
@@ -207,79 +329,72 @@ void init_server(void) {
     cst_lst.time_start = time(NULL);
 #endif
 
-    LOG(llevDebug, "Initialize new client/server data\n");
-    socket_info.nconns = 1;
-    init_sockets = malloc(sizeof(socket_struct));
-    init_sockets[0].faces_sent = NULL; /* unused */
-    init_sockets[0].account_name = NULL; /* Must be set to avoid undef behaviour elsewhere. */
-    socket_info.allocated_sockets = 1;
+#ifdef HAVE_GETADDRINFO
+    memset(&hints, '\0', sizeof(hints));
+    hints.ai_flags = AI_PASSIVE | AI_ADDRCONFIG;
+    hints.ai_socktype = SOCK_STREAM;
+    snprintf(buf, sizeof(buf), "%d", settings.csport);
+    e = getaddrinfo(NULL, buf, &hints, &ai);
+    if (e != 0) {
+        LOG(llevError, "init_server: getaddrinfo: %s\n", gai_strerror(e));
+        fatal(SEE_LAST_ERROR);
+    }
 
+    listen_socket_count = 0;
+    for (ai_p = ai; ai_p != NULL; ai_p = ai_p->ai_next) {
+        listen_socket_count++;
+    }
+#else
+    listen_socket_count = 1;
+#endif
+
+    LOG(llevDebug, "Initialize new client/server data\n");
+    init_sockets = malloc(sizeof(socket_struct) * listen_socket_count);
+    socket_info.allocated_sockets = listen_socket_count;
+    for (i = 0; i < listen_socket_count; i++) {
+        init_sockets[i].listen = calloc(sizeof(struct listen_info), 1);
+        init_sockets[i].faces_sent = NULL; /* unused */
+        init_sockets[i].account_name = NULL; /* Must be set to avoid undef behaviour elsewhere. */
+    }
+
+#ifdef HAVE_GETADDRINFO
+    for (i = 0, ai_p = ai; i < listen_socket_count && ai_p != NULL; i++, ai_p = ai_p->ai_next) {
+        init_sockets[i].listen->family   = ai_p->ai_family;
+        init_sockets[i].listen->socktype = ai_p->ai_socktype;
+        init_sockets[i].listen->protocol = ai_p->ai_protocol;
+        init_sockets[i].listen->addrlen  = ai_p->ai_addrlen;
+        init_sockets[i].listen->addr     = malloc(ai_p->ai_addrlen);
+        memcpy(init_sockets[i].listen->addr, ai_p->ai_addr, ai_p->ai_addrlen);
+    }
+    freeaddrinfo(ai);
+#else
     protox = getprotobyname("tcp");
     if (protox == NULL) {
         LOG(llevError, "init_server: Error getting protox\n");
-        return;
+        fatal(SEE_LAST_ERROR);
     }
-    init_sockets[0].fd = socket(PF_INET, SOCK_STREAM, protox->p_proto);
-    if (init_sockets[0].fd == -1) {
-        LOG(llevError, "Cannot create socket: %s\n", strerror_local(errno, err, sizeof(err)));
-        exit(-1);
-    }
-    insock.sin_family = AF_INET;
-    insock.sin_port = htons(settings.csport);
-    insock.sin_addr.s_addr = htonl(INADDR_ANY);
-
-    linger_opt.l_onoff = 0;
-    linger_opt.l_linger = 0;
-    if (setsockopt(init_sockets[0].fd, SOL_SOCKET, SO_LINGER, (char *)&linger_opt, sizeof(struct linger))) {
-        LOG(llevError, "Cannot setsockopt(SO_LINGER): %s\n", strerror_local(errno, err, sizeof(err)));
-    }
-/* Would be nice to have an autoconf check for this.  It appears that
- * these functions are both using the same calling syntax, just one
- * of them needs extra valus passed.
- */
-#if defined(__osf__) || defined(hpux) || defined(sgi) || defined(NeXT) || \
-    defined(__sun__) || defined(__linux__) || defined(SVR4) ||          \
-    defined(__FreeBSD__) || defined(__OpenBSD__) ||                     \
-    defined(WIN32) /* ---win32 add this here */  ||                     \
-    defined(__GNU__) /* HURD */
-    {
-#ifdef WIN32
-        char tmp = 1;
-#else
-        int tmp = 1;
+    init_sockets[0].listen->family   = PF_INET;
+    init_sockets[0].listen->socktype = SOCK_STREAM;
+    init_sockets[0].listen->protocol = protox->p_proto;
+    insock = calloc(sizeof(struct sockaddr_in), 1);
+    insock->sin_family = AF_INET;
+    insock->sin_port = htons(settings.csport);
+    insock->sin_addr.s_addr = htonl(INADDR_ANY);
+    init_sockets[0].listen->addr = (struct sockaddr *) insock;
+    init_sockets[0].listen->addrlen = sizeof(struct sockaddr_in);
 #endif
 
-        if (setsockopt(init_sockets[0].fd, SOL_SOCKET, SO_REUSEADDR, &tmp, sizeof(tmp))) {
-            LOG(llevError, "Cannot setsockopt(SO_REUSEADDR): %s\n", strerror_local(errno, err, sizeof(err)));
-        }
+    e = 1;
+    for (i = 0; i < listen_socket_count; i++) {
+        init_listening_socket(&init_sockets[i]);
+        if (init_sockets[i].fd != -1)
+            e = 0;
     }
-#else
-    if (setsockopt(init_sockets[0].fd, SOL_SOCKET, SO_REUSEADDR, (char *)NULL, 0)) {
-        LOG(llevError, "Cannot setsockopt(SO_REUSEADDR): %s\n", strerror_local(errno, err, sizeof(err)));
+    if (e != 0) {
+        LOG(llevError, "init_server: can't open any listening socket\n");
+        fatal(SEE_LAST_ERROR);
     }
-#endif
 
-    if (bind(init_sockets[0].fd, (struct sockaddr *)&insock, sizeof(insock)) == (-1)) {
-        LOG(llevError, "Cannot bind socket to port %d: %s\n", ntohs(insock.sin_port), strerror_local(errno, err, sizeof(err)));
-#ifdef WIN32 /* ***win32: close() -> closesocket() */
-        shutdown(init_sockets[0].fd, SD_BOTH);
-        closesocket(init_sockets[0].fd);
-#else
-        close(init_sockets[0].fd);
-#endif /* win32 */
-        exit(-1);
-    }
-    if (listen(init_sockets[0].fd, 5) == (-1))  {
-        LOG(llevError, "Cannot listen on socket: %s\n", strerror_local(errno, err, sizeof(err)));
-#ifdef WIN32 /* ***win32: close() -> closesocket() */
-        shutdown(init_sockets[0].fd, SD_BOTH);
-        closesocket(init_sockets[0].fd);
-#else
-        close(init_sockets[0].fd);
-#endif /* win32 */
-        exit(-1);
-    }
-    init_sockets[0].status = Ns_Add;
     read_client_images();
 }
 
@@ -291,8 +406,13 @@ void init_server(void) {
 
 /** Free's all the memory that ericserver allocates. */
 void free_all_newserver(void) {
+    int i;
     LOG(llevDebug, "Freeing all new client/server information.\n");
     free_socket_images();
+    for (i = 0; i < socket_info.allocated_sockets && init_sockets[i].listen; i++) {
+        free(init_sockets[i].listen->addr);
+        free(init_sockets[i].listen);
+    }
     free(init_sockets);
 }
 
