@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_item_c =
- *    "$Id: item.c 13919 2010-09-26 18:38:29Z ryo_saeba $";
+ *    "$Id: item.c 14838 2011-07-10 11:00:56Z ryo_saeba $";
  */
 
 /*
@@ -136,8 +136,13 @@ static void add_object_to_socklist(socket_struct *ns, SockList *sl, object *head
     if (!(ns->faces_sent[head->face->number]&NS_FACESENT_FACE))
         esrv_send_face(ns, head->face->number, 0);
 
-    if (QUERY_FLAG(head, FLAG_ANIMATE) && !ns->anims_sent[head->animation_id])
-        esrv_send_animation(ns, head->animation_id);
+    if (QUERY_FLAG(head, FLAG_ANIMATE)) {
+        if (head->animation_id == 0) {
+            LOG(llevError, "Item %s in %s (%d,%d) has FLAG_ANIMATE but animation_id 0\n", head->name, (head->env ? head->env->name : (head->map ? head->map->path : "???")), head->x, head->y);
+            CLEAR_FLAG(head, FLAG_ANIMATE);
+        } else if (!ns->anims_sent[head->animation_id])
+            esrv_send_animation(ns, head->animation_id);
+    }
 
     SockList_AddInt(sl, head->count);
     SockList_AddInt(sl, flags);
@@ -305,11 +310,16 @@ void esrv_draw_look(object *pl) {
 }
 
 /**
- * Sends whole inventory.
+ * Sends inventory of a container. If pl == op, then the whole contents are sent,
+ * else the contents is sent with "next group" and "prev group" arrows if required.
+ * @param pl who to send to.
+ * @param op what item's contents to send.
  */
 void esrv_send_inventory(object *pl, object *op) {
-    int got_one = 0;
+    int got_one = 0, start_look = 0, end_look = 0, objects_sent = 0;
     SockList sl;
+    char buf[MAX_BUF];
+    int prev_len = pl->contr->socket.num_look_objects - 2 - (((pl->contr->socket.container_position > pl->contr->socket.num_look_objects - 1)) ? 1 : 0);
 
     SockList_Init(&sl);
     SockList_AddPrintf(&sl, "delinv %u", op->count);
@@ -318,12 +328,50 @@ void esrv_send_inventory(object *pl, object *op) {
     SockList_Reset(&sl);
     SockList_AddString(&sl, "item2 ");
     SockList_AddInt(&sl, op->count);
+    objects_sent++;
+
+    if (pl != op && pl->contr->socket.container_position) {
+        SockList_AddInt(&sl, 0x80000000|MAX(0, pl->contr->socket.container_position-prev_len));
+        SockList_AddInt(&sl, 0);
+        SockList_AddInt(&sl, -1);
+        SockList_AddInt(&sl, empty_face->number);
+        snprintf(buf, sizeof(buf), "Click here to see previous group of items");
+        SockList_AddLen8Data(&sl, buf, MIN(strlen(buf), 255));
+        SockList_AddShort(&sl, 0);
+        SockList_AddChar(&sl, 0);
+        SockList_AddInt(&sl, 0);
+        SockList_AddShort(&sl, 0);
+        objects_sent++;
+        got_one++;
+    }
 
     FOR_INV_PREPARE(op, tmp) {
         object *head;
 
         head = HEAD(tmp);
         if (LOOK_OBJ(head)) {
+            if (start_look++ < pl->contr->socket.container_position && pl != op)
+                continue;
+            end_look++;
+            objects_sent++;
+            if (pl != op && objects_sent >= pl->contr->socket.num_look_objects) {
+                /* What we basically do is make a 'fake' object -
+                 * when the user applies it, we notice the special
+                 * tag the object has, and act accordingly.
+                 */
+                SockList_AddInt(&sl, 0x80000000|(pl->contr->socket.container_position + end_look - 1));
+                SockList_AddInt(&sl, 0);
+                SockList_AddInt(&sl, -1);
+                SockList_AddInt(&sl, empty_face->number);
+                snprintf(buf, sizeof(buf), "Click here to see next group of items");
+                SockList_AddLen8Data(&sl, buf, MIN(strlen(buf), 255));
+                SockList_AddShort(&sl, 0);
+                SockList_AddChar(&sl, 0);
+                SockList_AddInt(&sl, 0);
+                SockList_AddShort(&sl, 0);
+                break;
+            }
+
             add_object_to_socklist(&pl->contr->socket, &sl, head);
 
             got_one++;
@@ -341,8 +389,19 @@ void esrv_send_inventory(object *pl, object *op) {
             }
         } /* If LOOK_OBJ() */
     } FOR_INV_FINISH();
-    if (got_one)
-        Send_With_Handling(&pl->contr->socket, &sl);
+    if (got_one) {
+        /* special case: only one item, the "prev group" arrow */
+        if (pl != op && pl->contr->socket.container_position) {
+            if (got_one > 1)
+                Send_With_Handling(&pl->contr->socket, &sl);
+            else {
+                /* view shifted, get to previous page and resend */
+                pl->contr->socket.container_position = MAX(0, pl->contr->socket.container_position - prev_len);
+                esrv_send_inventory(pl, op);
+            }
+        } else
+            Send_With_Handling(&pl->contr->socket, &sl);
+    }
     SockList_Term(&sl);
 }
 
@@ -491,6 +550,11 @@ void esrv_send_item(object *pl, object*op) {
     Send_With_Handling(&pl->contr->socket, &sl);
     SET_FLAG(op, FLAG_CLIENT_SENT);
     SockList_Term(&sl);
+
+    /* if the object is in an opened container, then it may shift the contents,
+     * so resend everything */
+    if (pl->contr != NULL && pl->container != NULL && op->env == pl->container)
+        pl->contr->socket.update_inventory = 1;
 }
 
 /**
@@ -498,14 +562,18 @@ void esrv_send_item(object *pl, object*op) {
  * command with a -1 location.
  */
 
-void esrv_del_item(player *pl, int tag) {
+void esrv_del_item(player *pl, object *ob) {
     SockList sl;
 
     SockList_Init(&sl);
     SockList_AddString(&sl, "delitem ");
-    SockList_AddInt(&sl, tag);
+    SockList_AddInt(&sl, ob->count);
     Send_With_Handling(&pl->socket, &sl);
     SockList_Term(&sl);
+    /* if the object is in an opened container, then it may shift the contents,
+     * so resend everything */
+    if (pl->ob->container != NULL && ob->env == pl->ob->container)
+        pl->socket.update_inventory = 1;
 }
 
 /**************************************************************************
@@ -596,8 +664,14 @@ void apply_cmd(char *buf, int len, player *pl) {
 
     /* If the high bit is set, player applied a pseudo object. */
     if (tag&0x80000000) {
-        pl->socket.look_position = tag&0x7fffffff;
-        pl->socket.update_look = 1;
+        if (pl->ob->container != NULL) {
+            pl->socket.container_position = tag&0x7fffffff;
+            esrv_send_inventory(pl->ob, pl->ob->container);
+            pl->socket.update_inventory = 0;
+        } else {
+            pl->socket.look_position = tag&0x7fffffff;
+            pl->socket.update_look = 1;
+        }
         return;
     }
 
@@ -627,6 +701,18 @@ void lock_item_cmd(uint8 *data, int len, player *pl) {
                       "Could not find object to lock/unlock");
         return;
     }
+
+    if (op->map) {
+        draw_ext_info(NDI_UNIQUE, 0, pl->ob, MSG_TYPE_COMMAND, MSG_TYPE_COMMAND_ERROR,
+            "Can't lock/unlock an item on the ground");
+        return;
+    }
+    if (op->env != pl->ob) {
+        draw_ext_info(NDI_UNIQUE, 0, pl->ob, MSG_TYPE_COMMAND, MSG_TYPE_COMMAND_ERROR,
+            "Can't lock/unlock an item not directly in your inventory");
+        return;
+    }
+
     if (!flag)
         CLEAR_FLAG(op, FLAG_INV_LOCKED);
     else
