@@ -1,7 +1,7 @@
 
 /*
  * static char *rcsid_loop_c =
- *    "$Id: loop.c 14015 2010-10-21 06:20:33Z mwedel $";
+ *    "$Id: loop.c 16608 2012-01-14 18:09:49Z ryo_saeba $";
  */
 
 /*
@@ -47,7 +47,6 @@
 #ifndef WIN32 /* ---win32 exclude unix headers */
 #include <sys/types.h>
 #include <sys/time.h>
-#include <sys/socket.h>
 #include <netinet/in.h>
 #include <netdb.h>
 #endif /* end win32 */
@@ -135,6 +134,7 @@ static const struct client_cmd_mapping client_commands[] = {
     { "accountnew",         account_new_cmd },
     { "accountaddplayer",   account_add_player_cmd },
     { "accountplay",        account_play_cmd },
+    { "accountpw",          account_password },
     { "createplayer",       create_player_cmd },
     { NULL,                  NULL }                       /* terminator (I, II & III)*/
 };
@@ -193,6 +193,8 @@ void request_info_cmd(char *buf, int len, socket_struct *ns) {
         send_new_char_info(ns);
     else if (!strcmp(buf,"startingmap"))
         send_map_info(ns);
+    else if (!strcmp(buf, "knowledge_info"))
+        knowledge_send_info(ns);
     else
         Send_With_Handling(ns, &sl);
     SockList_Term(&sl);
@@ -321,6 +323,7 @@ static void block_until_new_connection(void) {
     struct timeval Timeout;
     fd_set readfs;
     int cycles;
+    int i;
 
     LOG(llevInfo, "Waiting for connections...\n");
 
@@ -334,7 +337,9 @@ static void block_until_new_connection(void) {
             tick_the_clock();
 
         FD_ZERO(&readfs);
-        FD_SET((uint32)init_sockets[0].fd, &readfs);
+        for (i = 0; i < socket_info.allocated_sockets && init_sockets[i].listen; i++)
+            if (init_sockets[i].status == Ns_Add)
+                FD_SET((uint32)init_sockets[i].fd, &readfs);
 
         /* If fastclock is set, we need to seriously slow down the updates
          * to the metaserver as well as watchdog.  Do same for flush_old_maps() -
@@ -384,6 +389,75 @@ static int is_fd_valid(int fd) {
 #endif
 }
 
+static void new_connection(int listen_fd) {
+    int newsocknum = -1, j;
+#ifdef HAVE_GETNAMEINFO
+    struct sockaddr_storage addr;
+#else
+    struct sockaddr_in addr;
+#endif
+    socklen_t addrlen = sizeof(addr);
+    char err[MAX_BUF];
+
+#ifdef ESRV_DEBUG
+    LOG(llevDebug, "do_server: New Connection\n");
+#endif
+
+    for (j = 0; j < socket_info.allocated_sockets; j++)
+        if (init_sockets[j].status == Ns_Avail) {
+            newsocknum = j;
+            break;
+        }
+
+    if (newsocknum == -1) {
+        /* If this is the case, all sockets currently in used */
+        init_sockets = realloc(init_sockets, sizeof(socket_struct)*(socket_info.allocated_sockets+1));
+        if (!init_sockets)
+            fatal(OUT_OF_MEMORY);
+        newsocknum = socket_info.allocated_sockets;
+        socket_info.allocated_sockets++;
+        init_sockets[newsocknum].listen = NULL;
+        init_sockets[newsocknum].faces_sent_len = nrofpixmaps;
+        init_sockets[newsocknum].faces_sent = calloc(1, nrofpixmaps*sizeof(*init_sockets[newsocknum].faces_sent));
+        if (!init_sockets[newsocknum].faces_sent)
+            fatal(OUT_OF_MEMORY);
+        init_sockets[newsocknum].status = Ns_Avail;
+    }
+
+    if (newsocknum < 0) {
+        LOG(llevError, "FATAL: didn't allocate a newsocket?? alloc = %d, newsocknum = %d", socket_info.allocated_sockets, newsocknum);
+        fatal(SEE_LAST_ERROR);
+    }
+
+    init_sockets[newsocknum].fd = accept(listen_fd, (struct sockaddr *)&addr, &addrlen);
+    if (init_sockets[newsocknum].fd == -1) {
+        LOG(llevError, "accept failed: %s\n", strerror_local(errno, err, sizeof(err)));
+    } else {
+        char buf[MAX_BUF];
+#ifndef HAVE_GETNAMEINFO
+        long ip;
+#endif
+        socket_struct *ns;
+
+        ns = &init_sockets[newsocknum];
+
+#ifdef HAVE_GETNAMEINFO
+        getnameinfo((struct sockaddr *) &addr, addrlen, buf, sizeof(buf), NULL, 0, NI_NUMERICHOST);
+#else
+        ip = ntohl(addr.sin_addr.s_addr);
+        snprintf(buf, sizeof(buf), "%ld.%ld.%ld.%ld", (ip>>24)&255, (ip>>16)&255, (ip>>8)&255, ip&255);
+#endif
+
+        if (checkbanned(NULL, buf)) {
+            LOG(llevInfo, "Banned host tried to connect: [%s]\n", buf);
+            close(init_sockets[newsocknum].fd);
+            init_sockets[newsocknum].fd = -1;
+        } else {
+            init_connection(ns, buf);
+        }
+    }
+}
+
 /**
  * This checks the sockets for input and exceptions, does the right thing.
  *
@@ -392,10 +466,8 @@ static int is_fd_valid(int fd) {
  *
  */
 void do_server(void) {
-    int i, pollret;
+    int i, pollret, active = 0;
     fd_set tmp_read, tmp_exceptions, tmp_write;
-    struct sockaddr_in addr;
-    socklen_t addrlen = sizeof(struct sockaddr);
     player *pl, *next;
     char err[MAX_BUF];
 
@@ -414,13 +486,18 @@ void do_server(void) {
             init_sockets[i].status = Ns_Dead;
         }
         if (init_sockets[i].status == Ns_Dead) {
-            free_newsocket(&init_sockets[i]);
-            init_sockets[i].status = Ns_Avail;
-            socket_info.nconns--;
+            if (init_sockets[i].listen) {
+                /* try to reopen the listening socket */
+                init_listening_socket(&init_sockets[i]);
+            } else {
+                free_newsocket(&init_sockets[i]);
+                init_sockets[i].status = Ns_Avail;
+            }
         } else if (init_sockets[i].status != Ns_Avail) {
             FD_SET((uint32)init_sockets[i].fd, &tmp_read);
             FD_SET((uint32)init_sockets[i].fd, &tmp_write);
             FD_SET((uint32)init_sockets[i].fd, &tmp_exceptions);
+            active++;
         }
     }
 
@@ -448,7 +525,7 @@ void do_server(void) {
         }
     }
 
-    if (socket_info.nconns == 1 && first_player == NULL)
+    if (active == 1 && first_player == NULL)
         block_until_new_connection();
 
     /* Reset timeout each time, since some OS's will change the values on
@@ -467,71 +544,22 @@ void do_server(void) {
     /* We need to do some of the processing below regardless */
     /*    if (!pollret) return;*/
 
-    /* Following adds a new connection */
-    if (pollret && FD_ISSET(init_sockets[0].fd, &tmp_read)) {
-        int newsocknum = 0;
-
-#ifdef ESRV_DEBUG
-        LOG(llevDebug, "do_server: New Connection\n");
-#endif
-        /* If this is the case, all sockets currently in used */
-        if (socket_info.allocated_sockets <= socket_info.nconns) {
-            init_sockets = realloc(init_sockets, sizeof(socket_struct)*(socket_info.nconns+1));
-            if (!init_sockets)
-                fatal(OUT_OF_MEMORY);
-            newsocknum = socket_info.allocated_sockets;
-            socket_info.allocated_sockets++;
-            init_sockets[newsocknum].faces_sent_len = nrofpixmaps;
-            init_sockets[newsocknum].faces_sent = calloc(1, nrofpixmaps*sizeof(*init_sockets[newsocknum].faces_sent));
-            if (!init_sockets[newsocknum].faces_sent)
-                fatal(OUT_OF_MEMORY);
-            init_sockets[newsocknum].status = Ns_Avail;
-        } else {
-            int j;
-
-            for (j = 1; j < socket_info.allocated_sockets; j++)
-                if (init_sockets[j].status == Ns_Avail) {
-                    newsocknum = j;
-                    break;
-                }
-        }
-        init_sockets[newsocknum].fd = accept(init_sockets[0].fd, (struct sockaddr *)&addr, &addrlen);
-        if (init_sockets[newsocknum].fd == -1) {
-            LOG(llevError, "accept failed: %s\n", strerror_local(errno, err, sizeof(err)));
-        } else {
-            char buf[MAX_BUF];
-            long ip;
-            socket_struct *ns;
-
-            ns = &init_sockets[newsocknum];
-
-            ip = ntohl(addr.sin_addr.s_addr);
-            snprintf(buf, sizeof(buf), "%ld.%ld.%ld.%ld", (ip>>24)&255, (ip>>16)&255, (ip>>8)&255, ip&255);
-
-            if (checkbanned(NULL, buf)) {
-                LOG(llevInfo, "Banned host tried to connect: [%s]\n", buf);
-                close(init_sockets[newsocknum].fd);
-                init_sockets[newsocknum].fd = -1;
-            } else {
-                init_connection(ns, buf);
-                socket_info.nconns++;
-            }
-        }
-    }
-
     /* Check for any exceptions/input on the sockets */
     if (pollret)
-        for (i = 1; i < socket_info.allocated_sockets; i++) {
-            if (init_sockets[i].status == Ns_Avail)
+        for (i = 0; i < socket_info.allocated_sockets; i++) {
+            /* listen sockets can stay in status Ns_Dead */
+            if (init_sockets[i].status != Ns_Add)
                 continue;
             if (FD_ISSET(init_sockets[i].fd, &tmp_exceptions)) {
                 free_newsocket(&init_sockets[i]);
                 init_sockets[i].status = Ns_Avail;
-                socket_info.nconns--;
                 continue;
             }
             if (FD_ISSET(init_sockets[i].fd, &tmp_read)) {
-                handle_client(&init_sockets[i], NULL);
+                if (init_sockets[i].listen)
+                    new_connection(init_sockets[i].fd);
+                else
+                    handle_client(&init_sockets[i], NULL);
             }
             if (FD_ISSET(init_sockets[i].fd, &tmp_write)) {
                 init_sockets[i].can_write = 1;
@@ -600,6 +628,11 @@ void do_server(void) {
                 draw_client_map(pl->ob);
                 if (pl->socket.update_look)
                     esrv_draw_look(pl->ob);
+                if (pl->socket.update_inventory) {
+                    if (pl->ob->container != NULL)
+                        esrv_send_inventory(pl->ob, pl->ob->container);
+                    pl->socket.update_inventory = 0;
+                }
                 if (pl->socket.tick)
                     send_tick(pl);
             }
