@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_sockets_c =
- *    "$Id: lowlevel.c 14015 2010-10-21 06:20:33Z mwedel $";
+ *    "$Id: lowlevel.c 14914 2011-07-24 10:02:41Z ryo_saeba $";
  */
 
 /*
@@ -580,7 +580,7 @@ CS_Stats cst_tot, cst_lst;
 void write_cs_stats(void) {
     time_t now = time(NULL);
 
-    /* If no connections recently, don't both to log anything */
+    /* If no connections recently, don't bother to log anything */
     if (cst_lst.ibytes == 0 && cst_lst.obytes == 0)
         return;
 
@@ -591,7 +591,7 @@ void write_cs_stats(void) {
         cst_lst.max_conn, (long)(now-cst_lst.time_start));
     cst_lst.ibytes = 0;
     cst_lst.obytes = 0;
-    cst_lst.max_conn = socket_info.nconns;
+    cst_lst.max_conn = socket_info.allocated_sockets;
     cst_lst.time_start = now;
 }
 #endif
