@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_metaserver_c =
- *    "$Id: metaserver.c 14245 2011-01-23 06:06:03Z mwedel $";
+ *    "$Id: metaserver.c 15225 2011-10-21 17:41:22Z ryo_saeba $";
  */
 
 /*
@@ -36,7 +36,6 @@
 
 #ifndef WIN32 /* ---win32 exclude unix header files */
 #include <sys/types.h>
-#include <sys/socket.h>
 #include <netinet/in.h>
 #include <netdb.h>
 #include <arpa/inet.h>
@@ -49,14 +48,9 @@
 
 #ifdef HAVE_CURL_CURL_H
 #include <curl/curl.h>
-#include <curl/types.h>
 #include <curl/easy.h>
 #endif
 
-static int metafd = -1;
-
-static struct sockaddr_in sock;
-
 /**
  * Updates our info in the metaserver
  * Note that this is used for both metaserver1 and metaserver2 -
@@ -64,7 +58,7 @@ static struct sockaddr_in sock;
  * data structure, doing locking in the process.
  */
 void metaserver_update(void) {
-    char data[MAX_BUF], num_players = 0;
+    char num_players = 0;
     player *pl;
 
     /* We could use socket_info.nconns, but that is not quite as accurate,
@@ -175,11 +169,12 @@ static void free_metaserver2(MetaServer2 *ms) {
 int metaserver2_init(void) {
     static int has_init = 0;
     FILE *fp;
-    char buf[MAX_BUF], *cp;
+    char buf[MAX_BUF], *cp, dummy[1];
     MetaServer2 *ms2, *msnext;
-    int comp;
     pthread_t thread_id;
 
+    dummy[0] = '\0';
+
 #ifdef HAVE_CURL_CURL_H
     if (!has_init) {
         memset(&local_info, 0, sizeof(LocalMeta2Info));
@@ -216,7 +211,7 @@ int metaserver2_init(void) {
     /* Now load up the values from the file */
     snprintf(buf, sizeof(buf), "%s/metaserver2", settings.confdir);
 
-    if ((fp = open_and_uncompress(buf, 0, &comp, "r")) == NULL) {
+    if ((fp = fopen(buf, "r")) == NULL) {
         LOG(llevError, "Warning: No metaserver2 file found\n");
         return 0;
     }
@@ -240,7 +235,7 @@ int metaserver2_init(void) {
             /* This makes it so we don't have to do NULL checks against
              * cp everyplace
              */
-            cp = "";
+            cp = dummy;
         }
 
         if (!strcasecmp(buf, "metaserver2_notification")) {
@@ -292,7 +287,7 @@ int metaserver2_init(void) {
             LOG(llevError, "Unknown value in metaserver2 file: %s\n", buf);
         }
     }
-    close_and_delete(fp, comp);
+    fclose(fp);
 
     /* If no hostname is set, can't do updates */
     if (!local_info.hostname)
@@ -309,6 +304,8 @@ int metaserver2_init(void) {
 #endif
 
     if (local_info.notification) {
+        int ret;
+
         /* As noted above, it is much easier for the rest of the code
          * to not have to check for null pointers.  So we do that
          * here, and anything that is null, we just allocate
@@ -327,9 +324,9 @@ int metaserver2_init(void) {
         if (!local_info.flags)
             local_info.flags = strdup("");
 
-        comp = pthread_create(&thread_id, NULL, metaserver2_thread, NULL);
-        if (comp) {
-            LOG(llevError, "metaserver2_init: return code from pthread_create() is %d\n", comp);
+        ret = pthread_create(&thread_id, NULL, metaserver2_thread, NULL);
+        if (ret) {
+            LOG(llevError, "metaserver2_init: return code from pthread_create() is %d\n", ret);
 
             /* Effectively true - we're not going to update the metaserver */
             local_info.notification = 0;
