@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_check_object_c =
- *   "$Id: toolkit_common.c 13749 2010-09-06 17:59:13Z ryo_saeba $";
+ *   "$Id: toolkit_common.c 15377 2011-11-01 19:31:32Z ryo_saeba $";
  */
 
 /*
@@ -62,17 +62,17 @@ static int status_flag = 0;
 /**
  * set the logdir to use
  */
-void cctk_setlog(char *logfile) {
+void cctk_setlog(const char *logfile) {
     settings.logfilename = logfile;
     SET_TKFLAG(STATUS_LOGDIR);
 }
 
-void cctk_setdatadir(char *datadir) {
+void cctk_setdatadir(const char *datadir) {
     settings.datadir = datadir;
     SET_TKFLAG(STATUS_DATADIR);
 }
 
-void cctk_setconfdir(char *confdir) {
+void cctk_setconfdir(const char *confdir) {
     settings.confdir = confdir;
     SET_TKFLAG(STATUS_CONFDIR);
 }
@@ -88,6 +88,7 @@ void cctk_init_std_archetypes(void) {
     settings.treasures = "treasures.bld";
     init_globals();
     init_hash_table();
+    init_stats(FALSE);
     init_objects();
     init_vars();
     init_block();
