@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_check_arch_c =
- *   "$Id: check_arch.c 11421 2009-02-10 14:58:26Z anmaster $";
+ *   "$Id: check_arch.c 15379 2011-11-01 19:40:45Z ryo_saeba $";
  */
 
 /*
@@ -36,13 +36,13 @@
 #include <loader.h>
 #include <toolkit_common.h>
 
-void setup(void) {
+static void setup(void) {
     cctk_setdatadir(BUILD_ROOT"lib");
     cctk_setlog(LOGDIR"/unit/common/arch.out");
     cctk_init_std_archetypes();
 }
 
-void teardown(void) {
+static void teardown(void) {
     /* put any cleanup steps here, they will be run after each testcase */
 }
 
@@ -266,7 +266,7 @@ START_TEST(test_object_create_arch) {
 }
 END_TEST
 
-Suite *arch_suite(void) {
+static Suite *arch_suite(void) {
     Suite *s = suite_create("arch");
     TCase *tc_core = tcase_create("Core");
 
