@@ -4,6 +4,7 @@
  * Ryo 2005-07-15
  **/
 #include <global.h>
+#include <sproto.h>
 
 void apply_auto_fix(mapstruct *m) {
 }
@@ -49,18 +50,12 @@ object *find_skill_by_number(object *who, int skillno) {
     return NULL;
 }
 
-void esrv_del_item(player *pl, int tag) {
+void esrv_del_item(player *pl, object *ob) {
 }
 
 void esrv_update_spells(player *pl) {
 }
 
-void monster_check_apply(object *ob, object *obt) {
-}
-
-void trap_adjust(object *ob, int x) {
-}
-
 void rod_adjust(object *rod) {
 }
 
