@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_check_account_c =
- *   "$Id: check_account_char.c 14125 2010-11-24 19:01:48Z akirschbaum $";
+ *   "$Id: check_account_char.c 15379 2011-11-01 19:40:45Z ryo_saeba $";
  */
 
 /*
@@ -37,10 +37,10 @@
 #include <sproto.h>
 #include <account_char.h>
 
-void setup(void) {
+static void setup(void) {
 }
 
-void teardown(void) {
+static void teardown(void) {
     /* put any cleanup steps here, they will be run after each testcase */
 }
 
@@ -147,7 +147,7 @@ START_TEST(test_account_char_load) {
 
 END_TEST
 
-Suite *account_suite(void) {
+static Suite *account_suite(void) {
     Suite *s = suite_create("account_char");
     TCase *tc_core = tcase_create("Core");
 
