@@ -496,8 +496,7 @@ static void animate_bomb(object *op) {
                     free_string(tmp->skill);
                 tmp->skill = add_refcount(op->skill);
             }
-            if (QUERY_FLAG(tmp, FLAG_IS_TURNABLE))
-                SET_ANIMATION(tmp, i);
+            object_update_turn_face(tmp);
             object_insert_in_map_at(tmp, op->map, op, 0, op->x+freearr_x[i], op->y+freearr_x[i]);
             ob_process(tmp);
         }
@@ -512,7 +511,6 @@ static void animate_bomb(object *op) {
  */
 static void move_missile(object *op) {
     int i, mflags;
-    object *owner;
     sint16 new_x, new_y;
     mapstruct *m;
 
@@ -522,7 +520,8 @@ static void move_missile(object *op) {
         return;
     }
 
-    owner = object_get_owner(op);
+    /* call is required to potentially clean owner, but we don't care for the result */
+    object_get_owner(op);
 
     new_x = op->x+DIRX(op);
     new_y = op->y+DIRY(op);
@@ -552,7 +551,7 @@ static void move_missile(object *op) {
     i = spell_find_dir(m, new_x, new_y, object_get_owner(op));
     if (i > 0 && i != op->direction) {
         op->direction = adjust_dir(op->direction, i);
-        SET_ANIMATION(op, op->direction);
+        object_update_turn_face(op);
     }
     object_insert_in_map_at(op, m, op, 0, new_x, new_y);
 }
@@ -892,7 +891,7 @@ static void check_spell_knockback(object *op) {
             continue;
 
         /* don't move floors or immobile objects */
-        if (QUERY_FLAG(tmp, FLAG_IS_FLOOR) || (!QUERY_FLAG(tmp, FLAG_ALIVE) && QUERY_FLAG(tmp, FLAG_NO_PICK)))
+        if (QUERY_FLAG(tmp, FLAG_IS_FLOOR) || QUERY_FLAG(tmp, FLAG_NO_PICK))
             continue;
 
         /* count the object's sections */
